tinyMCE.addI18n('pt.xhtmlxtras_dlg',{
attribute_label_title:"T\u00EDtulo",
attribute_label_id:"ID",
attribute_label_class:"Classe",
attribute_label_style:"Estilo",
attribute_label_cite:"Citar",
attribute_label_datetime:"Data/Hora",
attribute_label_langdir:"Dire\u00E7\u00E3o do texto",
attribute_option_ltr:"Da esquerda para a direita",
attribute_option_rtl:"Da direita para a esquerda",
attribute_label_langcode:"Idioma",
attribute_label_tabindex:"TabIndex",
attribute_label_accesskey:"Tecla de Atalho",
attribute_events_tab:"Eventos",
attribute_attrib_tab:"Atributos",
general_tab:"Geral",
attrib_tab:"Atributos",
events_tab:"Eventos",
fieldset_general_tab:"Configura\u00E7\u00F5es gerais",
fieldset_attrib_tab:"Atributos",
fieldset_events_tab:"Eventos",
title_ins_element:"Inserir",
title_del_element:"Apagar",
title_acronym_element:"Acr\u00F4nimo",
title_abbr_element:"Abrevia\u00E7\u00E3o",
title_cite_element:"Cita\u00E7\u00E3o",
remove:"Remover",
insert_date:"Inserir data/hora",
option_ltr:"Da esquerda para a direita",
option_rtl:"Da direita para a esquerda",
attribs_title:"Inserir/editar atributos"
});