tinyMCE.addI18n('it.xhtmlxtras_dlg',{
attribute_label_title:"Titolo",
attribute_label_id:"ID",
attribute_label_class:"Classe",
attribute_label_style:"Style",
attribute_label_cite:"Citazione",
attribute_label_datetime:"Date/Time",
attribute_label_langdir:"Direzione del testo",
attribute_option_ltr:"Sinistra verso destra",
attribute_option_rtl:"Destra verso sinistra",
attribute_label_langcode:"Lingua",
attribute_label_tabindex:"Indice tabulazione",
attribute_label_accesskey:"Tasto di accesso",
attribute_events_tab:"Eventi",
attribute_attrib_tab:"Attributi",
general_tab:"Generale",
attrib_tab:"Attributi",
events_tab:"Eventi",
fieldset_general_tab:"Impostazioni Generali",
fieldset_attrib_tab:"Attributi elemento",
fieldset_events_tab:"Eventi elemento",
title_ins_element:"Inserimento elemento",
title_del_element:"Cancellazione elemento",
title_acronym_element:"Acronimo elemento",
title_abbr_element:"Abbreviazione elemento",
title_cite_element:"Citazione elemento",
remove:"Rimuovi",
insert_date:"Inserisci data/ora corrente",
option_ltr:"Sinistra verso destra",
option_rtl:"Destra verso sinistra",
attribs_title:"Inserisci/modifica attributi"
});