tinyMCE.addI18n('he.xhtmlxtras_dlg',{
attribute_label_title:"\u05DB\u05D5\u05EA\u05E8\u05EA",
attribute_label_id:"ID",
attribute_label_class:"Class",
attribute_label_style:"Style",
attribute_label_cite:"\u05E6\u05D9\u05D8\u05D5\u05D8",
attribute_label_datetime:"\u05EA\u05D0\u05E8\u05D9\u05DA/\u05D6\u05DE\u05DF",
attribute_label_langdir:"\u05DB\u05D9\u05D5\u05D5\u05DF \u05D4\u05D8\u05E7\u05E1\u05D8",
attribute_option_ltr:"\u05DE\u05E9\u05DE\u05D0\u05DC \u05DC\u05D9\u05DE\u05D9\u05DF",
attribute_option_rtl:"\u05DE\u05D9\u05DE\u05D9\u05DF \u05DC\u05E9\u05DE\u05D0\u05DC",
attribute_label_langcode:"\u05E9\u05E4\u05D4",
attribute_label_tabindex:"TabIndex",
attribute_label_accesskey:"AccessKey",
attribute_events_tab:"\u05D0\u05D9\u05E8\u05D5\u05E2\u05D9\u05DD",
attribute_attrib_tab:"\u05EA\u05DB\u05D5\u05E0\u05D5\u05EA",
general_tab:"\u05DB\u05DC\u05DC\u05D9",
attrib_tab:"\u05EA\u05DB\u05D5\u05E0\u05D5\u05EA",
events_tab:"\u05D0\u05D9\u05E8\u05D5\u05E2\u05D9\u05DD",
fieldset_general_tab:"\u05D4\u05D2\u05D3\u05E8\u05D5\u05EA \u05DB\u05DC\u05DC\u05D9\u05D5\u05EA",
fieldset_attrib_tab:" \u05EA\u05DB\u05D5\u05E0\u05D5\u05EA \u05D4\u05D0\u05DC\u05DE\u05E0\u05D8",
fieldset_events_tab:"\u05D0\u05D9\u05E8\u05D5\u05E2\u05D9 \u05D4\u05D0\u05DC\u05DE\u05E0\u05D8",
title_ins_element:"\u05D4\u05DB\u05E0\u05E1\u05EA \u05D0\u05DC\u05DE\u05E0\u05D8",
title_del_element:"\u05DE\u05D7\u05D9\u05E7\u05EA \u05D0\u05DC\u05DE\u05E0\u05D8",
title_acronym_element:"\u05E8\u05D0\u05E9\u05D9 \u05EA\u05D9\u05D1\u05D5\u05EA \u05D4\u05D0\u05DC\u05DE\u05E0\u05D8",
title_abbr_element:"\u05E7\u05D9\u05E6\u05D5\u05E8 \u05D0\u05DC\u05DE\u05E0\u05D8",
title_cite_element:"\u05E6\u05D9\u05D8\u05D5\u05D8 \u05D0\u05DC\u05DE\u05E0\u05D8",
remove:"\u05D4\u05E1\u05E8",
insert_date:"\u05D4\u05DB\u05E0\u05E1\u05EA \u05D6\u05DE\u05DF/\u05EA\u05D0\u05E8\u05D9\u05DA \u05E0\u05D5\u05DB\u05D7\u05D9",
option_ltr:"\u05DE\u05E9\u05DE\u05D0\u05DC \u05DC\u05D9\u05DE\u05D9\u05DF",
option_rtl:"\u05DE\u05D9\u05DE\u05D9\u05DF \u05DC\u05E9\u05DE\u05D0\u05DC",
attribs_title:"\u05D4\u05DB\u05E0\u05E1\u05EA/\u05E2\u05D3\u05DB\u05D5\u05DF \u05EA\u05DB\u05D5\u05E0\u05D5\u05EA"
});