tinyMCE.addI18n({cs:{
common:{
edit_confirm:"Chcete pou\u017E\u00EDt pro tento text WYSIWYG editaci?",
apply:"Pou\u017E\u00EDt",
insert:"Vlo\u017Eit",
update:"Aktualizovat",
cancel:"Zru\u0161it",
close:"Zav\u0159\u00EDt",
browse:"Proch\u00E1zet",
class_name:"T\u0159\u00EDda",
not_set:"- Nenastaveno -",
clipboard_msg:"Funkce kop\u00EDrovat/vyjmout/vlo\u017Eit nejsou pou\u017Eiteln\u00E9 v Mozille a Firefoxu.\nChcete v\u00EDce informac\u00ED?",
clipboard_no_support:"Tato funkce nen\u00ED va\u0161\u00EDm prohl\u00ED\u017Ee\u010Dem podporov\u00E1na. Pou\u017Eijte kl\u00E1vesov\u00E9 zkratky.",
popup_blocked:"Blokov\u00E1n\u00ED vyskakovac\u00EDch oken neumo\u017Enilo otev\u0159\u00EDt okno, nutn\u00E9 pro funkci aplikace. Pro pln\u00E9 vyu\u017Eit\u00ED mo\u017Enost\u00ED vypn\u00C4\u009Bte blokov\u00E1n\u00ED vyskakovac\u00EDch oken pro tento web.",
invalid_data:"Chyba: Vlo\u017Een\u00E1 chybn\u00E1 data jsou ozna\u010Dena \u010Derven\u011B.",
more_colors:"V\u00EDce barev"
},
contextmenu:{
align:"Zarovn\u00E1n\u00ED",
left:"Doleva",
center:"Na st\u0159ed",
right:"Doprava",
full:"Do bloku"
},
insertdatetime:{
date_fmt:"%d.%m.%Y",
time_fmt:"%H:%M:%S",
insertdate_desc:"Vlo\u017Eit datum",
inserttime_desc:"Vlo\u017Eit \u010Das",
months_long:"Leden,\u00DAnor,B\u0159ezen,Duben,Kv\u011Bten,\u010Cerven,\u010Cervenec,Srpen,Z\u00E1\u0159\u00ED,\u0158\u00EDjen,Listopad,Prosinec",
months_short:"Led,\u00DAno,B\u0159e,Dub,Kv\u011B,\u010Cer,\u010Cvc,Srp,Z\u00E1\u0159,\u0158\u00EDj,Lis,Pro",
day_long:"Ned\u011Ble,Pond\u011Bl\u00ED,\u00DAter\u00FD,St\u0159eda,\u010Ctvrtek,P\u00E1tek,Sobota,Ned\u011Ble",
day_short:"Ne,Po,\u00DAt,St,\u010Ct,P\u00E1,So,Ne"
},
print:{
print_desc:"Tisknout"
},
preview:{
preview_desc:"N\u00E1hled"
},
directionality:{
ltr_desc:"Sm\u011Br zleva doprava",
rtl_desc:"Sm\u011Br zprava doleva"
},
layer:{
insertlayer_desc:"Vlo\u017Eit novou vrstvu",
forward_desc:"P\u0159esunout doP\u0159edu",
backward_desc:"P\u0159esunout dozadu",
absolute_desc:"P\u0159epnout absolutn\u00ED pozici",
content:"Nov\u00E1 vrstva..."
},
save:{
save_desc:"Ulo\u017Eit",
cancel_desc:"Zru\u0161it v\u0161echny zm\u011Bny"
},
nonbreaking:{
nonbreaking_desc:"Vlo\u017Eit pevnou mezeru"
},
iespell:{
iespell_desc:"Kontrolovat pravopis",
download:"ieSpell nebyl detekov\u00E1n. Chcete ho nainstalovat?"
},
advhr:{
advhr_desc:"Vodorovn\u00FD odd\u011Blova\u010D"
},
emotions:{
emotions_desc:"Emotikony"
},
searchreplace:{
search_desc:"Hledat",
replace_desc:"Naj\u00EDt/nahradit"
},
advimage:{
image_desc:"Vlo\u017Eit/upravit obr\u00E1zek"
},
advlink:{
link_desc:"Vlo\u017Eit/upravit odkaz"
},
xhtmlxtras:{
cite_desc:"Citace",
abbr_desc:"Zkratka",
acronym_desc:"Akronym",
del_desc:"Vymaz\u00E1n\u00ED",
ins_desc:"Vlo\u017Een\u00ED",
attribs_desc:"Vlo\u017Eit/upravit atributy"
},
style:{
desc:"Upravit CSS styl"
},
paste:{
paste_text_desc:"Vlo\u017Eit prost\u00FD text",
paste_word_desc:"Vlo\u017Eit z Wordu",
selectall_desc:"Vybrat v\u0161e"
},
paste_dlg:{
text_title:"Pou\u017Eijte CTRL+V pro vlo\u017Een\u00ED textu do okna.",
text_linebreaks:"Zachovat \u0159\u00E1dkov\u00E1n\u00ED",
word_title:"Pou\u017Eijte CTRL+V pro vlo\u017Een\u00ED textu do okna."
},
table:{
desc:"Vlo\u017Eit novou tabulku",
row_before_desc:"Vlo\u017Eit \u0159\u00E1dek P\u0159ed",
row_after_desc:"Vlo\u017Eit \u0159\u00E1dek za",
delete_row_desc:"Vymazat \u0159\u00E1dek",
col_before_desc:"Vlo\u017Eit sloupec P\u0159ed",
col_after_desc:"Vlo\u017Eit sloupec za",
delete_col_desc:"Vymazat sloupec",
split_cells_desc:"Rozd\u011Blit bu\u0148ky",
merge_cells_desc:"Slou\u010Dit bu\u0148ky",
row_desc:"Vlastnosti \u0159\u00E1dku",
cell_desc:"Vlastnosti bu\u0148ky",
props_desc:"Vlastnosti tabulky",
paste_row_before_desc:"Vlo\u017Eit \u0159\u00E1dek P\u0159ed",
paste_row_after_desc:"Vlo\u017Eit \u0159\u00E1dek za",
cut_row_desc:"Vyjmout \u0159\u00E1dek",
copy_row_desc:"Kop\u00EDrovat \u0159\u00E1dek",
del:"Vymazat tabulku",
row:"\u0158\u00E1dek",
col:"Sloupec",
cell:"Bu\u0148ka"
},
autosave:{
unload_msg:"Proveden\u00E9 zm\u011Bny mohou b\u00FDt ztraceny, jestli\u017Ee opust\u00EDte tuto str\u00E1nku."
},
fullscreen:{
desc:"P\u0159epnout na celostr\u00E1nkov\u00E9 zobrazen\u00ED"
},
media:{
desc:"Vlo\u017Eit/editovat m\u00E9dia",
edit:"Editovat m\u00E9dia"
},
fullpage:{
desc:"Vlastnosti dokumentu"
},
template:{
desc:"Vlo\u017Eit P\u0159eddefinovan\u00FD obsah ze \u0161ablony"
},
visualchars:{
desc:"Zobrazen\u00ED skryt\u00FDch znak\u016F zap/vyp"
},
spellchecker:{
desc:"Zapnout kontrolu textu",
menu:"Nastaven\u00ED kontroly textu",
ignore_word:"Ignorovat slovo",
ignore_words:"Ignorovat v\u0161e",
langs:"Jazyky",
wait:"\u010Cekejte pros\u00EDm...",
sug:"N\u00E1pov\u011Bda",
no_sug:"\u0139\u02DD\u00E1dn\u00E1 n\u00E1pov\u011Bda",
no_mpell:"Nebyly nalezeny \u017E\u00E1dn\u00E9 chyby."
},
pagebreak:{
desc:"Vlo\u017Eit konec str\u00E1nky"
}}});