tinyMCE.addI18n('ro.advimage_dlg',{
tab_general:"General",
tab_appearance:"Afi\u015Fare",
tab_advanced:"Avansat",
general:"General",
title:"Titlu",
preview:"Previzualizare",
constrain_proportions:"Men\u0163ine propor\u0163ii",
langdir:"Direc\u0163ie limb\u0103",
langcode:"Cod limb\u0103",
long_desc:"Descriere leg\u0103tur\u0103",
style:"Stil",
classes:"Clase",
ltr:"De la st\u00E2nga la dreapta",
rtl:"De la dreapta la st\u00E2nga",
id:"Id",
map:"Hart\u0103 imagine",
swap_image:"Schimb\u0103 imaginea",
alt_image:"Imagine alternativ\u0103",
mouseover:"Pentru maus deasupra",
mouseout:"Pentru maus \u00EEn afar\u0103",
misc:"Diverse",
example_img:"Imagine mic\u0103",
missing_alt:"Sigur dori\u0163i s\u0103 continua\u0163i f\u0103r\u0103 a introduce o descriere a imaginii?",
dialog_title:"Inserare/editare imagine",
src:"URL imagine",
alt:"Descriere imagine",
list:"List\u0103 imagini",
border:"Bordur\u0103",
dimensions:"Dimensiuni",
vspace:"Spa\u0163iu vertical",
hspace:"Spa\u0163iu orizontal",
align:"Aliniere",
align_baseline:"Baseline",
align_top:"Sus",
align_middle:"La mijloc",
align_bottom:"Jos",
align_texttop:"Textul sus",
align_textbottom:"Textul jos",
align_left:"St\u00E2nga",
align_right:"Dreapta",
image_list:"List\u0103 de imagini"
});