tinyMCE.addI18n('pt.advimage_dlg',{
tab_general:"Geral",
tab_appearance:"Apar\u00EAncia",
tab_advanced:"Avan\u00E7ado",
general:"Geral",
title:"T\u00EDtulo",
preview:"Pr\u00E9-Visualiza\u00E7\u00E3o",
constrain_proportions:"Manter propor\u00E7\u00F5es",
langdir:"Dire\u00E7\u00E3o do texto",
langcode:"C\u00F3digo de idioma",
long_desc:"Descri\u00E7\u00E3o extensa",
style:"Estilo",
classes:"Classes",
ltr:"Da esquerda para a direita",
rtl:"Da direita para a esquerda",
id:"Id",
map:"Mapa de imagem",
swap_image:"Trocar imagem",
alt_image:"Imagem alternativa",
mouseover:"mouseover",
mouseout:"mouseout",
misc:"Misto",
example_img:"Pr\u00E9-Visualiza\u00E7\u00E3o",
missing_alt:"Tem certeza que deseja continuar sem acrescentar uma descri\u00E7\u00E3o \u00E0 imagem? (Isto pode gerar problemas de acessibilidade em alguns navegadores)",
dialog_title:"Inserir/editar imagem",
src:"Endere\u00E7o da imagem",
alt:"Descri\u00E7\u00E3o da imagem",
list:"Lista de imagens",
border:"Limite",
dimensions:"Dimens\u00F5es",
vspace:"Espa\u00E7o vertical",
hspace:"Espa\u00E7o horizontal",
align:"Alinhamento",
align_baseline:"Sobre a linha de texto",
align_top:"Topo",
align_middle:"Meio",
align_bottom:"Abaixo",
align_texttop:"Topo do texto",
align_textbottom:"Base do texto",
align_left:"Esquerda",
align_right:"Direita",
image_list:"Lista de imagens"
});