tinyMCE.addI18n('lt.advanced_dlg',{
about_title:"Apie TinyMCE",
about_general:"Apie",
about_help:"Pagalba",
about_license:"Licencija",
about_plugins:"Papildiniai",
about_plugin:"Papildinys",
about_author:"Autorius",
about_version:"Versija",
about_loaded:"\u012Ekelti papildiniai",
anchor_title:"\u012Eterpti/redaguoti prierai\u0161\u0105",
anchor_name:"Prierai\u0161o vardas",
code_title:"HTML i\u0161eities kodo redaktorius",
code_wordwrap:"Skaidyti tekst\u0105",
colorpicker_title:"Pasirinkti spalv\u0105",
colorpicker_picker_tab:"Parinkiklis",
colorpicker_picker_title:"Spalvos parinkiklis",
colorpicker_palette_tab:"Palet\u0117",
colorpicker_palette_title:"Palet\u0117s spalvos",
colorpicker_named_tab:"\u012Evardintosios",
colorpicker_named_title:"\u012Evardintosios spalvos",
colorpicker_color:"Spalva:",
colorpicker_name:"Pavadinimas:",
charmap_title:"Pasirinkti nestandartin\u012F simbol\u012F",
image_title:"\u012Eterpti/redaguoti paveiksl\u0117l\u012F",
image_src:"Paveiksl\u0117lio URL adresas",
image_alt:"Paveiksl\u0117lio apra\u0161as",
image_list:"Paveiksl\u0117li\u0173 s\u0105ra\u0161as",
image_border:"R\u0117melis",
image_dimensions:"I\u0161matavimai",
image_vspace:"Vertikalus tarpas",
image_hspace:"Horizontalus tarpas",
image_align:"Lygiavimas",
image_align_baseline:"Pradiniame ta\u0161ke",
image_align_top:"Vir\u0161uje",
image_align_middle:"Viduryje",
image_align_bottom:"Apa\u010Dioje",
image_align_texttop:"Teksto vir\u0161uje",
image_align_textbottom:"Teksto apa\u010Dioje",
image_align_left:"Kair\u0117je",
image_align_right:"De\u0161in\u0117je",
link_title:"\u012Eterpti/redaguoti nuorod\u0105",
link_url:"Nuorodos URL adresas",
link_target:"Paskirtis",
link_target_same:"Atverti tame pa\u010Diame lange",
link_target_blank:"Atverti naujame lange",
link_titlefield:"Pavadinimas",
link_is_email:"URL adresas, kur\u012F \u012Fved\u0117te yra el. pa\u0161to adresas, ar norite prid\u0117ti reikaling\u0105 mailto: prefiks\u0105?",
link_is_external:"URL adresas, kur\u012F \u012Fved\u0117te yra i\u0161orin\u0117 nuoroda, ar norite prid\u0117ti reikaling\u0105 http:// prefiks\u0105?",
link_list:"Nuorod\u0173 s\u0105ra\u0161as"
});