tinyMCE.addI18n('vi.table_dlg',{
general_tab:"C\u01A1 b\u1EA3n",
advanced_tab:"N\u00E2ng cao",
general_props:"T\u00F9y ch\u1ECDn c\u01A1 b\u1EA3n",
advanced_props:"T\u00F9y ch\u1ECDn n\u00E2ng cao",
rowtype:"Row in table part",
title:"Ch\u00E8n/thay \u0111\u1ED5i b\u1EA3ng",
width:"Chi\u1EC1u r\u1ED9ng",
height:"Chi\u1EC1u cao",
cols:"S\u1ED1 c\u1ED9t",
rows:"S\u1ED1 d\u00F2ng",
cellspacing:"Kho\u1EA3ng c\u00E1ch ngang",
cellpadding:"Kho\u1EA3ng c\u00E1ch d\u1ECDc",
border:"\u0110\u01B0\u1EDDng vi\u1EC1n",
align:"Canh l\u1EC1",
align_default:"M\u1EB7c \u0111\u1ECBnh",
align_left:"Tr\u00E1i",
align_right:"Ph\u1EA3i",
align_middle:"Gi\u1EEFa",
row_title:"Thay \u0111\u1ED5i thu\u1ED9c t\u00EDnh d\u00F2ng",
cell_title:"Thay \u0111\u1ED5i thu\u1ED9c t\u00EDnh \u00F4",
cell_type:"Cell type",
valign:"Canh l\u1EC1 d\u1ECDc",
align_top:"Tr\u00EAn",
align_bottom:"D\u01B0\u1EDBi",
bordercolor:"M\u00E0u \u0111\u01B0\u1EDDng vi\u1EC1n",
bgcolor:"M\u00E0u n\u1EC1n",
merge_cells_title:"G\u1ED9p \u00F4",
id:"Id",
style:"Style",
langdir:"Language direction",
langcode:"Language code",
mime:"Target MIME type",
ltr:"Left to right",
rtl:"Right to left",
bgimage:"Background image",
summary:"Summary",
td:"Data",
th:"Header",
cell_cell:"C\u1EADp nh\u1EADt \u00F4 hi\u1EC7n t\u1EA1i",
cell_row:"C\u1EADp nh\u1EADt t\u1EA5t c\u1EA3 \u00F4 c\u00F3 tr\u00EAn d\u00F2ng",
cell_all:"C\u1EADp nh\u1EADt t\u1EA5t c\u1EA3 \u00F4 c\u00F3 trong b\u1EA3ng",
row_row:"C\u1EADp nh\u1EADt d\u00F2ng hi\u1EC7n t\u1EA1i",
row_odd:"C\u1EADp nh\u1EADt d\u00F2ng l\u1EBB c\u00F3 trong b\u1EA3ng",
row_even:"C\u1EADp nh\u1EADt d\u00F2ng ch\u1EB5n c\u00F3 trong b\u1EA3ng",
row_all:"C\u1EADp nh\u1EADt t\u1EA5t c\u1EA3 d\u00F2ng c\u00F3 trong b\u1EA3ng",
thead:"Ph\u1EA7n \u0111\u1EA7u b\u1EA3ng",
tbody:"Ph\u1EA7n th\u00E2n b\u1EA3ng",
tfoot:"Ph\u1EA7n cu\u1ED1i b\u1EA3ng",
scope:"Scope",
rowgroup:"Row Group",
colgroup:"Col Group",
col_limit:"You've exceeded the maximum number of columns of {$cols}.",
row_limit:"You've exceeded the maximum number of rows of {$rows}.",
cell_limit:"You've exceeded the maximum number of cells of {$cells}.",
missing_scope:"Are you sure you want to continue without specifying a scope for this table header cell. Without it, it may be difficult for some users with disabilities to understand the content or data displayed of the table.",
caption:"Th\u00EAm ti\u00EAu \u0111\u1EC1 cho b\u1EA3ng",
frame:"Frame",
frame_none:"none",
frame_groups:"groups",
frame_rows:"rows",
frame_cols:"cols",
frame_all:"all",
rules:"Rules",
rules_void:"void",
rules_above:"above",
rules_below:"below",
rules_hsides:"hsides",
rules_lhs:"lhs",
rules_rhs:"rhs",
rules_vsides:"vsides",
rules_box:"box",
rules_border:"border"
});