tinyMCE.addI18n('nl.emotions_dlg',{
title:"Emotie invoegen",
desc:"Emoties",
cool:"Stoer",
cry:"Huilen",
embarassed:"Schamen",
foot_in_mouth:"Verstomd",
frown:"Wenkbrauw ophalen",
innocent:"Onschuldig",
kiss:"Zoenen",
laughing:"Lachen",
money_mouth:"Hebberig",
sealed:"Afgesloten",
smile:"Lachen",
surprised:"Verrast",
tongue_out:"Tong uitsteken",
undecided:"Onbeslist",
wink:"Knipogen",
yell:"Roepen"
});