tinyMCE.addI18n('da.advlink_dlg',{
title:"Inds\u00E6t/rediger link",
url:"Link URL",
target:"M\u00E5l",
titlefield:"Titel",
is_email:"Den URL, der er indtastet, ser ud til at v\u00E6re en emailadresse. Vil du have tilf\u00F8jet det p\u00E5kr\u00E6vede mailto: foran?",
is_external:"Den URL, der er indtastet, ser ud til at v\u00E6re et eksternt link. Vil du have tilf\u00F8jet det p\u00E5kr\u00E6vede http:// foran?",
list:"Liste over links",
general_tab:"Generelt",
popup_tab:"Popup",
events_tab:"H\u00E6ndelser",
advanced_tab:"Advanceret",
general_props:"Generelle egenskaber",
popup_props:"Popup egenskaber",
event_props:"H\u00E6ndelser",
advanced_props:"Avancerede egenskaber",
popup_opts:"Indstillinger",
anchor_names:"Ankre",
target_same:"\u00C5ben i dette vindue / ramme",
target_parent:"\u00C5ben i overliggende vindue / ramme",
target_top:"\u00C5ben i \u00F8verste vindue / ramme (erstatter alle rammer)",
target_blank:"\u00C5ben i nyt vindue",
popup:"Javascript popup",
popup_url:"Popup URL",
popup_name:"Vinduesnavn",
popup_return:"Inds\u00E6t 'return false'",
popup_scrollbars:"Vis rullepanel",
popup_statusbar:"Vis statuslinje",
popup_toolbar:"Vis v\u00E6rkt\u00F8jslinjer",
popup_menubar:"Vis menulinje",
popup_location:"Vis adresselinje",
popup_resizable:"Lad det v\u00E6re muligt at \u00E6ndre st\u00F8rrelsen p\u00E5 vinduet",
popup_dependent:"Afh\u00E6ngig (Kun Mozilla/Firefox)",
popup_size:"St\u00F8rrelse",
popup_position:"Position (X/Y)",
id:"Id",
style:"Stil",
classes:"Klasser",
target_name:"Destinationsnavn",
langdir:"Sprogretning",
target_langcode:"Destinationssprog",
langcode:"Sprogkode",
encoding:"Destinationstegns\u00E6t",
mime:"Destinations-MIME-type",
rel:"Relativ side til destination",
rev:"Relativ destination til side",
tabindex:"Tabindex",
accesskey:"Genvejstast",
ltr:"Venstre mod h\u00F8jre",
rtl:"H\u00F8jre mod venstre",
link_list:"Liste over links"
});