tinyMCE.addI18n('vi.advanced',{
style_select:"Ki\u1EC3u",
font_size:"C\u1EE1 ch\u1EEF",
fontdefault:"Ph\u00F4ng ch\u1EEF",
block:"\u0110\u1ECBnh d\u1EA1ng",
paragraph:"\u0110o\u1EA1n v\u0103n b\u1EA3n",
div:"Div",
address:"\u0110\u1ECBa ch\u1EC9",
pre:"Kh\u00F4ng \u0111\u1ECBnh d\u1EA1ng",
h1:"Ti\u00EAu \u0111\u1EC1 1",
h2:"Ti\u00EAu \u0111\u1EC1 2",
h3:"Ti\u00EAu \u0111\u1EC1 3",
h4:"Ti\u00EAu \u0111\u1EC1 4",
h5:"Ti\u00EAu \u0111\u1EC1 5",
h6:"Ti\u00EAu \u0111\u1EC1 6",
blockquote:"\u0110\u1ECBnh d\u1EA1ng kh\u1ED1i",
code:"M\u00E3",
samp:"M\u00E3 v\u00ED d\u1EE5",
dt:"T\u00EAn \u0111\u1ECBnh ngh\u0129a ",
dd:"M\u00F4 t\u1EA3 \u0111\u1ECBnh ngh\u0129a",
bold_desc:"\u0110\u1EADm (Ctrl+B)",
italic_desc:"Nghi\u00EAng (Ctrl+I)",
underline_desc:"G\u1EA1ch ch\u00E2n (Ctrl+U)",
striketrough_desc:"G\u1EA1ch x\u00F3a",
justifyleft_desc:"C\u0103n tr\u00E1i",
justifycenter_desc:"C\u0103n gi\u1EEFa",
justifyright_desc:"C\u0103n ph\u1EA3i",
justifyfull_desc:"C\u0103n \u0111\u1EC1u",
bullist_desc:"Danh s\u00E1ch",
numlist_desc:"Danh s\u00E1ch th\u1EE9 t\u1EF1",
outdent_desc:"Gi\u1EA3m l\u1EC1 tr\u00E1i",
indent_desc:"T\u0103ng l\u1EC1 tr\u00E1i",
undo_desc:"Kh\u00F4i ph\u1EE5c (Ctrl+Z)",
redo_desc:"L\u1EB7p l\u1EA1i (Ctrl+Y)",
link_desc:"Ch\u00E8n/thay \u0111\u1ED5i li\u00EAn k\u1EBFt",
unlink_desc:"X\u00F3a li\u00EAn k\u1EBFt",
image_desc:"Ch\u00E8n/s\u1EEDa h\u00ECnh \u1EA3nh",
cleanup_desc:"D\u1ECDn d\u1EB9p m\u00E3 l\u1ED9n x\u1ED9n",
code_desc:"S\u1EEDa m\u00E3 ngu\u1ED3n HTML",
sub_desc:"Subscript",
sup_desc:"Superscript",
hr_desc:"Ch\u00E8n thanh ngang",
removeformat_desc:"X\u00F3a \u0111\u1ECBnh d\u1EA1ng",
custom1_desc:"M\u00F4 t\u1EA3 c\u1EE7a b\u1EA1n \u1EDF \u0111\u00E2y",
forecolor_desc:"Ch\u1ECDn m\u00E0u ch\u1EEF",
backcolor_desc:"Ch\u1ECDn m\u00E0u n\u1EC1n",
charmap_desc:"Ch\u00E8n k\u00FD t\u1EF1 \u0111\u1EB7c bi\u1EC7t",
visualaid_desc:"B\u1EADt/t\u1EAFt c\u00E1c ph\u1EA7n t\u1EED \u1EA9n",
anchor_desc:"Ch\u00E8n/s\u1EEDa m\u1ED1c (anchor)",
cut_desc:"C\u1EAFt",
copy_desc:"Sao ch\u00E9p",
paste_desc:"D\u00E1n",
image_props_desc:"Thu\u1ED9c t\u00EDnh h\u00ECnh \u1EA3nh",
newdocument_desc:"V\u0103n b\u1EA3n m\u1EDBi",
help_desc:"Gi\u00FAp \u0111\u1EE1",
blockquote_desc:"\u0110\u1ECBnh d\u1EA1ng kh\u1ED1i",
clipboard_msg:"Sao ch\u00E9p/C\u1EAFt/D\u00E1n kh\u00F4ng ho\u1EA1t \u0111\u1ED9ng tr\u00EAn Mozilla v\u00E0 Firefox.\nB\u1EA1n mu\u1ED1n xem th\u00EAm th\u00F4ng tin v\u1EC1 v\u1EA5n \u0111\u1EC1 n\u00E0y?",
path:"\u0110\u01B0\u1EDDng d\u1EABn",
newdocument:"B\u1EA1n c\u00F3 ch\u1EAFc ch\u1EAFn mu\u1ED1n x\u00F3a t\u1EA5t c\u1EA3 n\u1ED9i dung \u0111\u00E3 so\u1EA1n?",
toolbar_focus:"Nh\u1EA3y \u0111\u1EBFn thanh c\u00F4ng c\u1EE5 - Alt+Q, Nh\u1EA3y \u0111\u1EBFn \u00F4 so\u1EA1n th\u1EA3o - Alt-Z, Nh\u1EA3y \u0111\u1EBFn \u0111\u01B0\u1EDDng d\u1EABn - Alt-X",
more_colors:"Nhi\u1EC1u m\u00E0u h\u01A1n"
});