tinyMCE.addI18n('sl.media_dlg',{
title:"Vstavi / uredi multimedijsko vsebino",
general:"Splo\u0161no",
advanced:"Napredno",
file:"Datoteka/URL",
list:"Seznam",
size:"Dimenzije",
preview:"Predogled",
constrain_proportions:"Obdr\u017Ei razmerje",
type:"Tip",
id:"Oznaka",
name:"Ime",
class_name:"Razred",
vspace:"n-razmik",
hspace:"v-razmik",
play:"Samodejno predvajaj",
loop:"Zankaj",
menu:"Prika\u017Ei meni",
quality:"Kakovost",
scale:"Stopnja pove\u010Dave",
align:"Poravnava",
salign:"\"SAlign\"",
wmode:"\"WMode\"",
bgcolor:"Ozadje",
base:"\"Base\"",
flashvars:"\"Flashvars\"",
liveconnect:"\"SWLiveConnect\"",
autohref:"\"AutoHREF\"",
cache:"Predpomnjenje",
hidden:"Skrito",
controller:"Nadzorni element",
kioskmode:"Na\u010Din \'kiosk\'",
playeveryframe:"Predvajaj vsak okvir",
targetcache:"Ciljno predpomnjenje",
correction:"Brez popravkov",
enablejavascript:"Omogo\u010Di JavaScript",
starttime:"Za\u010Detni \u010Das",
endtime:"Kon\u010Dni \u010Das",
href:"\"Href\"",
qtsrcchokespeed:"\"Choke speed\"",
target:"Cilj",
volume:"Glasnost",
autostart:"Samodejno za\u010Dni",
enabled:"Omogo\u010Deno",
fullscreen:"Cel zaslon",
invokeurls:"Naslovi URLje",
mute:"Uti\u0161aj",
stretchtofit:"Raz\u0161iri",
windowlessvideo:"Video brez okna",
balance:"Ravnovesje",
baseurl:"Temeljni URL",
captioningid:"Oznaka podnapisov",
currentmarker:"Trenutna oznaka",
currentposition:"Trenutni polo\u017Eaj",
defaultframe:"Privzeti okvir",
playcount:"\u0160tevilo predvajanj",
rate:"Ocena",
uimode:"Na\u010Din uporabni\u0161kega vmesnika",
flash_options:"Mo\u017Enosti Flash",
qt_options:"Mo\u017Enosti Quicktime",
wmp_options:"Mo\u017Enosti Windows media player",
rmp_options:"Mo\u017Enosti Real media player",
shockwave_options:"Mo\u017Enosti Shockwave",
autogotourl:"Samodejno na URL",
center:"Sredina",
imagestatus:"Slika stanja",
maintainaspect:"Zakleni razmerje",
nojava:"Brez Jave",
prefetch:"Vnaprej\u0161nje nalaganje",
shuffle:"Pome\u0161aj",
console:"Konzola",
numloop:"\u0160t. zank",
controls:"Nadzorni elementi",
scriptcallbacks:"Klicani skript",
swstretchstyle:"Slog raztegovanja",
swstretchhalign:"raztegni v-poravnano",
swstretchvalign:"raztegni n-poravnano",
sound:"Zvok",
progress:"Napredek",
qtsrc:"\"QT Src\"",
qt_stream_warn:"Opozorilo: \"Streamed rtsp resources should be added to the QT Src field under the advanced tab.\nYou should also add a non streamed version to the Src field..\"",
align_top:"vrh",
align_right:"desno",
align_bottom:"dno",
align_left:"levo",
align_center:"sredina",
align_top_left:"zgoraj levo",
align_top_right:"zgoraj desno",
align_bottom_left:"spodaj levo",
align_bottom_right:"spodaj desno",
flv_options:"Mo\u017Enosti videa Flash",
flv_scalemode:"Na\u010Din pove\u010Devanja",
flv_buffer:"Medpomnjenje",
flv_startimage:"Za\u010Detna slika",
flv_starttime:"Za\u010Detni \u010Das",
flv_defaultvolume:"Privzeta glasnost",
flv_hiddengui:"Skrit up. vmesnik",
flv_autostart:"Samodejni zagon",
flv_loop:"Zanka",
flv_showscalemodes:"Prika\u017Ei na\u010Dine pove\u010Dave",
flv_smoothvideo:"Meh\u010Daj video",
flv_jscallback:"Klicani JavaScript"
});