tinyMCE.addI18n('se.table_dlg',{
general_tab:"Generellt",
advanced_tab:"Avancerat",
general_props:"Generella inst\u00E4llningar",
advanced_props:"Avancerade inst\u00E4llningar",
rowtype:"Radtyp",
title:"Infoga/redigera ny tabell",
width:"Bredd",
height:"H\u00F6jd",
cols:"Kolumner",
rows:"Rader",
cellspacing:"Cellspacing",
cellpadding:"Cellpadding",
border:"Ram",
align:"Justering",
align_default:"Ingen",
align_left:"V\u00E4nster",
align_right:"H\u00F6ger",
align_middle:"Mitten",
row_title:"Tabellradsinst\u00E4llningar",
cell_title:"Tabellcellsinst\u00E4llningar",
cell_type:"Celltyp",
valign:"Vertikal justering",
align_top:"Toppen",
align_bottom:"Botten",
bordercolor:"Ramf\u00E4rg",
bgcolor:"Bakgrundsf\u00E4rg",
merge_cells_title:"Sammanfoga celler",
id:"Id",
style:"Stil",
langdir:"Skriftriktning",
langcode:"Spr\u00E5kkod",
ltr:"V\u00E4nster till h\u00F6ger",
rtl:"H\u00F6ger till v\u00E4nster",
bgimage:"Bakgrundsbild",
summary:"Sammanfattning",
td:"Data",
th:"Huvud",
cell_cell:"Uppdatera nuvarande cell",
cell_row:"Uppdatera alla celler i raden",
cell_all:"Uppdatera alla celler i tabellen",
row_row:"Uppdatera nuvarande rad",
row_odd:"Uppdatera udda rader i tabellen",
row_even:"Uppdatera j\u00E4mna rader i tabellen",
row_all:"Uppdatera alla rader i tabellen",
thead:"tabellhuvud",
tbody:"tabellkropp",
tfoot:"tabellfot",
scope:"Omfattning",
rowgroup:"Radgrupp",
colgroup:"Kolumngrupp",
col_limit:"Du kan inte ange fler \u00E4n {$cols} kolumner.",
row_limit:"Du kan inte ange fler \u00E4n {$rows} rader.",
cell_limit:"Du kan inte skapa en tabell med fler \u00E4n {$cells} celler.",
missing_scope:"\u00C4r du s\u00E4ker p\u00E5 att du vill forts\u00E4tta utan att ange en omfattning, denna underl\u00E4ttar f\u00F6r icke-grafiska webbl\u00E4sare.",
caption:"\u00D6verskrift",
frame:"Ram",
frame_none:"none",
frame_groups:"groups",
frame_rows:"rows",
frame_cols:"cols",
frame_all:"all",
rules:"Regler",
rules_void:"void",
rules_above:"above",
rules_below:"below",
rules_hsides:"hsides",
rules_lhs:"lhs",
rules_rhs:"rhs",
rules_vsides:"vsides",
rules_box:"box",
rules_border:"border"
});