tinyMCE.addI18n('ii.advanced_dlg',{
about_title:"\u5173\u4E8ETinyMCE",
about_general:"\u5173\u4E8E",
about_help:"\u8BF4\u660E",
about_license:"\u6388\u6743",
about_plugins:"\u5916\u6302\u7EC4\u4EF6",
about_plugin:"\u5916\u6302\u7EC4\u4EF6",
about_author:"\u4F5C\u8005",
about_version:"\u7248\u672C",
about_loaded:"\u5DF2\u52A0\u8F7D\u7684\u5916\u6302\u7EC4\u4EF6",
anchor_title:"\u63D2\u5165/\u7F16\u8F91 \u951A\u70B9",
anchor_name:"\u951A\u70B9\u540D\u79F0",
code_title:"HTML \u539F\u59CB\u7801\u7F16\u8F91\u5668",
code_wordwrap:"\u81EA\u52A8\u6362\u884C",
colorpicker_title:"\u9009\u62E9\u989C\u8272",
colorpicker_picker_tab:"\u9009\u8272\u5668",
colorpicker_picker_title:"\u9009\u8272\u5668",
colorpicker_palette_tab:"\u8272\u76D8",
colorpicker_palette_title:"\u8272\u76D8\u989C\u8272",
colorpicker_named_tab:"\u8272\u540D",
colorpicker_named_title:"\u989C\u8272\u540D\u79F0",
colorpicker_color:"\u989C\u8272\uFF1A",
colorpicker_name:"\u540D\u79F0\uFF1A",
charmap_title:"\u9009\u62E9\u81EA\u5B9A\u4E49\u5B57\u7B26\u7B26\u53F7",
image_title:"\u63D2\u5165/\u7F16\u8F91 \u56FE\u6863",
image_src:"\u56FE\u6863URL",
image_alt:"\u56FE\u6863\u8BF4\u660E",
image_list:"\u56FE\u6587\u4EF6\u6E05\u5355",
image_border:"\u8FB9\u6846",
image_dimensions:"\u5C3A\u5BF8",
image_vspace:"\u5782\u76F4\u95F4\u8DDD",
image_hspace:"\u6C34\u5E73\u95F4\u8DDD",
image_align:"\u5BF9\u9F50\u65B9\u5F0F",
image_align_baseline:"\u57FA\u7EBF",
image_align_top:"\u7F6E\u9876\u5BF9\u9F50",
image_align_middle:"\u7F6E\u4E2D",
image_align_bottom:"\u7F6E\u5E95\u5BF9\u9F50",
image_align_texttop:"\u6587\u5B57\u4E0A\u65B9",
image_align_textbottom:"\u6587\u5B57\u4E0B\u65B9",
image_align_left:"\u9760\u5DE6\u5BF9\u9F50",
image_align_right:"\u9760\u53F3\u5BF9\u9F50",
link_title:"\u63D2\u5165/\u7F16\u8F91 \u94FE\u63A5",
link_url:"\u94FE\u63A5URL",
link_target:"\u76EE\u6807",
link_target_same:"\u76EE\u524D\u7A97\u53E3\u5F00\u542F\u94FE\u63A5",
link_target_blank:"\u65B0\u7A97\u53E3\u5F00\u542F\u94FE\u63A5",
link_titlefield:"\u6807\u9898",
link_is_email:"\u4F60\u8F93\u5165\u7684URL\u4F3C\u4E4E\u662F\u4E00\u4E2Aemail\u5730\u5740\uFF0C\u662F\u5426\u8981\u52A0\u4E0A\u524D\u81F4\u8BCD mailto: ?",
link_is_external:"\u4F60\u8F93\u5165\u7684URL\u4F3C\u4E4E\u662F\u4E00\u4E2A\u5916\u90E8\u94FE\u63A5\uFF0C\u662F\u5426\u8981\u52A0\u4E0A\u524D\u81F4\u8BCD http:// ?",
link_list:"\u94FE\u63A5\u6E05\u5355"
});