tinyMCE.addI18n('fr.advanced_dlg',{
about_title:"\u00C0 propos de TinyMCE",
about_general:"\u00C0 propos",
about_help:"Aide",
about_license:"Licence",
about_plugins:"Plugins",
about_plugin:"Plugin",
about_author:"Auteur",
about_version:"Version",
about_loaded:"Plugins charg\u00E9s",
anchor_title:"Ins\u00E9rer/\u00C9diter une ancre",
anchor_name:"Nom de l'ancre",
code_title:"\u00C9diteur de la source HTML",
code_wordwrap:"Rupture de ligne",
colorpicker_title:"Choisir une couleur",
colorpicker_picker_tab:"Nuancier",
colorpicker_picker_title:"Nuancier",
colorpicker_palette_tab:"Palette",
colorpicker_palette_title:"Couleurs de la palette",
colorpicker_named_tab:"Noms",
colorpicker_named_title:"Couleurs nomm\u00E9es",
colorpicker_color:"Couleur:",
colorpicker_name:"Nom:",
charmap_title:"Choisir le caract\u00E8re \u00E0 ins\u00E9rer",
image_title:"Ins\u00E9rer/\u00C9diter une image",
image_src:"URL de l'image",
image_alt:"Description de l'image",
image_list:"Liste d'images",
image_border:"Bordure",
image_dimensions:"Dimensions",
image_vspace:"Espacement vertical",
image_hspace:"Espacement horizontal",
image_align:"Alignement",
image_align_baseline:"Base",
image_align_top:"Sommet",
image_align_middle:"Milieu",
image_align_bottom:"Bas",
image_align_texttop:"Haut du texte",
image_align_textbottom:"Bas du texte",
image_align_left:"Gauche",
image_align_right:"Droite",
link_title:"Ins\u00E9rer/\u00C9diter un lien",
link_url:"URL du lien",
link_target:"Cible",
link_target_same:"Ouvrir dans la m\u00EAme fen\u00EAtre",
link_target_blank:"Ouvrir dans une nouvelle fen\u00EAtre",
link_titlefield:"Titre",
link_is_email:"L'URL que vous avez entr\u00E9 semble \u00EAtre une adresse e-mail, voulez-vous ajouter le pr\u00E9fixe mailto:?",
link_is_external:"L'URL que vous avez saisi semble \u00EAtre une adresse web externe. Voulez-vous ajouter le pr\u00E9fixe http://?",
link_list:"Liste de liens"
});