tinyMCE.addI18n('sk.table_dlg',{
general_tab:"Hlavn\u00E9",
advanced_tab:"Roz\u0161\u00EDren\u00E9",
general_props:"Hlavn\u00E9 vlastnosti",
advanced_props:"Roz\u0161\u00EDren\u00E9 vlastnosti",
rowtype:"Row in table part",
title:"Vlo\u017Ei\u0165/Upravi\u0165 tabu\u013Eku",
width:"\u0160\u00EDrka",
height:"V\u00FD\u0161ka",
cols:"St\u013Apce",
rows:"Riadky",
cellspacing:"Cellspacing",
cellpadding:"Cellpadding",
border:"R\u00E1m\u010Dek",
align:"Poloha",
align_default:"Predvolene",
align_left:"V\u013Eavo",
align_right:"Vpravo",
align_middle:"Na stred",
row_title:"Vlastnosti riadkov tabu\u013Eky",
cell_title:"Vlastnosti buniek tabu\u013Eky",
cell_type:"Tyb bunky",
valign:"Vertik\u00E1lna poloha",
align_top:"Hore",
align_bottom:"Dolu",
bordercolor:"Farba or\u00E1movania",
bgcolor:"Farba pozadia",
merge_cells_title:"Zl\u00FA\u010Di\u0165 bunky tabu\u013Eky",
id:"ID",
style:"CSS \u0160t\u00FDl",
langdir:"Smer textu",
langcode:"K\u00F3d jazyka",
mime:"Cie\u013Eov\u00FD typ MIME",
ltr:"Z \u013Eava do prava",
rtl:"Z prava do \u013Eava",
bgimage:"Obr\u00E1zok pozadia",
summary:"Popis tabu\u013Eky",
td:"D\u00E1ta",
th:"Hlav\u010Dka",
cell_cell:"Aktualizova\u0165 aktu\u00E1lnu bunku",
cell_row:"Aktualizova\u0165 v\u0161etky bunky v riadku",
cell_all:"Aktualizova\u0165 v\u0161etky bunky v tebu\u013Eke",
row_row:"Aktualizova\u0165 aktu\u00E1lny riadok",
row_odd:"Aktualizova\u0165 odd rows in table",
row_even:"Aktualizova\u0165 nep\u00E1rne riadky v tabu\u013Eke",
row_all:"Aktualizova\u0165 v\u0161etky riadky v tabu\u013Eke",
thead:"Hlavi\u010Dka tabu\u013Eky",
tbody:"Telo tabu\u013Eky",
tfoot:"P\u00E4ta tabu\u013Eky",
scope:"Scope",
rowgroup:"Skupina riadkov",
colgroup:"Skupina st\u013Apcov",
col_limit:"Bol presiahnut\u00FD maxim\u00E1lny po\u010Det st\u013Apcov {$cols}.",
row_limit:"Bol presiahnut\u00FD maxim\u00E1lny po\u010Det riadkov {$rows}.",
cell_limit:"Bol presiahnut\u00FD maxim\u00E1lny po\u010Det buniek {$cells}.",
missing_scope:"Are you sure you want to continue without specifying a scope for this table header cell. Without it, it may be difficult for some users with disabilities to understand the content or data displayed of the table.",
caption:"Table caption",
frame:"R\u00E1m\u010Dek",
frame_none:"\u017Eiadne",
frame_groups:"groups",
frame_rows:"riadky",
frame_cols:"st\u013Apce",
frame_all:"v\u0161etky",
rules:"Pravidl\u00E1",
rules_void:"void",
rules_above:"above",
rules_below:"below",
rules_hsides:"hsides",
rules_lhs:"lhs",
rules_rhs:"rhs",
rules_vsides:"vsides",
rules_box:"box",
rules_border:"okraj"
});