tinyMCE.addI18n('ms.media_dlg',{
title:"Masukkan / sunting media",
general:"Am",
advanced:"Lanjutan",
file:"Fail/URL",
list:"Senarai",
size:"Dimensi",
preview:"Pratonton",
constrain_proportions:"Kadar tahanan",
type:"Jenis",
id:"Id",
name:"Nama",
class_name:"Kelas",
vspace:"Ruangan-Tegak",
hspace:"Ruangan-Datar",
play:"Auto main",
loop:"Gelung",
menu:"Tunjuk menu",
quality:"Kualiti",
scale:"Ukuran",
align:"Luruskan",
salign:"SLuruskan",
wmode:"WMod",
bgcolor:"Latar belakang",
base:"Dasar",
flashvars:"Flashvars",
liveconnect:"SWLiveConnect",
autohref:"AutoHREF",
cache:"Tempat menyembunyikan",
hidden:"Tersorok",
controller:"Kendali",
kioskmode:"Mode toko",
playeveryframe:"Main setiap bingkai",
targetcache:"Sasaran tersembunyi",
correction:"Tiada pembetulan",
enablejavascript:"Bolehkan JavaScript",
starttime:"Masa bermula",
endtime:"Masa tamat",
href:"Href",
qtsrcchokespeed:"Kelajuan sumbatan",
target:"Sasaran",
volume:"Ketinggian suara",
autostart:"Auto mula",
enabled:"Dibolehkan",
fullscreen:"Skrin penuh",
invokeurls:"Panggil URL",
mute:"Bisu",
stretchtofit:"Bujurkan supaya sesuai",
windowlessvideo:"Tetingkap tanpa video",
balance:"Baki",
baseurl:"URL dasar",
captioningid:"Tajuk id",
currentmarker:"Penanda semasa",
currentposition:"Posisi semasa",
defaultframe:"Bingkai asal",
playcount:"Kira",
rate:"Undi",
uimode:"Mod Grafik",
flash_options:"Flash",
qt_options:"Quicktime",
wmp_options:"Pemain Windows media",
rmp_options:"Pemain Real media",
shockwave_options:"Shockwave",
autogotourl:"Auto pergi-ke URL",
center:"Tengah",
imagestatus:"Status imej",
maintainaspect:"Pelihara aspek",
nojava:"Java tidak dibenarkan",
prefetch:"Preambilan",
shuffle:"Merangkak",
console:"Konsol",
numloop:"Nombor gelungan",
controls:"Kendali",
scriptcallbacks:"Panggilan balik skrip",
swstretchstyle:"Gaya bentangan",
swstretchhalign:"Bentangan Selarian-Ufuk",
swstretchvalign:"Stretch Selarian-Tegak",
sound:"Sound",
progress:"Progress",
qtsrc:"QT Src",
align_top:"Atas",
align_right:"Kanan",
align_bottom:"Bawah",
align_left:"Kiri",
align_center:"Tengah",
align_top_left:"Kiri atas",
align_top_right:"Kanan atas",
align_bottom_left:"Bawah kiri",
align_bottom_right:"Bawah kanan",
flv_options:"Alatan flash video",
flv_scalemode:"Skala mod",
flv_buffer:"Buffer",
flv_startimage:"Start imej",
flv_starttime:"Masa mula",
flv_defaultvolume:"Bunyi asal",
flv_hiddengui:"GUI tersorok",
flv_autostart:"Auto mula",
flv_loop:"Gegelung",
flv_showscalemodes:"Tunjuk skala mod",
flv_smoothvideo:"Perlahankan video",
flv_jscallback:"JS Callback"
});