tinyMCE.addI18n('es.advanced_dlg',{
about_title:"Acerca de TinyMCE",
about_general:"Acerca de ",
about_help:"Ayuda",
about_license:"Licencia",
about_plugins:"Complementos",
about_plugin:"Complemento",
about_author:"Autor",
about_version:"Versi\u00F3n",
about_loaded:"Complementos cargados",
anchor_title:"Insertar/editar ancla",
anchor_name:"Nombre del ancla",
code_title:"Editor del c\u00F3digo fuente HTML",
code_wordwrap:"Ajustar al margen",
colorpicker_title:"Seleccionar color",
colorpicker_picker_tab:"Selector",
colorpicker_picker_title:"Paleta de color",
colorpicker_palette_tab:"Paleta",
colorpicker_palette_title:"Paleta de colores",
colorpicker_named_tab:"Nombrados",
colorpicker_named_title:"Colores nombrados",
colorpicker_color:"Color:",
colorpicker_name:"Nombre:",
charmap_title:"Seleccionar caracter personalizado",
image_title:"Insertar/editar imagen",
image_src:"URL de la Imagen",
image_alt:"Descripci\u00F3n de la Imagen",
image_list:"Lista de la Imagen",
image_border:"Borde",
image_dimensions:"Dimensi\u00F3n",
image_vspace:"Espacio vertical",
image_hspace:"Espacio horizontal",
image_align:"Alineaci\u00F3n",
image_align_baseline:"L\u00EDnea base",
image_align_top:"Arriba",
image_align_middle:"Medio",
image_align_bottom:"Debajo",
image_align_texttop:"Texto arriba",
image_align_textbottom:"Texto debajo",
image_align_left:"Izquierda",
image_align_right:"Derecha",
link_title:"Insertar/editar hiperv\u00EDnculo",
link_url:"URL del hiperv\u00EDnculo",
link_target:"Destino",
link_target_same:"Abrir v\u00EDnculo en la misma ventana",
link_target_blank:"Abrir v\u00EDnculo en una ventana nueva",
link_titlefield:"T\u00EDtulo",
link_is_email:"La URL que introdujo parece ser una direcci\u00F3n de email,  \u00BFdesea agregar el prefijo mailto: necesario?",
link_is_external:"La URL que introdujo parece ser un v\u00EDnculo externo,  \u00BFdesea agregar el prefijo http:// necesario?",
link_list:"Lista de hiperv\u00EDnculos"
});