tinyMCE.addI18n('ml.advanced_dlg',{
about_title:"About TinyMCE",
about_general:"About",
about_help:"\u0D38\u0D39\u0D3E\u0D2F\u0D02",
about_license:"License",
about_plugins:"Plugins",
about_plugin:"Plugin",
about_author:"Author",
about_version:"\u0D2A\u0D24\u0D3F\u0D2A\u0D4D\u0D2A\u0D41\u0D4D",
about_loaded:"Loaded plugins",
anchor_title:"Insert/edit anchor",
anchor_name:"\u0D28\u0D19\u0D4D\u0D15\u0D42\u0D30 \u0D2A\u0D47\u0D30\u0D41\u0D4D",
code_title:"HTML Source Editor",
code_wordwrap:"Word wrap",
colorpicker_title:"\u0D28\u0D3F\u0D31\u0D02 \u0D24\u0D3F\u0D30\u0D1E\u0D4D\u0D1E\u0D46\u0D1F\u0D41\u0D15\u0D4D\u0D15\u0D41\u0D15",
colorpicker_picker_tab:"Picker",
colorpicker_picker_title:"Color picker",
colorpicker_palette_tab:"Palette",
colorpicker_palette_title:"Palette colors",
colorpicker_named_tab:"\u0D2A\u0D47\u0D30\u0D3F\u0D1F\u0D4D\u0D1F",
colorpicker_named_title:"\u0D2A\u0D47\u0D30\u0D3F\u0D1F\u0D4D\u0D1F \u0D28\u0D3F\u0D31\u0D19\u0D4D\u0D19\u0D33\u0D4D\u200D",
colorpicker_color:"\u0D28\u0D3F\u0D31\u0D02:",
colorpicker_name:"\u0D2A\u0D47\u0D30\u0D41\u0D4D:",
charmap_title:"Select custom character",
image_title:"Insert/edit image",
image_src:"Image URL",
image_alt:"Image description",
image_list:"Image list",
image_border:"\u0D05\u0D24\u0D3F\u0D30\u0D41\u0D4D",
image_dimensions:"\u0D05\u0D33\u0D35\u0D41\u0D15\u0D33\u0D4D\u200D",
image_vspace:"\u0D32\u0D02\u0D2C \u0D38\u0D4D\u0D25\u0D32\u0D02",
image_hspace:"\u0D24\u0D3F\u0D30\u0D36\u0D4D\u0D1A\u0D40\u0D28 \u0D38\u0D4D\u0D25\u0D32\u0D02",
image_align:"Alignment",
image_align_baseline:"Baseline",
image_align_top:"Top",
image_align_middle:"\u0D28\u0D1F\u0D41\u0D35\u0D3F\u0D32\u0D4D\u200D",
image_align_bottom:"Bottom",
image_align_texttop:"Text top",
image_align_textbottom:"Text bottom",
image_align_left:"Left",
image_align_right:"Right",
link_title:"Insert/edit link",
link_url:"\u0D2C\u0D3E\u0D28\u0D4D\u0D27\u0D35 \u0D35\u0D3F\u0D32\u0D3E\u0D38\u0D02",
link_target:"Target",
link_target_same:"Open link in the same window",
link_target_blank:"Open link in a new window",
link_titlefield:"Title",
link_is_email:"The URL you entered seems to be an email address, do you want to add the required mailto: prefix?",
link_is_external:"The URL you entered seems to external link, do you want to add the required http:// prefix?",
link_list:"Link list"
});