tinyMCE.addI18n('cs.table_dlg',{
general_tab:"Hlavn\u00ED",
advanced_tab:"Pokro\u010Dil\u00E9",
general_props:"Hlavn\u00ED nastaven\u00ED",
advanced_props:"Pokro\u010Dil\u00E9 nastaven\u00ED",
rowtype:"Typ \u0159\u00E1dku",
title:"Vlo\u017Eit/upravit tabulku",
width:"\u0160\u00ED\u0159ka",
height:"V\u00FD\u0161ka",
cols:"Sloupce",
rows:"\u0158\u00E1dky",
cellspacing:"Rozestup bun\u011Bk",
cellpadding:"Odsazen\u00ED obsahu",
border:"R\u00E1me\u010Dek",
align:"Zarovn\u00E1n\u00ED",
align_default:"V\u00FDchoz\u00ED",
align_left:"Vlevo",
align_right:"Vpravo",
align_middle:"Doprost\u0159ed",
row_title:"Vlastnosti \u0159\u00E1dku",
cell_title:"Vlastnosti bu\u0148ky",
cell_type:"Typ bu\u0148ky",
valign:"Vertik\u00E1ln\u00ED zarovn\u00E1n\u00ED",
align_top:"Nahoru",
align_bottom:"Dol\u016F",
bordercolor:"Barva r\u00E1me\u010Dku",
bgcolor:"Barva pozad\u00ED",
merge_cells_title:"Spojit bu\u0148ky",
id:"ID",
style:"Styl",
langdir:"Sm\u011Br textu",
langcode:"K\u00F3d jazyka",
mime:"MIME typ c\u00EDle",
ltr:"Zleva doprava",
rtl:"Zprava doleva",
bgimage:"Obr\u00E1zek pozad\u00ED",
summary:"Sum\u00E1\u0159",
td:"Data",
th:"Z\u00E1hlav\u00ED",
cell_cell:"Aktualizovat zvolenou bu\u0148ku",
cell_row:"Aktualizovat v\u0161echny bu\u0148ky v \u0159\u00E1dku",
cell_all:"Aktualizovat v\u0161echny bu\u0148ky v tabulce",
row_row:"Aktualizovat zvolen\u00FD \u0159\u00E1dek",
row_odd:"Aktualizovat lich\u00E9 \u0159\u00E1dky tabulky",
row_even:"Aktualizovat sud\u00E9 \u0159\u00E1dky tabulky",
row_all:"Aktualizovat v\u0161echny \u0159\u00E1dky tabulky",
thead:"Hlavi\u010Dka tabulky",
tbody:"T\u011Blo tabulky",
tfoot:"Pata tabulky",
scope:"Zv\u00FDrazn\u011Bn\u00ED",
rowgroup:"Skupina \u0159\u00E1dk\u016F",
colgroup:"Skupina sloupc\u016F",
col_limit:"P\u0159ekro\u010Dili jste maxim\u00E1ln\u00ED po\u010Det sloupc\u016F {$cols}.",
row_limit:"P\u0159ekro\u010Dili jste maxim\u00E1ln\u00ED po\u010Det \u0159\u00E1dk\u016F {$rows}.",
cell_limit:"P\u0159ekro\u010Dili jste maxim\u00E1ln\u00ED po\u010Det bun\u011Bk {$cells}.",
missing_scope:"Jste si jist\u00ED, \u017Ee nechcete definovat zv\u00FDrazn\u011Bn\u00ED pro tuto hlavi\u010Dkovou bu\u0148ku (hlavi\u010Dku \u0159\u00E1dku nebo sloupce)? Bez n\u011Bj mo\u017En\u00E1 nebude mo\u017En\u00E9 spr\u00E1vn\u011B pochopit zobrazen\u00FD obsah \u010Di data tabulky.",
caption:"Nadpis tabulky",
frame:"R\u00E1m (frame)",
frame_none:"\u017E\u00E1dn\u00FD",
frame_groups:"skupiny",
frame_rows:"\u0159\u00E1dky",
frame_cols:"sloupce",
frame_all:"v\u0161e",
rules:"Pravidla (rules)",
rules_void:"void",
rules_above:"nad",
rules_below:"pod",
rules_hsides:"hsides",
rules_lhs:"lhs",
rules_rhs:"rhs",
rules_vsides:"vsides",
rules_box:"box",
rules_border:"r\u00E1me\u010Dek"
});