tinyMCE.addI18n('hu.table_dlg',{
general_tab:"\u00C1ltal\u00E1nos",
advanced_tab:"Halad\u00F3",
general_props:"\u00C1ltal\u00E1nos tulajdons\u00E1gok",
advanced_props:"Halad\u00F3 tulajdons\u00E1gok",
rowtype:"Sor a t\u00E1bl\u00E1ban",
title:"T\u00E1bl\u00E1zat besz\u00FAr\u00E1sa/szerkeszt\u00E9se",
width:"Sz\u00E9less\u00E9g",
height:"Magass\u00E1g",
cols:"Oszlopok",
rows:"Sorok",
cellspacing:"Cellak\u00F6z",
cellpadding:"Cella bels\u0151k\u00F6z",
border:"Keret",
align:"Igaz\u00EDt\u00E1s",
align_default:"Alap\u00E9rtelmezett",
align_left:"Balra",
align_right:"Jobbra",
align_middle:"K\u00F6z\u00E9pre",
row_title:"Sor tulajdons\u00E1gai",
cell_title:"Cella tulajdons\u00E1gai",
cell_type:"Cellat\u00EDpus",
valign:"F\u00FCgg\u0151leges igaz\u00EDt\u00E1s",
align_top:"Fel",
align_bottom:"Le",
bordercolor:"Keretsz\u00EDn",
bgcolor:"H\u00E1tt\u00E9rsz\u00EDn",
merge_cells_title:"Cell\u00E1k \u00F6sszevon\u00E1sa",
id:"Id",
style:"St\u00EDlus",
langdir:"\u00CDr\u00E1s ir\u00E1ny",
langcode:"Nyelvk\u00F3d",
mime:"C\u00E9l MIME t\u00EDpus",
ltr:"Balr\u00F3l jobbra",
rtl:"Jobbr\u00F3l balra",
bgimage:"H\u00E1tt\u00E9rk\u00E9p",
summary:"\u00D6sszegz\u00E9s",
td:"Adat",
th:"Fejl\u00E9c",
cell_cell:"Cella friss\u00EDt\u00E9se",
cell_row:"Sor \u00F6sszes cell\u00E1j\u00E1nak friss\u00EDt\u00E9se",
cell_all:"T\u00E1bl\u00E1zat \u00F6sszes cell\u00E1j\u00E1nak friss\u00EDt\u00E9se",
row_row:"Sor friss\u00EDt\u00E9se",
row_odd:"P\u00E1ratlan sorok friss\u00EDt\u00E9se",
row_even:"P\u00E1ros sorok friss\u00EDt\u00E9se",
row_all:"Minden sor friss\u00EDt\u00E9se",
thead:"T\u00E1bl\u00E1zat fej",
tbody:"T\u00E1bl\u00E1zat test",
tfoot:"T\u00E1bl\u00E1zat l\u00E1b",
scope:"Hat\u00F3k\u00F6r",
rowgroup:"Sor csoport",
colgroup:"Oszlop csoport",
col_limit:"T\u00FAll\u00E9pte a maxim\u00E1lis oszlopsz\u00E1mot, ami {$cols}.",
row_limit:"T\u00FAll\u00E9pte a maxim\u00E1lis sorsz\u00E1mot, ami {$rows}.",
cell_limit:"T\u00FAll\u00E9pte a maxim\u00E1lis cellasz\u00E1mot, ami {$cells}.",
missing_scope:"Biztosan folytatni akarja an\u00E9lk\u00FCl, hogy hat\u00F3k\u00F6rt adna ennek a fejl\u00E9ccell\u00E1nak? Korl\u00E1toz\u00E1sokkal \u00E9l\u0151k sz\u00E1m\u00E1ra neh\u00E9z lesz meg\u00E9rteni a t\u00E1bl\u00E1zat tartalm\u00E1t.",
caption:"C\u00EDmsor",
frame:"Keret",
frame_none:"nincs",
frame_groups:"csoportok",
frame_rows:"sorok",
frame_cols:"oszlopok",
frame_all:"mind",
rules:"Vonalak",
rules_void:"sehol",
rules_above:"f\u00F6l\u00F6tte",
rules_below:"alatta",
rules_hsides:"v. oldalak",
rules_lhs:"lhs",
rules_rhs:"rhs",
rules_vsides:"f. oldalak",
rules_box:"doboz",
rules_border:"keret"
});