tinyMCE.addI18n('nn.table_dlg',{
general_tab:"Generelt",
advanced_tab:"Avansert",
general_props:"Generelt",
advanced_props:"Generelle eigenskapar",
rowtype:"Rad i tabell",
title:"Set inn / rediger tabell",
width:"Breidd",
height:"H\u00F8gd",
cols:"Kolonner",
rows:"Rader",
cellspacing:"Celleavstand",
cellpadding:"Cellefylling",
border:"Ramme",
align:"Justering",
align_default:"Standard",
align_left:"Venstre",
align_right:"H\u00F8gre",
align_middle:"Midtstilt",
row_title:"Radeigenskapar",
cell_title:"Celleeigenskapar",
cell_type:"Celletype",
valign:"Vertikal justering",
align_top:"Topp",
align_bottom:"Botn",
bordercolor:"Rammefarge",
bgcolor:"Bakgrunn",
merge_cells_title:"Sl\u00E5 saman celler",
id:"Id",
style:"Stil",
langdir:"Skriftretning",
langcode:"Spr\u00E5kkode",
mime:"M\u00E5let sin MIME-type",
ltr:"Venstre mot h\u00F8gre",
rtl:"H\u00F8gre mot venstre",
bgimage:"Bakgrunnsbilete",
summary:"Samandrag",
td:"Data",
th:"Overskrift",
cell_cell:"Oppdater aktuell celle",
cell_row:"Oppdater alle celler i rada",
cell_all:"Oppdater alle celler i tabellen",
row_row:"Oppdater aktuell rad",
row_odd:"Oppdater oddetallrader",
row_even:"Oppdater partallrader",
row_all:"Oppdater alle rader",
thead:"Tabellhovud",
tbody:"Tabellkropp",
tfoot:"Tabellfot",
scope:"Omr\u00E5de",
rowgroup:"Radgruppe",
colgroup:"Kolonnegruppe",
col_limit:"Du har fleire enn maksimalt tal kolonner p\u00E5 {$cols}.",
row_limit:"Du har fleire enn maksimalt tal rader p\u00E5 {$rows}.",
cell_limit:"Du har fleire enn maksimalt tal celler p\u00E5 {$cells}.",
missing_scope:"Er du sikker p\u00E5 at du vil fortsetje utan \u00E5 angi eit omr\u00E5de for denne overskrifscella? Utan dette kan det bli vanskeleg for enkelte funksjonshemma brukarar \u00E5 forst\u00E5 innhaldet eller dataane som blir presenterte i tabellen.",
caption:"Tabelloverskrift",
frame:"Ramme",
frame_none:"ingen",
frame_groups:"grupper",
frame_rows:"rader",
frame_cols:"kolonnar",
frame_all:"alle",
rules:"Strekar",
rules_void:"ingen",
rules_above:"over",
rules_below:"under",
rules_hsides:"hsides",
rules_lhs:"lhs",
rules_rhs:"rhs",
rules_vsides:"vsides",
rules_box:"boks",
rules_border:"ramme"
});