tinyMCE.addI18n('es.emotions_dlg',{
title:"Insertar emoticon",
desc:"Emoticones",
cool:"Todo bien",
cry:"Llora",
embarassed:"Verg\u00FCenza",
foot_in_mouth:"Pie en la boca",
frown:"Triste",
innocent:"Inocente",
kiss:"Beso",
laughing:"Risa",
money_mouth:"Dinero boca",
sealed:"Sellado",
smile:"Sonrisa",
surprised:"Sorprendido",
tongue_out:"Lengua fuera",
undecided:"Indeciso",
wink:"Gui\u00F1o",
yell:"Enfadado"
});