tinyMCE.addI18n({tr:{
common:{
edit_confirm:"Bu metin b\u00F6lgesi i\u00E7in WYSIWYG modunu kullanmak istiyor musunuz?",
apply:"Uygula",
insert:"Ekle",
update:"G\u00FCncelle",
cancel:"\u0130ptal",
close:"Kapat",
browse:"G\u00F6zat",
class_name:"S\u0131n\u0131f",
not_set:"-- se\u00E7iniz --",
clipboard_msg:"Kopyala/Kes/Yap\u0131\u015Ft\u0131r Mozilla ve Firefox'ta kullan\u0131lamaz.\nBu konuda daha fazla bilgi edinmek ister misiniz?",
clipboard_no_support:"\u015Eimdilik taray\u0131c\u0131n\u0131z taraf\u0131ndan desteklenmemektedir, bunun yerine k\u0131sayol tu\u015Flar\u0131n\u0131 kullan\u0131n\u0131z.",
popup_blocked:"\u00DCzg\u00FCn\u00FCz, fakat popup-engelleyiciniz uygulama i\u00E7in gerekli bir pencerenin a\u00E7\u0131lmas\u0131na izin vermedi. Bu arac\u0131 tam olarak kullanabilmek i\u00E7in popup engelleyicinizi kapatman\u0131z gerekebilir.",
invalid_data:"Hata: Ge\u00E7ersiz de\u011Ferler girildi, bunlar k\u0131rm\u0131z\u0131yla i\u015Faretlendi.",
more_colors:"Daha fazla renk"
},
contextmenu:{
align:"Hizalama",
left:"Sola",
center:"Ortala",
right:"Sa\u011Fa",
full:"\u0130ki yana"
},
insertdatetime:{
date_fmt:"%d-%m-%Y",
time_fmt:"%H:%M:%S",
insertdate_desc:"Tarih ekle",
inserttime_desc:"Zaman ekle",
months_long:"Ocak,\u015Eubat,Mart,Nisan,May\u0131s,Haziran,Temmuz,A\u011Fustos,Eyl\u00FCl,Ekim,Kas\u0131m,Aral\u0131k",
months_short:"Oca,\u015Eub,Mar,Nis,May,Haz,Tem,A\u011Fu,Eyl,Eki,Kas,Ara",
day_long:"Pazar,Pazartesi,Sal\u0131,\u00C7ar\u015Famba,Per\u015Fembe,Cuma,Cumartesi,Pazar",
day_short:"Paz,Pzt,Sal,\u00C7r\u015F,Per,Cum,Cts,Paz"
},
print:{
print_desc:"Yazd\u0131r"
},
preview:{
preview_desc:"\u00D6nizleme"
},
directionality:{
ltr_desc:"Sa\u011Fdan sola y\u00F6nelimli",
rtl_desc:"Soldan sa\u011Fa y\u00F6nelimli"
},
layer:{
insertlayer_desc:"Yeni katman ekle",
forward_desc:"\u00D6ne al",
backward_desc:"Arkaya al",
absolute_desc:"Mutlak konumland\u0131rmay\u0131 a\u00E7/kapa",
content:"Yeni katman..."
},
save:{
save_desc:"Kaydet",
cancel_desc:"T\u00FCm de\u011Fi\u015Fiklikleri iptal et"
},
nonbreaking:{
nonbreaking_desc:"K\u0131r\u0131l\u0131ms\u0131z bo\u015Fluk karakteri ekle"
},
iespell:{
iespell_desc:"\u0130mla kontrol\u00FCn\u00FC \u00E7al\u0131\u015Ft\u0131r",
download:"ieSpell bulunamad\u0131. \u015Eimdi kurmak ister misiniz?"
},
advhr:{
advhr_desc:"Yatay \u00E7izgi"
},
emotions:{
emotions_desc:"\u0130fadeler"
},
searchreplace:{
search_desc:"Bul",
replace_desc:"Bul/De\u011Fi\u015Ftir"
},
advimage:{
image_desc:"Resim ekle/d\u00FCzenle"
},
advlink:{
link_desc:"Ba\u011Flant\u0131 ekle/d\u00FCzenle"
},
xhtmlxtras:{
cite_desc:"Kaynak",
abbr_desc:"K\u0131saltma",
acronym_desc:"K\u0131sa ad",
del_desc:"Silme",
ins_desc:"Ekleme",
attribs_desc:"Nitelik ekle/d\u00FCzenle"
},
style:{
desc:"CSS Stili D\u00FCzenle"
},
paste:{
paste_text_desc:"Sade Metin olarak yap\u0131\u015Ft\u0131r",
paste_word_desc:"Word'den yap\u0131\u015Ft\u0131r",
selectall_desc:"T\u00FCm\u00FCn\u00FC Se\u00E7"
},
paste_dlg:{
text_title:"Pencereye metin yap\u0131\u015Ft\u0131rmak i\u00E7in CTRL+V tu\u015Funu kullan\u0131n\u0131z.",
text_linebreaks:"Sat\u0131r k\u0131r\u0131l\u0131mlar\u0131n\u0131 koru",
word_title:"Pencereye metin yap\u0131\u015Ft\u0131rmak i\u00E7in CTRL+V tu\u015Funu kullan\u0131n\u0131z."
},
table:{
desc:"Yeni bir tablo ekler",
row_before_desc:"\u00DCst\u00FCne bir sat\u0131r ekle",
row_after_desc:"Alt\u0131na bir sat\u0131r ekle",
delete_row_desc:"Sat\u0131r\u0131 sil",
col_before_desc:"Soluna bir kolon ekle",
col_after_desc:"Sa\u011F\u0131na bir kolon ekle",
delete_col_desc:"Kolonu sil",
split_cells_desc:"Birle\u015Fitirilmi\u015F tablo h\u00FCcrelerini ay\u0131r",
merge_cells_desc:"Tablo h\u00FCcrelerini birle\u015Ftir",
row_desc:"Tablo sat\u0131r \u00F6zellikleri",
cell_desc:"Tablo h\u00FCcre \u00F6zellikler",
props_desc:"Tablo \u00F6zellikleri",
paste_row_before_desc:"\u00DCst\u00FCne tablo sat\u0131r\u0131n\u0131 yap\u0131\u015Ft\u0131r",
paste_row_after_desc:"Alt\u0131na tablo sat\u0131r\u0131n\u0131 yap\u0131\u015Ft\u0131r",
cut_row_desc:"Tablo sat\u0131r\u0131n\u0131 kes",
copy_row_desc:"Tablo sat\u0131r\u0131n\u0131 kopyala",
del:"Tabloyu sil",
row:"Sat\u0131r",
col:"Kolon",
cell:"H\u00FCcre"
},
autosave:{
unload_msg:"Bu sayfadan \u00E7\u0131karsan\u0131z yapt\u0131\u011F\u0131n\u0131z de\u011Fi\u015Fiklikler kaybedilecek."
},
fullscreen:{
desc:"Tam ekran modunu a\u00E7/kapa"
},
media:{
desc:"T\u00FCmle\u015Fik medya ekle/d\u00FCzenle",
edit:"T\u00FCmle\u015Fik medya d\u00FCzenle"
},
fullpage:{
desc:"Belge \u00F6zellikleri"
},
template:{
desc:"\u00D6ntan\u0131ml\u0131 \u015Fablon i\u00E7eri\u011Fi ekle"
},
visualchars:{
desc:"G\u00F6rsel kontrol karakterleri a\u00E7\u0131k/kapal\u0131."
},
spellchecker:{
desc:"\u0130mla kontrol\u00FCn\u00FC a\u00E7/kapa",
menu:"\u0130mla kontrol ayarlar\u0131",
ignore_word:"S\u00F6zc\u00FC\u011F\u00FC \u00F6nemseme",
ignore_words:"Hi\u00E7birini \u00F6nemseme",
langs:"Diller",
wait:"L\u00FCtfen bekleyiniz...",
sug:"\u00D6neriler",
no_sug:"\u00D6neri yok",
no_mpell:"Bir imla hatas\u0131 bulunamad\u0131."
},
pagebreak:{
desc:"Sayfa k\u0131r\u0131l\u0131m\u0131 ekle."
}}});