tinyMCE.addI18n('cs.advanced_dlg',{
about_title:"O TinyMCE",
about_general:"O n\u00E1s",
about_help:"N\u00E1pov\u011Bda",
about_license:"Licence",
about_plugins:"Pluginy",
about_plugin:"Plugin",
about_author:"Autor",
about_version:"Verze",
about_loaded:"Na\u010Dten\u00E9 pluginy",
anchor_title:"Vlo\u017Eit/upravit kotvu",
anchor_name:"N\u00E1zev kotvy",
code_title:"HTML",
code_wordwrap:"Zalomen\u00ED \u0159\u00E1dk\u016F",
colorpicker_title:"V\u00FDb\u011Br barvy",
colorpicker_picker_tab:"Kap\u00E1tko",
colorpicker_picker_title:"Kap\u00E1tko",
colorpicker_palette_tab:"Paleta",
colorpicker_palette_title:"Paleta barev",
colorpicker_named_tab:"N\u00E1zvy",
colorpicker_named_title:"Pojmenovan\u00E9 barvy",
colorpicker_color:"Vybran\u00E1 barva:",
colorpicker_name:"N\u00E1zev:",
charmap_title:"Vlo\u017Eit speci\u00E1ln\u00ED znak",
image_title:"Vlo\u017Eit/upravit obr\u00E1zek",
image_src:"URL obr\u00E1zku",
image_alt:"Popis obr\u00E1zku",
image_list:"Seznam obr\u00E1zk\u016F",
image_border:"R\u00E1me\u010Dek",
image_dimensions:"Rozm\u011Bry",
image_vspace:"Vertik\u00E1ln\u00ED mezera",
image_hspace:"Horizont\u00E1ln\u00ED mezera",
image_align:"Zarovn\u00E1n\u00ED",
image_align_baseline:"Na z\u00E1kladnu",
image_align_top:"Nahoru",
image_align_middle:"Na st\u0159ed \u0159\u00E1dku",
image_align_bottom:"Dol\u016F",
image_align_texttop:"S vrchem \u0159\u00E1dku",
image_align_textbottom:"Se spodkem \u0159\u00E1dku",
image_align_left:"Vlevo",
image_align_right:"Vpravo",
link_title:"Vlo\u017Eit/upravit odkaz",
link_url:"URL odkazu",
link_target:"C\u00EDl",
link_target_same:"Otev\u0159\u00EDt odkaz ve stejn\u00E9m okn\u011B",
link_target_blank:"Otev\u0159\u00EDt odkaz v nov\u00E9m okn\u011B",
link_titlefield:"Titulek",
link_is_email:"Zadan\u00E9 URL vypad\u00E1 jako e-mailov\u00E1 adresa, chcete doplnit prefix mailto:?",
link_is_external:"Zadan\u00E9 URL vypad\u00E1 jako extern\u00ED odkaz, chcete doplnit prefix http://?",
link_list:"Seznam odkaz\u016F"
});