tinyMCE.addI18n('cy.xhtmlxtras_dlg',{
attribute_label_title:"Teitl",
attribute_label_id:"ID",
attribute_label_class:"Dosbarth",
attribute_label_style:"Arddull",
attribute_label_cite:"Dyfynnu",
attribute_label_datetime:"Dyddiad/Amser",
attribute_label_langdir:"Cyfeiriad Testun",
attribute_option_ltr:"Chwith i'r dde",
attribute_option_rtl:"De i'r chwith",
attribute_label_langcode:"Iaith",
attribute_label_tabindex:"Trefn tabio",
attribute_label_accesskey:"Bysell mynediad",
attribute_events_tab:"Digwyddiadau",
attribute_attrib_tab:"Priodoleddau",
general_tab:"Cyffredinol",
attrib_tab:"Priodoleddau",
events_tab:"Digwyddiadau",
fieldset_general_tab:"Gosodiadau Cyfredinol",
fieldset_attrib_tab:"Priodoleddau Elfen",
fieldset_events_tab:"Digwyddiadau Elfen",
title_ins_element:"Elfen Mewnosodiad",
title_del_element:"Elfen Dilead",
title_acronym_element:"Elfen Acronym",
title_abbr_element:"Elfen Talfyriad",
title_cite_element:"Elfen Dyfyniad",
remove:"Tynnu",
insert_date:"Mewnosod dyddiad/amser presennol",
option_ltr:"Chwith i'r dde",
option_rtl:"De i'r chwith",
attribs_title:"Mewnosod/Golygu Priodoleddau"
});