tinyMCE.addI18n('hu.advanced_dlg',{
about_title:"A TinyMCE-r\u0151l",
about_general:"R\u00F3lunk",
about_help:"Seg\u00EDts\u00E9g",
about_license:"Licensz",
about_plugins:"Pluginok",
about_plugin:"Plugin",
about_author:"Szerz\u0151",
about_version:"Verzi\u00F3",
about_loaded:"Bet\u00F6lt\u00F6tt pluginok",
anchor_title:"Horgony besz\u00FAr\u00E1sa/szerkeszt\u00E9se",
anchor_name:"Horgonyn\u00E9v",
code_title:"HTML forr\u00E1s szerkeszt\u00E9se",
code_wordwrap:"Sz\u00F6veg t\u00F6rdel\u00E9se",
colorpicker_title:"Sz\u00EDnv\u00E1laszt\u00E1s",
colorpicker_picker_tab:"V\u00E1laszt\u00F3",
colorpicker_picker_title:"Sz\u00EDnv\u00E1laszt\u00F3",
colorpicker_palette_tab:"Paletta",
colorpicker_palette_title:"Paletta sz\u00EDnek",
colorpicker_named_tab:"Elnevezettek",
colorpicker_named_title:"Elnevezett sz\u00EDnek",
colorpicker_color:"Sz\u00EDn:",
colorpicker_name:"N\u00E9v:",
charmap_title:"Egyedi karakter v\u00E1laszt\u00E1sa",
image_title:"K\u00E9p besz\u00FAr\u00E1sa/szerkeszt\u00E9se",
image_src:"K\u00E9p URL",
image_alt:"K\u00E9p le\u00EDr\u00E1s",
image_list:"K\u00E9p lista",
image_border:"Keret",
image_dimensions:"Dimenzi\u00F3k",
image_vspace:"F\u00FCgg\u0151leges t\u00E1v",
image_hspace:"V\u00EDzszintes t\u00E1v",
image_align:"Igaz\u00EDt\u00E1s",
image_align_baseline:"Alapvonalhoz",
image_align_top:"Fentre",
image_align_middle:"K\u00F6z\u00E9pre",
image_align_bottom:"Lentre",
image_align_texttop:"Sz\u00F6veg tetej\u00E9hez",
image_align_textbottom:"Sz\u00F6veg alj\u00E1hoz",
image_align_left:"Balra",
image_align_right:"Jobbra",
link_title:"Link besz\u00FAr\u00E1sa/szerkeszt\u00E9se",
link_url:"Link URL",
link_target:"Target",
link_target_same:"Link azonos ablakba nyit\u00E1sa",
link_target_blank:"Link \u00FAj ablakba nyit\u00E1sa",
link_titlefield:"C\u00EDm",
link_is_email:"A be\u00EDrt URL e-mail c\u00EDmnek t\u0171nik, k\u00EDv\u00E1nja a sz\u00FCks\u00E9ges mailto:-t el\u00E9 tenni?",
link_is_external:"A be\u00EDrt URL k\u00FCls\u0151 hivatkoz\u00E1snak t\u0171nik, k\u00EDv\u00E1nja a sz\u00FCks\u00E9ges http://-t el\u00E9 tenni?",
link_list:"Link lista"
});