tinyMCE.addI18n('sk.advanced',{
style_select:"- \u0160t\u00FDly -",
font_size:"- Ve\u013Ekos\u0165 p\u00EDsma  -",
fontdefault:"- Typ p\u00EDsma -",
block:"- Form\u00E1t -",
paragraph:"Odstavec [p]",
div:"Div",
address:"Adresa [address]",
pre:"Predform\u00E1t [pre]",
h1:"Nadpis 1 [h1]",
h2:"Nadpis 2 [h2]",
h3:"Nadpis 3 [h3]",
h4:"Nadpis 4 [h4]",
h5:"Nadpis 5 [h5]",
h6:"Nadpis 6 [h6]",
blockquote:"Odsadenie",
code:"K\u00F3d",
samp:"Uk\u00E1\u017Eka k\u00F3du",
dt:"Defin\u00EDcia podmienky",
dd:"Defin\u00EDcia popisu",
bold_desc:"Tu\u010Dn\u00FD text (Ctrl+B)",
italic_desc:"\u0160ikm\u00FD text (kurziv\u00E1) (Ctrl+I)",
underline_desc:"Pod\u010Diarknut\u00FD text (Ctrl+U)",
striketrough_desc:"Pre\u0161krtnut\u00FD text",
justifyleft_desc:"Zarovna\u0165 v\u013Eavo",
justifycenter_desc:"Zarovna\u0165 na stred",
justifyright_desc:"Zarovna\u0165 vpravo",
justifyfull_desc:"Zarovna\u0165 do bloku",
bullist_desc:"Zoznam s odr\u00E1\u017Ekami",
numlist_desc:"\u010C\u00EDslovan\u00FD zoznam",
outdent_desc:"Zmen\u0161i\u0165 odsadenie",
indent_desc:"Zv\u00E4\u010D\u0161i\u0165 odsadenie",
undo_desc:"Sp\u00E4\u0165 (Ctrl+Z)",
redo_desc:"Znovu (Ctrl+Y)",
link_desc:"Vlo\u017Ei\u0165/upravi\u0165 odkaz",
unlink_desc:"Zru\u0161i\u0165 odkaz",
image_desc:"Vlo\u017Ei\u0165/upravi\u0165 obr\u00E1zok",
cleanup_desc:"Vy\u010Disti\u0165 neusporiadan\u00FD k\u00F3d",
code_desc:"Zobrazi\u0165 HTML zdroj",
sub_desc:"Doln\u00FD index",
sup_desc:"Horn\u00FD index",
hr_desc:"Vlo\u017Ei\u0165 vodorovn\u00FD odde\u013Eova\u010D",
removeformat_desc:"Odstr\u00E1ni\u0165 form\u00E1tovanie",
custom1_desc:"\u013Dubovoln\u00FD popisok",
forecolor_desc:"Vyber farbu textu",
backcolor_desc:"Vyber farbu pozadia",
charmap_desc:"Vlo\u017Ei\u0165 vlastn\u00FD znak",
visualaid_desc:"Zobrazi\u0165 pomocn\u00E9/skryt\u00E9 prvky",
anchor_desc:"Vlo\u017Ei\u0165/upravi\u0165 n\u00E1zov kotvy",
cut_desc:"Vystrihn\u00FA\u0165",
copy_desc:"Kop\u00EDrova\u0165",
paste_desc:"Vlo\u017Ei\u0165",
image_props_desc:"Vlastnosti obr\u00E1zka",
newdocument_desc:"Nov\u00FD dokument",
help_desc:"N\u00E1poveda",
blockquote_desc:"Citovan\u00FD text",
clipboard_msg:"Funkcie Kop\u00EDrova\u0165/vysrihn\u00FA\u0165/vlo\u017Ei\u0165 nie su podporovan\u00E9 prehliada\u010Dmi Mozilla a Firefox. \r\nChce\u0161 viac inform\u00E1ci\u00ED o tomto probl\u00E9me?",
path:"Cesta",
newdocument:"Naozaj chce\u0161 vy\u010Disti\u0165 v\u0161etok obsah?",
toolbar_focus:"Prejdi na n\u00E1strojov\u00E9 tla\u010Didl\u00E1 - Alt+Q, Prejdi na editor - Alt-Z, Prejdi na cestu elementov - Alt-X",
more_colors:"Viac farieb"
});