tinyMCE.addI18n('nn.advanced_dlg',{
about_title:"Om TinyMCE",
about_general:"Om",
about_help:"Hjelp",
about_license:"Lisens",
about_plugins:"Programtillegg",
about_plugin:"Programtillegg",
about_author:"Utviklar",
about_version:"Versjon",
about_loaded:"Lasta programtillegg",
anchor_title:"Set inn / endre anker",
anchor_name:"Ankernamn",
code_title:"HTML-editor",
code_wordwrap:"Tekstbryting",
colorpicker_title:"Vel ein farge",
colorpicker_picker_tab:"Vel farge",
colorpicker_picker_title:"Fargeval",
colorpicker_palette_tab:"Palett",
colorpicker_palette_title:"Palettfargar",
colorpicker_named_tab:"Namneval",
colorpicker_named_title:"Fargenamn",
colorpicker_color:"Farge:",
colorpicker_name:"Namn:",
charmap_title:"Vel spesialteikn",
image_title:"Set inn / endre bilete",
image_src:"Bilete-URL",
image_alt:"Bileteomtale",
image_list:"Liste med bilete",
image_border:"Ramme",
image_dimensions:"Dimensjonar",
image_vspace:"Vertikal avstand",
image_hspace:"Horisontal avstand",
image_align:"Justering",
image_align_baseline:"Botnlinje",
image_align_top:"Topp",
image_align_middle:"Midtstilt",
image_align_bottom:"Botn",
image_align_texttop:"Teksttopp",
image_align_textbottom:"Tekstbotn",
image_align_left:"Venstre",
image_align_right:"H\u00F8gre",
link_title:"Set inn / endre lenkje",
link_url:"Lenkje-URL",
link_target:"Vindauge",
link_target_same:"Opne i dette vindauget",
link_target_blank:"Opne i nytt vindauget",
link_titlefield:"Tittel",
link_is_email:"Nettadressa du skreiv inn ser ut til \u00E5 vere ein e-postadresse. \u00D8nskjer du \u00E5 leggje til det obligatoriske mailto:-prefikset?",
link_is_external:"Nettadressa du skreiv inn ser ut til \u00E5 vere ein ekstern nettadresse. \u00D8nskjer du \u00E5 leggje til det obligatoriske http://-prefikset?",
link_list:"Lenkjeliste"
});