tinyMCE.addI18n('et.media_dlg',{
title:"Sisesta/muuda meediat",
general:"\u00DCldine",
advanced:"T\u00E4psem",
file:"Fail/URL",
list:"Nimekiri",
size:"M\u00F5\u00F5dud",
preview:"Eelvaade",
constrain_proportions:"S\u00E4ilita proportsioon",
type:"T\u00FC\u00FCp",
id:"ID",
name:"Nime",
class_name:"Klass",
vspace:"V-vahe",
hspace:"H-vahe",
play:"Auto-start",
loop:"Auto-kordus",
menu:"N\u00E4ita men\u00FC\u00FCd",
quality:"Kvaliteet",
scale:"M\u00F5\u00F5tkava",
align:"Joondus",
salign:"SJoondus",
wmode:"WMoodus",
bgcolor:"Taust",
base:"Baas",
flashvars:"Flashiv\u00E4rk",
liveconnect:"SWLive-\u00DChendus",
autohref:"Auto-HREF",
cache:"Vahem\u00E4lu",
hidden:"Peidetud",
controller:"Kontrollija",
kioskmode:"Kioski reziim",
playeveryframe:"M\u00E4ngi igat raami",
targetcache:"Sihtm\u00E4rgi vahem\u00E4lu",
correction:"Parandust ei ole",
enablejavascript:"Luba JavaScript\u2019i",
starttime:"Stardi aeg",
endtime:"L\u00F5pu aeg",
href:"Href",
qtsrcchokespeed:"Kiirus",
target:"Sihtm\u00E4rk",
volume:"Valjudus",
autostart:"Auto-start",
enabled:"Lubatud",
fullscreen:"T\u00E4isekraan",
invokeurls:"N\u00E4ita URL\u2019e",
mute:"Vaigista",
stretchtofit:"Venita sobivaks",
windowlessvideo:"Aknata video",
balance:"Tasakaal",
baseurl:"Baas URL",
captioningid:"Tiitri ID",
currentmarker:"Antud marker",
currentposition:"Antud positioon",
defaultframe:"Vaikimisi raam",
playcount:"M\u00E4ngukorrad",
rate:"Hinda",
uimode:"UI Reziim",
flash_options:"Flash\u2019i seaded",
qt_options:"Quicktime\u2019 seaded",
wmp_options:"Windows media player\u2019i seaded",
rmp_options:"Real media player\u2019i seaded",
shockwave_options:"Shockwave\u2019i seaded",
autogotourl:"Auto-URL",
center:"Keskel",
imagestatus:"Pildi staatus",
maintainaspect:"S\u00E4ilitamise aspekt",
nojava:"Ilma java\u2019ta",
prefetch:"Prefetch",
shuffle:"Sega",
console:"Konsool",
numloop:"Kordused",
controls:"Kontrollid",
scriptcallbacks:"Skripti tagasikutse",
swstretchstyle:"Venita stiili",
swstretchhalign:"Venita H-joondust",
swstretchvalign:"Venita V-joondust",
sound:"Heli",
progress:"Progress",
qtsrc:"QT Src",
qt_stream_warn:"Striimitav variant peaks olema lisatud.",
align_top:"\u00DCleval",
align_right:"Paremal",
align_bottom:"All",
align_left:"Vasakul",
align_center:"Keskel",
align_top_left:"\u00DCleval vasakul",
align_top_right:"Pleval paremal",
align_bottom_left:"All vasakul",
align_bottom_right:"All paremal",
flv_options:"Flash video seaded",
flv_scalemode:"Skaala reziim",
flv_buffer:"Puffer",
flv_startimage:"Stardi pilt",
flv_starttime:"Stardi aeg",
flv_defaultvolume:"Vaikimisi helitugevus",
flv_hiddengui:"Peidetud GUI",
flv_autostart:"Auto-start",
flv_loop:"Auto.kordus",
flv_showscalemodes:"Show scale modes",
flv_smoothvideo:"Sujuv video",
flv_jscallback:"JS tagasikutse"
});