tinyMCE.addI18n('ca.table_dlg',{
general_tab:"General",
advanced_tab:"Avan\u00E7at",
general_props:"Propietats generals",
advanced_props:"Propietats avan\u00E7ades",
rowtype:"Part de la taula on \u00E9s la fila",
title:"Insereix/Modifica taula",
width:"Amplada",
height:"Al\u00E7ada",
cols:"Columnes",
rows:"Files",
cellspacing:"Espai de Cel.la",
cellpadding:"Espai de marge",
border:"Vora",
align:"Alineaci\u00F3",
align_default:"Per defecte",
align_left:"Esquerra",
align_right:"Dreta",
align_middle:"Centrat",
row_title:"Propietats de la fila de la taula",
cell_title:"Propietats de la cel\u00B7la de la taula",
cell_type:"Tipus de cel\u00B7la",
valign:"Alineaci\u00F3 vertical",
align_top:"Dalt",
align_bottom:"Baix",
bordercolor:"Color de la vora",
bgcolor:"Color del fons",
merge_cells_title:"Refon les cel\u00B7les de la taula",
id:"Id",
style:"Estil",
langdir:"Direcci\u00F3 de l'Idioma",
langcode:"Codi de l'idioma",
mime:"Tipus MIME de l'objectiu",
ltr:"D'esquerra a dreta",
rtl:"De dreta a esquerra",
bgimage:"Imatge de fons",
summary:"Resum",
td:"Dades",
th:"Cap\u00E7alera",
cell_cell:"Actualitza la cel\u00B7la actual",
cell_row:"Actualitza totes les cel\u00B7les de la fila",
cell_all:"Actualitza totes les cel\u00B7les de la taula",
row_row:"Actualitza la fila actual",
row_odd:"Actualitza les files senars de la taula",
row_even:"Actualitza les files parelles de la taula",
row_all:"Actualitza les files de la taula",
thead:"Cap\u00E7alera de la Taula",
tbody:"Cos de la Taula",
tfoot:"Peu de la Taula",
scope:"Abast",
rowgroup:"Grup de Files",
colgroup:"Grup de Columnes",
col_limit:"Has excedit el nombre m\u00E0xim de columnes de {$cols}.",
row_limit:"Has excedit el nombre m\u00E0xim de files de {$rows}.",
cell_limit:"Has excedit el nombre m\u00E0xim de cel\u00B7les de {$cells}.",
missing_scope:"Segur que vols continuar sense especificar un abast per a les cel\u00B7les de cap\u00E7alera d'aquesta taula? Sense aix\u00F2, alguns usuaris/es amb discapacitats tindran dificultats per entendre el contingut o les dades mostrades a la taula.",
caption:"T\u00EDtol de la taula",
frame:"Marc",
frame_none:"cap",
frame_groups:"grups",
frame_rows:"files",
frame_cols:"columnes",
frame_all:"totes",
rules:"Regles",
rules_void:"salta regles",
rules_above:"sobre",
rules_below:"sota",
rules_hsides:"banda horitzontal",
rules_lhs:"lhs",
rules_rhs:"rhs",
rules_vsides:"banda vertical",
rules_box:"caixa",
rules_border:"vora"
});