tinyMCE.addI18n('sk.advanced_dlg',{
about_title:"O TinyMCE",
about_general:"O Programe",
about_help:"N\u00E1poveda",
about_license:"Licencia",
about_plugins:"Pluginy",
about_plugin:"Plugin",
about_author:"Autor",
about_version:"Verzia",
about_loaded:"Na\u010D\u00EDtan\u00E9 pluginy",
anchor_title:"Vlo\u017Ei\u0165/upravi\u0165 n\u00E1zov kotvy",
anchor_name:"N\u00E1zov kotvy",
code_title:"Editor HTML k\u00F3du",
code_wordwrap:"Zalamova\u0165 riadky",
colorpicker_title:"Vyber farbu",
colorpicker_picker_tab:"Mie\u0161a\u010D",
colorpicker_picker_title:"Mie\u0161a\u010D farieb",
colorpicker_palette_tab:"Paleta",
colorpicker_palette_title:"Paleta farieb",
colorpicker_named_tab:"N\u00E1zvoslovia",
colorpicker_named_title:"N\u00E1zvy farieb",
colorpicker_color:"Farba:",
colorpicker_name:"N\u00E1zov:",
charmap_title:"Vyber \u0161peci\u00E1lny znak",
image_title:"Vlo\u017Ei\u0165/editova\u0165 obr\u00E1zok",
image_src:"URL obr\u00E1zka",
image_alt:"Popis obr\u00E1zka",
image_list:"Zoznam obr\u00E1zkov",
image_border:"Okraj",
image_dimensions:"Rozmery",
image_vspace:"Vertik\u00E1lna medzera",
image_hspace:"Horizont\u00E1lna medzera",
image_align:"Usporiadanie",
image_align_baseline:"Z\u00E1klad\u0148a",
image_align_top:"Hore",
image_align_middle:"Uprostred",
image_align_bottom:"Dolu",
image_align_texttop:"Text hore",
image_align_textbottom:"Text dolu",
image_align_left:"V\u013Eavo",
image_align_right:"Vpravo",
link_title:"Vlo\u017Ei\u0165/editova\u0165 odkaz",
link_url:"URL odkazu",
link_target:"Cie\u013E odkazu",
link_target_same:"Otvori\u0165 odkaz v rovnakom okne",
link_target_blank:"Otvori\u0165 odkaz v novom okne",
link_titlefield:"N\u00E1zov",
link_is_email:"Zd\u00E1 sa, \u017Ee zadan\u00E1 URL je emailov\u00E1 adresa. Chce\u0161 vlo\u017Ei\u0165 povinn\u00FD prefix mailto: ?",
link_is_external:"Zd\u00E1 sa, \u017Ee zadan\u00E1 URL je extern\u00FD odkaz. Chce\u0161 vlo\u017Ei\u0165 povinn\u00FD prefix http:// ?",
link_list:"Zoznam odkazov"
});