tinyMCE.addI18n({es:{
common:{
edit_confirm:" \u00BFDesea utilizar el modo WYSIWYG para esta caja de texto?",
apply:"Aplicar",
insert:"Insertar",
update:"Actualizar",
cancel:"Cancelar",
close:"Cerrar",
browse:"Examinar",
class_name:"Clase",
not_set:"-- Ninguno --",
clipboard_msg:"Copiar/Cortar/Pegar no se encuentra disponible en Mozilla y Firefox.\n \u00BFDesea obtener m\u00E1s informaci\u00F3n acerca de este tema?",
clipboard_no_support:"Su navegador no soporta las funciones de cortapapeles, use los accesos por teclado.",
popup_blocked:"Lo sentimos, su bloqueo de ventanas emergentes ha deshabilitado una ventana que provee funcionalidades a la aplicaci\u00F3n. Necesita deshabilitar este bloqueo en este sitio para poder utilizar todas las funciones.",
invalid_data:"Error: Introdujo un valor no v\u00E1lido, est\u00E1n marcados en rojo.",
more_colors:"M\u00E1s colores"
},
contextmenu:{
align:"Alineaci\u00F3n",
left:"Izquierda",
center:"Centrado",
right:"Derecha",
full:"Justificado"
},
insertdatetime:{
date_fmt:"%d-%m-%Y",
time_fmt:"%H:%M:%S",
insertdate_desc:"Insertar fecha",
inserttime_desc:"Insertar hora",
months_long:"Enero,Febrero,Marzo,Abril,Mayo,Junio,Julio,Agosto,Septiembre,Octubre,Noviembre,Diciembre",
months_short:"Ene,Feb,Mar,Abr,May,Jun,Jul,Ago,Sep,Oct,Nov,Dic",
day_long:"Domingo,Lunes,Martes,Mi\u00E9rcoles,Jueves,Viernes,S\u00E1bado,Domingo",
day_short:"Dom,Lun,Mar,Mie,Jue,Vie,Sab,Dom"
},
print:{
print_desc:"Imprimir"
},
preview:{
preview_desc:"Vista previa"
},
directionality:{
ltr_desc:"Direcci\u00F3n izquierda a derecha",
rtl_desc:"Direcci\u00F3n derecha a izquierda"
},
layer:{
insertlayer_desc:"Insertar nueva capa",
forward_desc:"Avanzar",
backward_desc:"Retroceder",
absolute_desc:"Cambiar a posici\u00F3n absoluta",
content:"Nueva capa..."
},
save:{
save_desc:"Guardar",
cancel_desc:"Cancelar todos los cambios"
},
nonbreaking:{
nonbreaking_desc:"Insertar caracter de espacio 'non-breaking'"
},
iespell:{
iespell_desc:"Corrector ortogr\u00E1fico",
download:"No se detect\u00F3 'ieSpell'.  \u00BFDesea instalarlo ahora?"
},
advhr:{
advhr_desc:"Regla horizontal"
},
emotions:{
emotions_desc:"Emoticones"
},
searchreplace:{
search_desc:"Buscar",
replace_desc:"Buscar/Reemplazar"
},
advimage:{
image_desc:"Insertar/editar imagen"
},
advlink:{
link_desc:"Insertar/editar hiperv\u00EDnculo"
},
xhtmlxtras:{
cite_desc:"Cita",
abbr_desc:"Abreviatura",
acronym_desc:"Acr\u00F3nimo",
del_desc:"Borrado",
ins_desc:"Inserci\u00F3n",
attribs_desc:"Insertar/Editar atributos"
},
style:{
desc:"Editar Estilo CSS"
},
paste:{
paste_text_desc:"Pegar como texto plano",
paste_word_desc:"Pegar desde Word",
selectall_desc:"Seleccionar todo"
},
paste_dlg:{
text_title:"Use CTRL+V en su teclado para pegar el texto en la ventana.",
text_linebreaks:"Keep linebreaks",
word_title:"Use CTRL+V en su teclado para pegar el texto en la ventana."
},
table:{
desc:"Inserta una nueva tabla",
row_before_desc:"Insertar fila (antes)",
row_after_desc:"Insertar fila (despu\u00E9s)",
delete_row_desc:"Suprimir fila",
col_before_desc:"Insertar columna (antes)",
col_after_desc:"Insertar columna (despu\u00E9s)",
delete_col_desc:"Suprimir columna",
split_cells_desc:"Dividir celdas",
merge_cells_desc:"Vincular celdas",
row_desc:"Propiedades de la fila",
cell_desc:"Propiedades de la celda",
props_desc:"Propiedades de la tabla",
paste_row_before_desc:"Pegar filas (antes)",
paste_row_after_desc:"Pegar filas (despu\u00E9s)",
cut_row_desc:"Cortar fila",
copy_row_desc:"Copiar fila",
del:"Eliminar tabla",
row:"Fila",
col:"Columna",
cell:"Celda"
},
autosave:{
unload_msg:"Los cambios realizados se perder\u00E1n si sale de esta p\u00E1gina."
},
fullscreen:{
desc:"Cambiar a modo Pantalla Completa"
},
media:{
desc:"Insertar/editar medio embebido",
edit:"Editar medio embebido"
},
fullpage:{
desc:"Propiedades del documento"
},
template:{
desc:"Insertar contenido de plantilla predefinida"
},
visualchars:{
desc:"Caracteres de control ON/OFF."
},
spellchecker:{
desc:"Cambiar a corrector ortogr\u00E1fico",
menu:"Configuraci\u00F3n de corrector ortogr\u00E1fico",
ignore_word:"Ignorar",
ignore_words:"Ignorar todo",
langs:"Idiomas",
wait:"Espere...",
sug:"Sugerencias",
no_sug:"Sin sugerencias",
no_mpell:"No se encontraron errores."
},
pagebreak:{
desc:"Insertar fin de p\u00E1gina"
}}});