tinyMCE.addI18n('az.advlink_dlg',{
title:"Ke\u00E7idi \u0259lav\u0259/redakt\u0259 et",
url:"Ke\u00E7id \u00FCnvan\u0131",
target:"H\u0259d\u0259f",
titlefield:"Ad\u0131",
is_email:"Daxil edil\u0259n \u00FCnvan e-po\u00E7ta b\u0259nz\u0259yir. mailto: prefiksini \u0259lav\u0259 etm\u0259k ist\u0259yirsiniz?",
is_external:"Daxil edil\u0259n \u00FCnvan xarici ke\u00E7id\u0259 b\u0259nz\u0259yir. http:// prefiksini \u0259lav\u0259 etm\u0259k ist\u0259yirsiniz?",
list:"Ke\u00E7id siyah\u0131s\u0131",
general_tab:"\u00DCmumi",
popup_tab:"\u00DCz\u0259 \u00E7\u0131xan p\u0259nc\u0259r\u0259",
events_tab:"Hadis\u0259l\u0259r",
advanced_tab:"\u018Flav\u0259l\u0259r",
general_props:"\u00DCmumi x\u00FCsusiyy\u0259tl\u0259ri",
popup_props:"\u00DCz\u0259 \u00E7\u0131xan p\u0259nc\u0259r\u0259l\u0259rin x\u00FCsusiyy\u0259tl\u0259ti",
event_props:"Hadis\u0259l\u0259r",
advanced_props:"\u018Flav\u0259 x\u00FCsusiyy\u0259tl\u0259r",
popup_opts:"Parametrl\u0259r",
anchor_names:"L\u00F6vb\u0259r",
target_same:"Bu p\u0259nc\u0259r\u0259d\u0259 a\u00E7 / \u00E7\u0259r\u00E7iv\u0259",
target_parent:"Ana p\u0259nc\u0259r\u0259d\u0259 a\u00E7 / \u00E7\u0259r\u00E7iv\u0259",
target_top:"Yuxar\u0131 \u00E7\u0259r\u00E7iv\u0259d\u0259 a\u00E7 (dig\u0259rl\u0259rini d\u0259 doldurur)",
target_blank:"Yeni p\u0259nc\u0259r\u0259d\u0259 a\u00E7",
popup:"\u00DCz\u0259 \u00E7\u0131xan Javascript-p\u0259nc\u0259r\u0259",
popup_url:"\u00DCz\u0259 \u00E7\u0131xan p\u0259nc\u0259r\u0259nin \u00FCnvan\u0131",
popup_name:"P\u0259nc\u0259r\u0259nin ad\u0131",
popup_return:"'return false' \u0259lav\u0259 et",
popup_scrollbars:"F\u0131rlanan\u0131n zolaqlar\u0131n\u0131 g\u00F6st\u0259r",
popup_statusbar:"M\u0259tn v\u0259ziyy\u0259tini g\u00F6st\u0259r",
popup_toolbar:"Al\u0259tl\u0259r panelini g\u00F6st\u0259r",
popup_menubar:"Menyu s\u0259trini g\u00F6st\u0259r",
popup_location:"\u00DCnvan s\u0259trini g\u00F6st\u0259r",
popup_resizable:"P\u0259nc\u0259r\u0259 \u00F6l\u00E7\u00FCs\u00FCn\u00FC d\u0259yi\u015Fil\u0259n et",
popup_dependent:"As\u0131l\u0131 olan (yaln\u0131z Mozilla/Firefox)",
popup_size:"\u00F6l\u00E7\u00FC",
popup_position:"M\u00F6vqe (X/Y)",
id:"\u0130dentifikator",
style:"Sil",
classes:"Sinifl\u0259r",
target_name:"H\u0259d\u0259f ad\u0131",
langdir:"Dil istiqam\u0259ti",
target_langcode:"H\u0259d\u0259fli dil",
langcode:"Dil kodu",
encoding:"H\u0259d\u0259fli kodla\u015Fd\u0131rma",
mime:"H\u0259d\u0259fli MIME-n\u00F6v",
rel:"P\u0259nc\u0259r\u0259nin h\u0259d\u0259f\u0259 m\u00FCnasib\u0259ti",
rev:"H\u0259d\u0259fin p\u0259nc\u0259r\u0259y\u0259 m\u00FCnasib\u0259ti",
tabindex:"Hesab indeksi",
accesskey:"Giri\u015F klavi\u015Fi",
ltr:"Solda-sa\u011Fa",
rtl:"Sa\u011Fda-sola",
link_list:"Ke\u00E7id siyah\u0131s\u0131"
});