tinyMCE.addI18n('he.media_dlg',{
title:"\u05D4\u05D5\u05E1\u05E4\u05EA/\u05E2\u05E8\u05D9\u05DB\u05EA \u05E1\u05E8\u05D8\u05D5\u05DF",
general:"\u05DB\u05DC\u05DC\u05D9",
advanced:"\u05DE\u05EA\u05E7\u05D3\u05DD",
file:"\u05DB\u05EA\u05D5\u05D1\u05EA \u05D4\u05E7\u05D5\u05D1\u05E5",
list:"\u05E8\u05E9\u05D9\u05DE\u05D4",
size:"\u05E8\u05D5\u05D7\u05D1 \u05D5\u05D2\u05D5\u05D1\u05D4",
preview:"\u05EA\u05E6\u05D5\u05D2\u05D4 \u05DE\u05E7\u05D3\u05D9\u05DE\u05D4",
constrain_proportions:"\u05E9\u05DE\u05D5\u05E8 \u05E2\u05DC \u05E4\u05E8\u05D5\u05E4\u05D5\u05E8\u05E6\u05D9\u05D5\u05EA",
type:"\u05E1\u05D5\u05D2",
id:"Id",
name:"Name",
class_name:"Class",
vspace:"\u05E8\u05D5\u05D5\u05D7 \u05D0\u05E0\u05DB\u05D9",
hspace:"\u05E8\u05D5\u05D5\u05D7 \u05D0\u05D5\u05E4\u05E7\u05D9",
play:"\u05E0\u05D2\u05D9\u05E0\u05D4 \u05D0\u05D5\u05D8\u05D5\u05DE\u05D8\u05D9\u05EA \u05E2\u05DD \u05D4\u05D8\u05E2\u05D9\u05E0\u05D4",
loop:"\u05E0\u05D2\u05D9\u05E0\u05D4 \u05DE\u05D7\u05D6\u05D5\u05E8\u05D9\u05EA",
menu:"\u05D4\u05E6\u05D2\u05EA \u05EA\u05E4\u05E8\u05D9\u05D8",
quality:"\u05D0\u05D9\u05DB\u05D5\u05EA \u05D4\u05E1\u05E8\u05D8\u05D5\u05DF",
scale:"Scale",
align:"Align",
salign:"SAlign",
wmode:"WMode",
bgcolor:"\u05E6\u05D1\u05E2 \u05E8\u05E7\u05E2",
base:"Base",
flashvars:"Flashvars",
liveconnect:"SWLiveConnect",
autohref:"AutoHREF",
cache:"Cache",
hidden:"Hidden",
controller:"Controller",
kioskmode:"Kiosk mode",
playeveryframe:"Play every frame",
targetcache:"Target cache",
correction:"No correction",
enablejavascript:"Enable JavaScript",
starttime:"Start time",
endtime:"End time",
href:"Href",
qtsrcchokespeed:"Choke speed",
target:"Target",
volume:"Volume",
autostart:"Auto start",
enabled:"Enabled",
fullscreen:"Fullscreen",
invokeurls:"Invoke URLs",
mute:"Mute",
stretchtofit:"Stretch to fit",
windowlessvideo:"Windowless video",
balance:"Balance",
baseurl:"Base URL",
captioningid:"Captioning id",
currentmarker:"Current marker",
currentposition:"Current position",
defaultframe:"Default frame",
playcount:"Play count",
rate:"Rate",
uimode:"UI Mode",
flash_options:"\u05D0\u05E4\u05E9\u05E8\u05D5\u05D9\u05D5\u05EA \u05E4\u05DC\u05D0\u05E9",
qt_options:"\u05D0\u05E4\u05E9\u05E8\u05D5\u05D9\u05D5\u05EA Quicktime",
wmp_options:"\u05D0\u05E4\u05E9\u05E8\u05D5\u05D9\u05D5\u05EA \u05DE\u05D3\u05D9\u05D4 \u05E4\u05DC\u05D9\u05D9\u05E8",
rmp_options:"\u05D0\u05E4\u05E9\u05E8\u05D5\u05D9\u05D5\u05EA \u05E0\u05D2\u05DF Real Media",
shockwave_options:"\u05D0\u05E4\u05E9\u05E8\u05D5\u05D9\u05D5\u05EA Shockwave",
autogotourl:"Auto goto URL",
center:"\u05DE\u05E8\u05DB\u05D6",
imagestatus:"Image status",
maintainaspect:"Maintain aspect",
nojava:"No java",
prefetch:"Prefetch",
shuffle:"Shuffle",
console:"Console",
numloop:"Num loops",
controls:"Controls",
scriptcallbacks:"Script callbacks",
swstretchstyle:"Stretch style",
swstretchhalign:"Stretch H-Align",
swstretchvalign:"Stretch V-Align",
sound:"\u05E6\u05DC\u05D9\u05DC",
progress:"Progress",
qtsrc:"QT Src",
qt_stream_warn:"Streamed rtsp resources should be added to the QT Src field under the advanced tab.\nYou should also add a non streamed version to the Src field..",
align_top:"Top",
align_right:"Right",
align_bottom:"Bottom",
align_left:"\u05DC\u05E9\u05DE\u05D0\u05DC",
align_center:"Center",
align_top_left:"Top left",
align_top_right:"Top right",
align_bottom_left:"Bottom left",
align_bottom_right:"Bottom right",
flv_options:"Flash video options",
flv_scalemode:"Scale mode",
flv_buffer:"Buffer",
flv_startimage:"Start image",
flv_starttime:"Start time",
flv_defaultvolume:"Default volumne",
flv_hiddengui:"Hidden GUI",
flv_autostart:"Auto start",
flv_loop:"Loop",
flv_showscalemodes:"Show scale modes",
flv_smoothvideo:"Smooth video",
flv_jscallback:"JS Callback"
});