tinyMCE.addI18n('it.advanced_dlg',{
about_title:"Informazioni su TinyMCE",
about_general:"Informazioni",
about_help:"Aiuto",
about_license:"Licenza",
about_plugins:"Plugins",
about_plugin:"Plugin",
about_author:"Autore",
about_version:"Versione",
about_loaded:"Plugin caricati",
anchor_title:"Inserisci/modifica ancora",
anchor_name:"Nome ancora",
code_title:"Editor sorgente HTML",
code_wordwrap:"A capo automatico",
colorpicker_title:"Seleziona un colore",
colorpicker_picker_tab:"Selettore",
colorpicker_picker_title:"Selettore colori",
colorpicker_palette_tab:"Tavolozza",
colorpicker_palette_title:"Tavolozza dei colori",
colorpicker_named_tab:"Per nome",
colorpicker_named_title:"Colori per nome",
colorpicker_color:"Colore:",
colorpicker_name:"Nome:",
charmap_title:"Seleziona carattere speciale",
image_title:"Inserisci/modifica immagine",
image_src:"URL immagine",
image_alt:"Descrizione immagine",
image_list:"Lista immagini",
image_border:"Bordo",
image_dimensions:"Dimensioni",
image_vspace:"Spaziatura verticale",
image_hspace:"Spaziatura orizzontale",
image_align:"Allineamentot",
image_align_baseline:"Alla base",
image_align_top:"In alto",
image_align_middle:"In mezzo",
image_align_bottom:"In basso",
image_align_texttop:"In alto al testo",
image_align_textbottom:"In basso al testo",
image_align_left:"A sinistra",
image_align_right:"A destra",
link_title:"Inserisci/modifica collegamento",
link_url:"URL collegamento",
link_target:"Target",
link_target_same:"Apri link nella stessa finestra",
link_target_blank:"Apri link in una nuova finestra",
link_titlefield:"Titolo",
link_is_email:"L'URL inserito sembra essere un indirizzo email. Aggiungere il necessario prefisso mailto: ?",
link_is_external:"L'URL inserito sembra essere un link esterno. Aggiungere il necessario prefisso http:// ?",
link_list:"Lista collegamenti"
});