tinyMCE.addI18n({ko:{
common:{
edit_confirm:"WYSIWYG\uBAA8\uB4DC\uB85C \uC804\uD658\uD569\uB2C8\uAE4C?",
apply:"\uC801\uC6A9",
insert:"\uC0BD\uC785",
update:"\uAC31\uC2E0",
cancel:"\uCDE8\uC18C",
close:"\uB2EB\uAE30",
browse:"\uBE0C\uB77C\uC6B0\uC988",
class_name:"\uD074\uB798\uC2A4",
not_set:"-- \uC5C6\uC74C --",
clipboard_msg:"\uBCF5\uC0AC/\uC798\uB77C\uB0B4\uAE30/\uBD99\uC774\uAE30\uB294 Mozilla \uBC0FFirefox \uC5D0\uC11C \uC0AC\uC6A9\uB418\uC9C0 \uC54A\uC2B5\uB2C8\uB2E4.\n\uC0C1\uC138\uC815\uBCF4\uB97C \uD45C\uC2DC\uD569\uB2C8\uAE4C?",
clipboard_no_support:"\uC774 \uAE30\uB2A5\uC740 \uBE0C\uB77C\uC6B0\uC800\uC5D0 \uC758\uD574 \uC81C\uD55C\uB418\uACE0 \uC788\uC2B5\uB2C8\uB2E4. \uB2E8\uCD95\uD0A4\uC744 \uC774\uC6A9\uD558\uC2ED\uC2DC\uC624.",
popup_blocked:"\uD31D\uC5C5\uC774 \uCC28\uB2E8\uB418\uC5C8\uC2B5\uB2C8\uB2E4. \uBAA8\uB4E0 \uAE30\uB2A5\uC744 \uC774\uC6A9\uD558\uC2DC\uAE30 \uC704\uD574\uC11C\uB294 \uD31D\uC5C5\uCC28\uB2E8\uC744 \uD574\uC81C\uD574 \uC8FC\uC138\uC694.",
invalid_data:"\uC5D0\uB7EC: \uC720\uD6A8\uD558\uC9C0 \uC54A\uB294 \uAE00\uC790\uAC00 \uC788\uC2B5\uB2C8\uB2E4. \uBE68\uAC04\uC0C9\uC73C\uB85C \uD45C\uC2DC\uB429\uB2C8\uB2E4.",
more_colors:"\uADF8 \uC678\uC758 \uC0C9"
},
contextmenu:{
align:"\uC815\uB82C",
left:"\uC67C\uCABD \uC815\uB82C",
center:"\uAC00\uC6B4\uB370 \uC815\uB82C",
right:"\uC624\uB978\uCABD \uC815\uB82C",
full:"\uBC30\uBD84 \uC815\uB82C"
},
insertdatetime:{
date_fmt:"%Y-%m-%d",
time_fmt:"%H:%M:%S",
insertdate_desc:"\uB0A0\uC9DC \uC0BD\uC785",
inserttime_desc:"\uC2DC\uAC04 \uC0BD\uC785",
months_long:"1\uC6D4,2\uC6D4,3\uC6D4,4\uC6D4,5\uC6D4,6\uC6D4,7\uC6D4,8\uC6D4,9\uC6D4,10\uC6D4,11\uC6D4,12\uC6D4",
months_short:"1,2,3,4,5,6,7,8,9,10,11,12",
day_long:"\uC77C\uC694\uC77C,\uC6D4\uC694\uC77C,\uD654\uC694\uC77C,\uC218\uC694\uC77C,\uBAA9\uC694\uC77C,\uAE08\uC694\uC77C,\uD1A0\uC694\uC77C,\uC77C\uC694\uC77C",
day_short:"\uC77C,\uC6D4,\uD654,\uC218,\uBAA9,\uAE08,\uD1A0,\uC77C"
},
print:{
print_desc:"\uC778\uC1C4"
},
preview:{
preview_desc:"\uBBF8\uB9AC\uBCF4\uAE30"
},
directionality:{
ltr_desc:"\uBB38\uC790\uBC29\uD5A5\uC744 \uC67C\uCABD\uC5D0\uC11C \uC624\uB978\uCABD\uC73C\uB85C",
rtl_desc:"\uBB38\uC790\uBC29\uD5A5\uC744 \uC624\uB978\uCABD\uC5D0\uC11C \uC67C\uCABD\uC73C\uB85C"
},
layer:{
insertlayer_desc:"\uC0C8 \uB808\uC774\uC5B4",
forward_desc:"\uC55E\uC73C\uB85C \uC774\uB3D9",
backward_desc:"\uB4A4\uB85C \uC774\uB3D9",
absolute_desc:"\uC808\uB300\uC704\uCE58\uB85C \uC804\uD658",
content:"\uC0C8 \uB808\uC774\uC5B4..."
},
save:{
save_desc:"\uC800\uC7A5",
cancel_desc:"\uBAA8\uB450 \uCDE8\uC18C"
},
nonbreaking:{
nonbreaking_desc:"\uBE48\uCE78 \uC0BD\uC785"
},
iespell:{
iespell_desc:"\uCCA0\uC790 \uAC80\uC0AC",
download:"ieSpell\uC774 \uBC1C\uACAC\uB418\uC9C0 \uC54A\uC558\uC2B5\uB2C8\uB2E4.\n\uC778\uC2A4\uD1A8 \uD558\uC2DC\uACA0\uC2B5\uB2C8\uAE4C?"
},
advhr:{
advhr_desc:"\uAD6C\uBD84\uC120"
},
emotions:{
emotions_desc:"\uC774\uBAA8\uD2F0\uCF58"
},
searchreplace:{
search_desc:"\uAC80\uC0C9",
replace_desc:"\uAC80\uC0C9/\uCE58\uD658"
},
advimage:{
image_desc:"\uC774\uBBF8\uC9C0\uC758 \uC0BD\uC785/\uD3B8\uC9D1"
},
advlink:{
link_desc:"\uB9C1\uD06C\uC758 \uC0BD\uC785/\uD3B8\uC9D1"
},
xhtmlxtras:{
cite_desc:"\uC778\uC6A9\uCC98",
abbr_desc:"\uC57D\uAE30",
acronym_desc:"\uBA38\uB9AC \uAE00\uC790\uC5B4",
del_desc:"\uC0AD\uC81C",
ins_desc:"\uC0BD\uC785",
attribs_desc:"\uC18D\uC131 \uC0BD\uC785/\uD3B8\uC9D1"
},
style:{
desc:"CSS\uD3B8\uC9D1"
},
paste:{
paste_text_desc:"\uD14D\uC2A4\uD2B8\uCC98\uB7FC \uBD99\uC5EC\uB123\uAE30",
paste_word_desc:"Word\uB85C\uBD80\uD130 \uBD99\uC5EC\uB123\uAE30",
selectall_desc:"\uBAA8\uB450 \uC120\uD0DD"
},
paste_dlg:{
text_title:"\uC708\uB3C4\uC6B0\uC5D0 \uD14D\uC2A4\uD2B8\uB97C \uBD99\uC774\uB824\uBA74 \uD0A4\uBCF4\uB4DC\uB85C Ctrl+V\uB97C \uC785\uB825\uD574 \uC8FC\uC138\uC694.",
text_linebreaks:"\uAC1C\uD589\uC744 \uBCF4\uAD00 \uC720\uC9C0",
word_title:"\uC708\uB3C4\uC6B0\uC5D0 \uD14D\uC2A4\uD2B8\uB97C \uBD99\uC774\uB824\uBA74 \uD0A4\uBCF4\uB4DC\uB85CCtrl+V\uB97C \uC785\uB825\uD574 \uC8FC\uC138\uC694."
},
table:{
desc:"\uC0C8 \uD14C\uC774\uBE14 \uC0BD\uC785",
row_before_desc:"\uC55E\uC5D0 \uD589 \uC0BD\uC785",
row_after_desc:"\uB4A4\uC5D0 \uD589 \uC0BD\uC785",
delete_row_desc:"\uD589 \uC0AD\uC81C",
col_before_desc:"\uC55E\uC5D0 \uC5F4\uC0BD\uC785",
col_after_desc:"\uB4A4\uC5D0 \uC5F4\uC0BD\uC785",
delete_col_desc:"\uC5F4\uC0AD\uC81C",
split_cells_desc:"\uACB0\uD569\uB41C \uC140\uC744 \uBD84\uD560",
merge_cells_desc:"\uC140\uC744 \uACB0\uD569",
row_desc:"\uD589\uC758 \uC18D\uC131",
cell_desc:"\uC140\uC758 \uC18D\uC131",
props_desc:"\uD14C\uC774\uBE14 \uC18D\uC131",
paste_row_before_desc:"\uC55E\uC5D0 \uD589\uC744 \uBD99\uC5EC\uB123\uAE30",
paste_row_after_desc:"\uB4A4\uB85C \uD589\uC744 \uBD99\uC5EC\uB123\uAE30",
cut_row_desc:"\uD589\uC744 \uC798\uB77C\uB0B4\uAE30",
copy_row_desc:"\uD589\uC744 \uBCF5\uC0AC",
del:"\uD14C\uC774\uBE14 \uC0AD\uC81C",
row:"\uD589",
col:"\uC5F4",
cell:"\uC140"
},
autosave:{
unload_msg:"\uB2E4\uB978 \uD398\uC774\uC9C0\uB85C \uC774\uB3D9\uD558\uBA74 \uD3B8\uC9D1\uD55C \uB0B4\uC6A9\uC774 \uCDE8\uC18C\uB429\uB2C8\uB2E4."
},
fullscreen:{
desc:"\uC804\uCCB4\uD654\uBA74"
},
media:{
desc:"\uBBF8\uB514\uC5B4\uC758 \uC0BD\uC785/\uD3B8\uC9D1",
edit:"\uBBF8\uB514\uC5B4\uC758 \uD3B8\uC9D1"
},
fullpage:{
desc:"\uD398\uC774\uC9C0\uC758 \uC18D\uC131"
},
template:{
desc:"\uC815\uC758\uAC00 \uB05D\uB09C \uD15C\uD50C\uB9BF\uC758 \uC0BD\uC785"
},
visualchars:{
desc:"\uC81C\uC5B4 \uBB38\uC790\uC758 \uD45C\uC2DC \uC804\uD658"
},
spellchecker:{
desc:"\uC2A4\uD3A0\uB9C1 \uC804\uD658",
menu:"\uC2A4\uD3A0\uB9C1 \uC124\uC815",
ignore_word:"\uC774 \uC5B4\uAD6C\uB97C \uBB34\uC2DC",
ignore_words:"\uBAA8\uB450 \uBB34\uC2DC",
langs:"\uC5B8\uC5B4",
wait:"\uAE30\uB2E4\uB824 \uC8FC\uC138\uC694...",
sug:"\uD6C4\uBCF4",
no_sug:"\uD6C4\uBCF4 \uC5C6\uC74C",
no_mpell:"\uC624\uD0C8\uC790\uAC00 \uBC1C\uACAC\uB418\uC9C0 \uC54A\uC558\uC2B5\uB2C8\uB2E4."
},
pagebreak:{
desc:"\uC0C8\uD398\uC774\uC9C0 \uC0BD\uC785"
}}});