tinyMCE.addI18n('sk.media_dlg',{
title:"Vlo\u017Eenie / editovanie vnoren\u00FDch m\u00E9di\u00ED",
general:"Z\u00E1kladn\u00E9",
advanced:"Pokro\u010Dil\u00E9",
file:"S\u00FAbor/URL",
list:"Zoznam",
size:"Rozmery",
preview:"N\u00E1h\u013Ead",
constrain_proportions:"Zachova\u0165 proporcie",
type:"Typ",
id:"ID",
name:"N\u00E1zov",
class_name:"Trieda",
vspace:"Ver. medzera",
hspace:"Hor. medzera",
play:"Samosp\u00FA\u0161\u0165anie",
loop:"Slu\u010Dka",
menu:"Zobrazi\u0165 menu",
quality:"Kvalita",
scale:"Mierka",
align:"Zarovna\u0165",
salign:"SAlign",
wmode:"WMode",
bgcolor:"Pozadie",
base:"Z\u00E1klad",
flashvars:"Flashvars",
liveconnect:"SWLiveConnect",
autohref:"AutoHREF",
cache:"Z\u00E1loha",
hidden:"Skryt\u00FD",
controller:"Controller",
kioskmode:"Kiosk mode",
playeveryframe:"Prehra\u0165 ka\u017Ed\u00FD frame",
targetcache:"Target cache",
correction:"Bez opravy",
enablejavascript:"Povoli\u0165 JavaScript",
starttime:"Po\u010Diato\u010Dn\u00FD \u010Das",
endtime:"Kone\u010Dn\u00FD \u010Das",
href:"Href",
qtsrcchokespeed:"Choke speed",
target:"Cie\u013E",
volume:"Hlasitos\u0165 zvuku",
autostart:"Samosp\u00FA\u0161\u0165anie",
enabled:"Povoli\u0165",
fullscreen:"Cel\u00E1 obrazovka",
invokeurls:"Invoke URLs",
mute:"Uml\u010Da\u0165",
stretchtofit:"Stretch to fit",
windowlessvideo:"Windowless video",
balance:"Rovnov\u00E1ha",
baseurl:"Z\u00E1kladn\u00E1 URL",
captioningid:"Captioning id",
currentmarker:"Current marker",
currentposition:"Current position",
defaultframe:"Predvolen\u00FD r\u00E1mec",
playcount:"Po\u010D\u00EDtadlo prehrat\u00ED",
rate:"Pomer",
uimode:"UI Mode",
flash_options:"Vlastnosti Flash",
qt_options:"Vlastnosti Quicktime",
wmp_options:"Vlastnosti Windows media player",
rmp_options:"Vlastnosti Real media player",
shockwave_options:"Vlastnosti Shockwave",
autogotourl:"Auto goto URL",
center:"Center",
imagestatus:"Image status",
maintainaspect:"Maintain aspect",
nojava:"No java",
prefetch:"Prefetch",
shuffle:"Shuffle",
console:"Konzola",
numloop:"Num loops",
controls:"Controls",
scriptcallbacks:"Script callbacks",
swstretchstyle:"Stretch style",
swstretchhalign:"Stretch H-Align",
swstretchvalign:"Stretch V-Align",
sound:"Zvuk",
progress:"Progress",
qtsrc:"QT Src",
qt_stream_warn:"Streamed rtsp resources should be added to the QT Src field under the advanced tab.\nYou should also add a non streamed version to the Src field..",
align_top:"Top",
align_right:"Right",
align_bottom:"Bottom",
align_left:"Left",
align_center:"Center",
align_top_left:"Top left",
align_top_right:"Top right",
align_bottom_left:"Bottom left",
align_bottom_right:"Bottom right",
flv_options:"Flash video options",
flv_scalemode:"Scale mode",
flv_buffer:"Buffer",
flv_startimage:"Start image",
flv_starttime:"Start time",
flv_defaultvolume:"Default volumne",
flv_hiddengui:"Hidden GUI",
flv_autostart:"Samosp\u00FA\u0161\u0165anie",
flv_loop:"Slu\u010Dka",
flv_showscalemodes:"Show scale modes",
flv_smoothvideo:"Smooth video",
flv_jscallback:"JS Callback"
});