tinyMCE.addI18n('et.advanced',{
style_select:"Stiilid",
font_size:"Fondi suurus",
fontdefault:"Font",
block:"Formaat",
paragraph:"Paragraaf",
div:"Div",
address:"Aadress",
pre:"Eelformeeritud",
h1:"Heading 1",
h2:"Heading 2",
h3:"Heading 3",
h4:"Heading 4",
h5:"Heading 5",
h6:"Heading 6",
blockquote:"Plokkviide",
code:"Kood",
samp:"Koodi n\u00E4ide",
dt:"Defineeringu tingimus",
dd:"Defineeringu kirjeldus",
bold_desc:"Rasvane (Ctrl+B)",
italic_desc:"Kursiiv (Ctrl+I)",
underline_desc:"Allajoonitud (Ctrl+U)",
striketrough_desc:"L\u00E4bijoonitud",
justifyleft_desc:"Vasak joondus",
justifycenter_desc:"Keskjoondus",
justifyright_desc:"Parem joondus",
justifyfull_desc:"T\u00E4isjoondus",
bullist_desc:"Ebakorrap\u00E4rane loetelu",
numlist_desc:"Korrap\u00E4rane loetelu",
outdent_desc:"Taanda v\u00E4lja",
indent_desc:"Taanda sisse",
undo_desc:"V\u00F5ta tagasi (Ctrl+Z)",
redo_desc:"Tee uuesti (Ctrl+Y)",
link_desc:"Sisesta/redigeeri link",
unlink_desc:"Eemalda link",
image_desc:"Sisesta/redigeeri pilt",
cleanup_desc:"Puhasta segane kood",
code_desc:"Redigeeri HTML l\u00E4htekoodi",
sub_desc:"Alaindeks",
sup_desc:"\u00DClaindeks",
hr_desc:"Sisesta horisontaalne joonlaud",
removeformat_desc:"Eemalda vormindus",
custom1_desc:"Teie kohandatud kirjeldus siia",
forecolor_desc:"Vali teksti v\u00E4rv",
backcolor_desc:"Vali tausta v\u00E4rv",
charmap_desc:"Sisesta kohandatud kirjam\u00E4rk",
visualaid_desc:"L\u00FClita \u00FCmber juhtjooned/n\u00E4htamatud elemendid",
anchor_desc:"Sisesta/redigeeri ankur",
cut_desc:"L\u00F5ika",
copy_desc:"Kopeeri",
paste_desc:"Kleebi",
image_props_desc:"Pildi kirjeldus",
newdocument_desc:"Uus dokument",
help_desc:"Abi",
blockquote_desc:"Plokkviide",
clipboard_msg:"Kopeeri/L\u00F5ika/Kleebi ei ole Mozillas ja Firefoxis saadaval. Kas soovid rohkem infot selle probleemi kohta?",
path:"Tee",
newdocument:"Oled sa kindel, et tahad kustutada k\u00F5ik sisud?",
toolbar_focus:"H\u00FCppa t\u00F6\u00F6riista nuppudele - Alt+Q, H\u00FCppa redigeerijale - Alt-Z, H\u00FCppa elemendi teele - Alt-X",
more_colors:"Rohkem v\u00E4rve"
});