tinyMCE.addI18n('tr.advanced',{
style_select:"Stiller",
font_size:"Yaz\u0131 boyutu",
fontdefault:"Yaz\u0131 tipi",
block:"Bi\u00E7im",
paragraph:"Paragraf",
div:"B\u00F6l\u00FCm",
address:"Adres",
pre:"\u00D6nformatl\u0131",
h1:"Ba\u015Fl\u0131k 1",
h2:"Ba\u015Fl\u0131k 2",
h3:"Ba\u015Fl\u0131k 3",
h4:"Ba\u015Fl\u0131k 4",
h5:"Ba\u015Fl\u0131k 5",
h6:"Ba\u015Fl\u0131k 6",
blockquote:"Al\u0131nt\u0131",
code:"Kod",
samp:"Kod \u00F6rne\u011Fi",
dt:"Tan\u0131m terimi ",
dd:"Tan\u0131m a\u00E7\u0131klamas\u0131",
bold_desc:"Kal\u0131n (Ctrl+B)",
italic_desc:"E\u011Fik (Ctrl+I)",
underline_desc:"Alt\u0131 \u00E7izgili (Ctrl+U)",
striketrough_desc:"Ortas\u0131 \u00E7izgili",
justifyleft_desc:"Sola yasla",
justifycenter_desc:"Ortala",
justifyright_desc:"Sa\u011Fa yasla",
justifyfull_desc:"\u0130ki yana yasla",
bullist_desc:"S\u0131ras\u0131z liste",
numlist_desc:"S\u0131ral\u0131 liste",
outdent_desc:"D\u0131\u015Fa kayd\u0131r",
indent_desc:"\u0130\u00E7e kayd\u0131r",
undo_desc:"Geri al (Ctrl+Z)",
redo_desc:"Tekrarla (Ctrl+Y)",
link_desc:"Ba\u011Flant\u0131 ekle/d\u00FCzenle",
unlink_desc:"Ba\u011Flant\u0131y\u0131 sil",
image_desc:"Resim ekle/d\u00FCzenle",
cleanup_desc:"Da\u011F\u0131n\u0131k kodu temizle",
code_desc:"HTML Kayna\u011F\u0131n\u0131 D\u00FCzenle",
sub_desc:"Altsimge",
sup_desc:"\u00DCstsimge",
hr_desc:"Yatay \u00E7izgi ekle",
removeformat_desc:"Bi\u00E7imi kald\u0131r",
custom1_desc:"\u00D6zel a\u00E7\u0131klaman\u0131z\u0131 buraya girin",
forecolor_desc:"Metin rengi se\u00E7",
backcolor_desc:"Arkaplan rengi se\u00E7",
charmap_desc:"\u00D6zel karakter ekle",
visualaid_desc:"Y\u00F6nergeleri ve g\u00F6r\u00FCnmez elemanlar\u0131 a\u00E7/kapa",
anchor_desc:"\u00C7engel noktas\u0131 ekle",
cut_desc:"Kes",
copy_desc:"Kopyala",
paste_desc:"Yap\u0131\u015Ft\u0131r",
image_props_desc:"Resim \u00F6zellikleri",
newdocument_desc:"Yeni belge",
help_desc:"Yard\u0131m",
blockquote_desc:"Al\u0131nt\u0131",
clipboard_msg:"Kopyala/Kes/Yap\u0131\u015Ft\u0131r Mozilla ve Firefox'ta kullan\u0131lamaz.\r\nBu konuda daha fazla bilgi edinmek ister misiniz?",
path:"Yol",
newdocument:"T\u00FCm i\u00E7eri\u011Fi bo\u015Faltmak istedinizden emin misiniz?",
toolbar_focus:"Ara\u00E7 d\u00FC\u011Fmelerine atla - Alt+Q, Edit\u00F6re atla - Alt-Z, Eleman yoluna atla - Alt-X",
more_colors:"Daha fazla renk"
});