tinyMCE.addI18n('fi.table_dlg',{
general_tab:"Yleiset",
advanced_tab:"Edistynyt",
general_props:"Yleiset asetukset",
advanced_props:"Edistyneet asetukset",
rowtype:"Rivi taulukon osassa",
title:"Lis\u00E4\u00E4/muokkaa taulukkoa",
width:"Leveys",
height:"Korkeus",
cols:"Sarakkeet",
rows:"Rivit",
cellspacing:"Solun v\u00E4li",
cellpadding:"Solun tyhj\u00E4 tila",
border:"Kehys",
align:"Tasaus",
align_default:"Oletus",
align_left:"Vasen",
align_right:"Oikea",
align_middle:"Keskitetty",
row_title:"Taulukon rivin asetukset",
cell_title:"Taulukon solun asetukset",
cell_type:"Solun tyyppi",
valign:"Pystysuunnan tasaus",
align_top:"Yl\u00F6s",
align_bottom:"Alas",
bordercolor:"Kehyksen v\u00E4ri",
bgcolor:"Taustan v\u00E4ri",
merge_cells_title:"Yhdist\u00E4 taulukon solut",
id:"Id",
style:"Tyyli",
langdir:"Kielen suunta",
langcode:"Kielen koodi",
mime:"Kohteen MIME-tyyppi",
ltr:"Vasemmalta oikealle",
rtl:"Oikealta vasemmalle",
bgimage:"Taustakuva",
summary:"Yhteenveto",
td:"Tietue",
th:"Otsake",
cell_cell:"P\u00E4ivit\u00E4 solu",
cell_row:"P\u00E4ivit\u00E4 kaikki rivin solut",
cell_all:"P\u00E4ivit\u00E4 kaikki taulukon solut",
row_row:"P\u00E4ivit\u00E4 rivi",
row_odd:"P\u00E4ivit\u00E4 taulukon parittomat rivit",
row_even:"P\u00E4ivit\u00E4 taulukon parilliset rivit",
row_all:"P\u00E4ivit\u00E4 kaikki taulukon rivit",
thead:"Taulukon otsake",
tbody:"Taulukon runko",
tfoot:"Taulukon alaosa",
scope:"Tila",
rowgroup:"Rivi ryhm\u00E4",
colgroup:"Sarake ryhm\u00E4",
col_limit:"Olet ylitt\u00E4nyt suurimman sallitun m\u00E4\u00E4r\u00E4n sarakkeita {$cols}.",
row_limit:"Olet ylitt\u00E4nyt suurimman sallitun m\u00E4\u00E4r\u00E4n rivej\u00E4 {$rows}.",
cell_limit:"Olet ylitt\u00E4nyt suurimman sallitun m\u00E4\u00E4r\u00E4n soluja {$cells}.",
missing_scope:"Haluatko varmasti jatkaa m\u00E4\u00E4ritt\u00E4m\u00E4tt\u00E4 tilaa t\u00E4lle taulukon otsakesolulle? Ilman sit\u00E4 joidenkin k\u00E4ytt\u00E4jien voi olla vaikea ymm\u00E4rt\u00E4\u00E4 taulukon sis\u00E4lt\u00E4m\u00E4\u00E4 informaatiota.",
caption:"Taulukon seloste",
frame:"kehys",
frame_none:"ei mit\u00E4\u00E4n",
frame_groups:"ryhm\u00E4t",
frame_rows:"rivit",
frame_cols:"sarakkeet",
frame_all:"kaikki",
rules:"S\u00E4\u00E4nn\u00F6t",
rules_void:"tyhj\u00E4",
rules_above:"yl\u00E4puoli",
rules_below:"alapuoli",
rules_hsides:"vaakasuorat reunat",
rules_lhs:"lhs",
rules_rhs:"rhs",
rules_vsides:"pystysuorat reunat",
rules_box:"laatikko",
rules_border:"kehys"
});