tinyMCE.addI18n('nb.xhtmlxtras_dlg',{
attribute_label_title:"Tittel",
attribute_label_id:"ID",
attribute_label_class:"Klasse",
attribute_label_style:"Stil",
attribute_label_cite:"Sted",
attribute_label_datetime:"Dato/tid",
attribute_label_langdir:"Tekstretning",
attribute_option_ltr:"Venstre til h\u00F8yre",
attribute_option_rtl:"H\u00F8yre til venstre",
attribute_label_langcode:"Spr\u00E5k",
attribute_label_tabindex:"Tabuleringsindeks",
attribute_label_accesskey:"Tilgangsn\u00F8kkel",
attribute_events_tab:"Hendelser",
attribute_attrib_tab:"Attributter",
general_tab:"Generelt",
attrib_tab:"Attributter",
events_tab:"Hendelser",
fieldset_general_tab:"Generelle innstillinger",
fieldset_attrib_tab:"Elementattributter",
fieldset_events_tab:"Elementhendelser",
title_ins_element:"Innsettingselement",
title_del_element:"Sletteelement",
title_acronym_element:"Akronymelement",
title_abbr_element:"Forkortelseselement",
title_cite_element:"Sitatelement",
remove:"Fjern",
insert_date:"Sett inn dato/tid",
option_ltr:"Venstre mot h\u00F8yre",
option_rtl:"H\u00F8yre mot venstre",
attribs_title:"Sett inn / endre attributter"
});