tinyMCE.addI18n({sq:{
common:{
edit_confirm:"Doni t\u00EB p\u00EBrdorni m\u00EBnyr\u00EBn WYSIWYG p\u00EBr k\u00EBt\u00EB tekst?",
apply:"Zbato",
insert:"Fut",
update:"Rifresko",
cancel:"Anulo",
close:"Mbyll",
browse:"Shfleto",
class_name:"Klasa",
not_set:"-- pa v\u00EBn\u00EB --",
clipboard_msg:"Kopja/Prerja/Ngjitja nuk suportohen n\u00EB Mozilla dhe Firefox.\nD\u00EBshironi m\u00EB shum\u00EB informacione p\u00EBr k\u00EBt\u00EB \u00E7\u00EBshtje?",
clipboard_no_support:"Aktualisht nuk suportohet nga Shfletuesi juaj, p\u00EBrdorni tastjer\u00EBn.",
popup_blocked:"Ju k\u00EBrkojm\u00EB ndjes\u00EB, por bllokuesi i popup-eve ka bllokuar nj\u00EB dritare q\u00EB ofron funksjonalitet p\u00EBr programin. Duhet t'a \u00E7aktivizoni bllokuesin e popup-eve n\u00EB m\u00EBnyr\u00EB q\u00EB t'i p\u00EBrdorni opsionet.",
invalid_data:"Gabim: Keni futur vlera t\u00EB pavlefshme, t\u00EB cilat jan\u00EB sh\u00EBnuar me t\u00EB kuqe.",
more_colors:"M\u00EB shum\u00EB ngjyra"
},
contextmenu:{
align:"Drejtimi",
left:"Majtas",
center:"Qend\u00EBr",
right:"Djathtas",
full:"I Plot\u00EB"
},
insertdatetime:{
date_fmt:"%d-%m-%y",
time_fmt:"%H:%M:%S",
insertdate_desc:"Fut dat\u00EBn",
inserttime_desc:"Fut or\u00EBn",
months_long:"Janar,Shkurt,Mars,Prill,Maj,Qershor,Korrik,Gusht,Shtator,Tetor,N\u00EBntor,Dhjetor",
months_short:"Jan,Shk,Mar,Pri,Maj,Qer,Kor,Gus,Sht,Tet,N\u00EBn,Dhj",
day_long:"E Djel\u00EB,E H\u00EBn\u00EB,E Mart\u00EB,E M\u00EBrkur\u00EB,E Enjte,E Premte,E Shtun\u00EB,E Djel\u00EB",
day_short:"Dje,H\u00EBn,Mar,M\u00EBr,Enj,Pre,Sht,Dje"
},
print:{
print_desc:"Printo"
},
preview:{
preview_desc:"Paraqitje"
},
directionality:{
ltr_desc:"Drejtimi majtas-djathtas",
rtl_desc:"Drejtimi djathtas-majtas"
},
layer:{
insertlayer_desc:"Fut shtres\u00EB t\u00EB re",
forward_desc:"L\u00EBviz para",
backward_desc:"L\u00EBviz prapa",
absolute_desc:"Aktivizo/\u00E7aktivizo pozicionimin absolut",
content:"Shtres\u00EB e re..."
},
save:{
save_desc:"Ruaj",
cancel_desc:"Anuloji t\u00EB gjitha ndryshimet"
},
nonbreaking:{
nonbreaking_desc:"Fut hap\u00EBsir\u00EB"
},
iespell:{
iespell_desc:"Kontrollo p\u00EBr gabime drejt\u00EBshkrimore",
download:"ieSpell nuk u detektua. D\u00EBshironi ta instaloni?"
},
advhr:{
advhr_desc:"Linj\u00EB horizontale"
},
emotions:{
emotions_desc:"Emocionet"
},
searchreplace:{
search_desc:"K\u00EBrko",
replace_desc:"K\u00EBrko/Z\u00EBvend\u00EBso"
},
advimage:{
image_desc:"Fut/edito foto"
},
advlink:{
link_desc:"Fut/edito lidhje"
},
xhtmlxtras:{
cite_desc:"Citat",
abbr_desc:"Shkurtim",
acronym_desc:"Akronim",
del_desc:"Fshirje",
ins_desc:"Futje",
attribs_desc:"Fut/Edito Tipare"
},
style:{
desc:"Edito Stilet CSS"
},
paste:{
paste_text_desc:"Ngjit si Tekst",
paste_word_desc:"Ngjit nga Word",
selectall_desc:"Zgjidhi t\u00EB gjitha"
},
paste_dlg:{
text_title:"P\u00EBrdor CTRL+V p\u00EBr t\u00EB ngjitur tekstin.",
text_linebreaks:"Ruaj linjat e reja",
word_title:"P\u00EBrdor CTRL+V p\u00EBr t\u00EB ngjitur tekstin."
},
table:{
desc:"Fut nj\u00EB tabel\u00EB t\u00EB re",
row_before_desc:"Fut rresht p\u00EBrpara",
row_after_desc:"Fut rresht pas",
delete_row_desc:"Fshi rreshtin",
col_before_desc:"Fut kolon\u00EB p\u00EBrpara",
col_after_desc:"Fut kolon\u00EB pas",
delete_col_desc:"Fshi kolon\u00EBn",
split_cells_desc:"Ndaji qelizat e bashkuara",
merge_cells_desc:"Bashkoji qelizat",
row_desc:"Tiparet e rreshtit",
cell_desc:"Tiparet e qeliz\u00EBs",
props_desc:"Tiparet e tabel\u00EBs",
paste_row_before_desc:"Ngjite rreshtin p\u00EBrpara",
paste_row_after_desc:"Ngjite rreshtin pas",
cut_row_desc:"Prit rreshtin",
copy_row_desc:"Kopjo rreshtin",
del:"Fshi tabel\u00EBn",
row:"Rresht",
col:"Kolon\u00EB",
cell:"Qeliz\u00EB"
},
autosave:{
unload_msg:"Ndryshimet q\u00EB keni b\u00EBr\u00EB do t\u00EB humbasin n\u00EBse largoheni nga kjo faqe."
},
fullscreen:{
desc:"Aktivizo/\u00E7aktivizo pamjen e plot\u00EB"
},
media:{
desc:"Fut / edito media",
edit:"Edito media"
},
fullpage:{
desc:"Tiparet e dokumentit"
},
template:{
desc:"Fut p\u00EBrmbajtje shabllon"
},
visualchars:{
desc:"Karakteret e kontrollit vizual: on/off."
},
spellchecker:{
desc:"Aktivizo/\u00E7aktivizo kontrolluesin e gabimeve",
menu:"Tiparet e kontrolluesit t\u00EB gabimeve",
ignore_word:"Injoro fjal\u00EBn",
ignore_words:"Injoroji t\u00EB gjitha",
langs:"Gjuh\u00EBt",
wait:"Ju lutem prisni...",
sug:"Sygjerimet",
no_sug:"Asnj\u00EB sygjerim",
no_mpell:"Nuk u gjet asnj\u00EB gabim."
},
pagebreak:{
desc:"Fut thyerje faqeje."
}}});