tinyMCE.addI18n('sk.xhtmlxtras_dlg',{
attribute_label_title:"N\u00E1zov",
attribute_label_id:"ID",
attribute_label_class:"Trieda",
attribute_label_style:"\u0160t\u00FDl",
attribute_label_cite:"Cit\u00E1cia",
attribute_label_datetime:"D\u00E1tum/\u010Das",
attribute_label_langdir:"Smer textu",
attribute_option_ltr:"Z \u013Eava do prava",
attribute_option_rtl:"Z prava do \u013Eava",
attribute_label_langcode:"Jazyk",
attribute_label_tabindex:"TabIndex",
attribute_label_accesskey:"AccessKey",
attribute_events_tab:"Akcie",
attribute_attrib_tab:"Atrib\u00FAty",
general_tab:"Hlavn\u00E9",
attrib_tab:"Attrib\u00FAty",
events_tab:"Akcie",
fieldset_general_tab:"Hlavn\u00E9 nastavenia",
fieldset_attrib_tab:"Prvok atrib\u00FAtov",
fieldset_events_tab:"Prvok akci\u00ED",
title_ins_element:"Prvok vlo\u017Eenia",
title_del_element:"Prvok zru\u0161enia",
title_acronym_element:"Prvok acronymu",
title_abbr_element:"Prvok skratky",
title_cite_element:"Prvok cit\u00E1cie",
remove:"Odstr\u00E1ni\u0165",
insert_date:"Vlo\u017Ei\u0165 aktu\u00E1lny d\u00E1tum/\u010Das",
option_ltr:"Z \u013Eava do prava",
option_rtl:"Z prava do \u013Eava",
attribs_title:"Vlo\u017Ei\u0165/editova\u0165 atrib\u00FAty"
});