tinyMCE.addI18n('ia.media_dlg',{
title:"\u63D2\u5165/\u7F16\u8F91 \u5A92\u4F53",
general:"\u57FA\u672C",
advanced:"\u9AD8\u7EA7",
file:"\u6587\u4EF6/\u5730\u5740",
list:"\u5217\u8868",
size:"\u5927\u5C0F",
preview:"\u9884\u89C8",
constrain_proportions:"\u4FDD\u6301\u6BD4\u4F8B",
type:"\u7C7B\u578B",
id:"Id",
name:"\u540D\u79F0",
class_name:"\u7C7B\u540D",
vspace:"\u5782\u76F4\u95F4\u8DDD",
hspace:"\u6C34\u5E73\u95F4\u8DDD",
play:"\u81EA\u52A8\u64AD\u653E",
loop:"\u5FAA\u73AF",
menu:"\u663E\u793A\u83DC\u5355",
quality:"\u54C1\u8D28",
scale:"\u7F29\u653E",
align:"\u5BF9\u9F50",
salign:"SAlign",
wmode:"WMode",
bgcolor:"\u80CC\u666F\u8272",
base:"\u57FA\u7EBF",
flashvars:"Flash\u53D8\u6570",
liveconnect:"SWLiveConnect",
autohref:"AutoHREF",
cache:"\u7F13\u5B58",
hidden:"\u9690\u85CF",
controller:"\u63A7\u5236\u53F0",
kioskmode:"Kiosk \u6A21\u5F0F",
playeveryframe:"\u9010\u5E27\u64AD\u653E",
targetcache:"\u76EE\u6807\u7F13\u5B58",
correction:"\u4FEE\u6B63",
enablejavascript:"\u542F\u7528 JavaScript",
starttime:"\u5F00\u59CB\u65F6\u95F4",
endtime:"\u7ED3\u675F\u65F6\u95F4",
href:"Href",
qtsrcchokespeed:"Choke speed",
target:"\u76EE\u6807",
volume:"\u97F3\u91CF",
autostart:"\u81EA\u52A8\u5F00\u59CB",
enabled:"\u542F\u7528",
fullscreen:"\u5168\u5C4F\u5E55",
invokeurls:"\u8C03\u7528\u7684URLs",
mute:"\u9759\u97F3",
stretchtofit:"\u7F29\u653E\u81F3\u5408\u9002\u5927\u5C0F",
windowlessvideo:"\u65E0\u7A97\u53E3\u89C6\u9891",
balance:"\u5E73\u8861",
baseurl:"Base URL",
captioningid:"\u5B57\u5E55 id",
currentmarker:"\u5F53\u524D\u6807\u7B7E",
currentposition:"\u5F53\u524D\u4F4D\u7F6E",
defaultframe:"\u9ED8\u8BA4\u5E27",
playcount:"\u64AD\u653E\u6B21\u6570",
rate:"\u7801\u7387",
uimode:"UI \u6A21\u5F0F",
flash_options:"Flash \u9009\u9879",
qt_options:"Quicktime \u9009\u9879",
wmp_options:"Windows media player \u9009\u9879",
rmp_options:"Real media player \u9009\u9879",
shockwave_options:"Shockwave \u9009\u9879",
autogotourl:"\u81EA\u52A8\u8DF3\u8F6C URL",
center:"\u5C45\u4E2D",
imagestatus:"\u56FE\u50CF\u72B6\u6001",
maintainaspect:"\u7EF4\u62A4\u72B6\u6001",
nojava:"No java",
prefetch:"\u9884\u8BFB",
shuffle:"\u968F\u673A",
console:"\u63A7\u5236\u53F0",
numloop:"\u5FAA\u73AF\u6B21\u6570",
controls:"\u63A7\u5236",
scriptcallbacks:"\u811A\u672C\u56DE\u6863",
swstretchstyle:"\u7F29\u653E\u6837\u5F0F",
swstretchhalign:"\u7F29\u653E\u81F3\u6C34\u5E73\u5BF9\u9F50",
swstretchvalign:"\u7F29\u653E\u81F3\u5782\u76F4\u5BF9\u9F50",
sound:"\u58F0\u97F3",
progress:"\u8FDB\u5EA6",
qtsrc:"QT Src",
qt_stream_warn:"Streamed rtsp resources should be added to the QT Src field under the advanced tab.\nYou should also add a non streamed version to the Src field..",
align_top:"\u9876\u90E8",
align_right:"\u5C45\u53F3",
align_bottom:"\u5E95\u90E8",
align_left:"\u5C45\u5DE6",
align_center:"\u5C45\u4E2D",
align_top_left:"\u9876\u90E8\u5C45\u5DE6",
align_top_right:"\u9876\u90E8\u5C45\u53F3",
align_bottom_left:"\u5E95\u90E8\u5C45\u5DE6",
align_bottom_right:"\u5E95\u90E8\u5C45\u53F3",
flv_options:"Flash \u89C6\u9891\u9009\u9879",
flv_scalemode:"\u7F29\u653E\u6A21\u5F0F",
flv_buffer:"\u7F13\u51B2",
flv_startimage:"\u5F00\u59CB\u56FE\u50CF",
flv_starttime:"\u5F00\u59CB\u65F6\u95F4",
flv_defaultvolume:"\u9ED8\u8BA4\u58F0\u97F3",
flv_hiddengui:"\u9690\u85CFGUI",
flv_autostart:"\u81EA\u52A8\u5F00\u59CB",
flv_loop:"\u5FAA\u73AF",
flv_showscalemodes:"\u663E\u793A\u7F29\u653E\u6A21\u5F0F",
flv_smoothvideo:"\u5E73\u6ED1\u89C6\u9891",
flv_jscallback:"JS \u56DE\u6A94"
});