tinyMCE.addI18n('sk.advimage_dlg',{
tab_general:"Hlavn\u00E9",
tab_appearance:"Vzh\u013Ead",
tab_advanced:"Roz\u0161\u00EDren\u00E9",
general:"Hlavn\u00E9 nastavenia",
title:"Titulok",
preview:"N\u00E1h\u013Ead",
constrain_proportions:"Zachova\u0165 pomer str\u00E1n",
langdir:"Smer textu",
langcode:"K\u00F3d jazyka",
long_desc:"Dlh\u00FD popis obr\u00E1zka",
style:"CSS \u0160t\u00FDl",
classes:"CSS Trieda",
ltr:"Z \u013Eava do prava",
rtl:"Z prava do \u013Eava",
id:"ID",
map:"Obr\u00E1zkov\u00E1 mapa",
swap_image:"Zmena obr\u00E1zka",
alt_image:"Alternat\u00EDvny obr\u00E1zok",
mouseover:"ak je kurzor nad obr\u00E1zkom",
mouseout:"ak kurzor od\u00EDde z obr\u00E1zka",
misc:"R\u00F4zne",
example_img:"Vzh\u013Ead n\u00E1h\u013Ead obr\u00E1zka",
missing_alt:"Naozaj chce\u0161 pokra\u010Dova\u0165 bez vlo\u017Een\u00E9ho popisu obr\u00E1zka? Bez popisu sa bude obr\u00E1zok nespr\u00E1vne zobrazova\u0165 v textov\u00FDch prehliada\u010Doch. Rovnako ak m\u00E1 u\u017E\u00EDvate\u013E vypnut\u00E9 zobrazenie obr\u00E1zkov alebo ak je u\u017E\u00EDvate\u013E nevidiaci, bude ma\u0165 probl\u00E9my rozpozna\u0165 obr\u00E1zok.",
dialog_title:"Vlo\u017Ei\u0165/editova\u0165 obr\u00E1zok",
src:"URL obr\u00E1zka",
alt:"Popis obr\u00E1zku",
list:"Zoznam obr\u00E1zkov",
border:"Okraj",
dimensions:"Rozmery",
vspace:"Vertik\u00E1lna medzera",
hspace:"Horizont\u00E1lna medzera",
align:"Usporiadanie",
align_baseline:"Z\u00E1klad\u0148a",
align_top:"Hore",
align_middle:"Uprostred",
align_bottom:"Dolu",
align_texttop:"Text hore",
align_textbottom:"Text dolu",
align_left:"V\u013Eavo",
align_right:"Vpravo",
image_list:"Zoznam obr\u00E1zkov"
});