tinyMCE.addI18n('sq.xhtmlxtras_dlg',{
attribute_label_title:"Titulli",
attribute_label_id:"ID",
attribute_label_class:"Klasa",
attribute_label_style:"Stili",
attribute_label_cite:"Citati",
attribute_label_datetime:"Data/Ora",
attribute_label_langdir:"Drejtimi i tekstit",
attribute_option_ltr:"Majtas-Djathtas",
attribute_option_rtl:"Djathtas-Majtas",
attribute_label_langcode:"Gjuha",
attribute_label_tabindex:"Indeksi i Tab",
attribute_label_accesskey:"Butoni i aksesit",
attribute_events_tab:"Ngjarjet",
attribute_attrib_tab:"Tiparet",
general_tab:"T\u00EB P\u00EBrgjithshme",
attrib_tab:"Tiparet",
events_tab:"Ngjarjet",
fieldset_general_tab:"Opsionet e P\u00EBrgjithshme",
fieldset_attrib_tab:"Tiparet e elementit",
fieldset_events_tab:"Ngjarjet e elementit",
title_ins_element:"Element Fut\u00EBs",
title_del_element:"Element Fshir\u00EBs",
title_acronym_element:"Element Akronim",
title_abbr_element:"Element Shkurtimi",
title_cite_element:"Element Citat",
remove:"Fshi",
insert_date:"Fut dat\u00EBn/or\u00EBn aktuale",
option_ltr:"Majtas-Djathtas",
option_rtl:"Djathtas-Majtas",
attribs_title:"Fut/Edito Tipare"
});