tinyMCE.addI18n('pt.advlink_dlg',{
title:"Inserir/editar hyperlink",
url:"URL do hyperlink",
target:"Alvo",
titlefield:"T\u00EDtulo",
is_email:"A URL digitada parece ser um endere\u00E7o de e-mail. Deseja acrescentar o prefixo necess\u00E1rio mailto:?",
is_external:"A URL digitada parece conduzir a um link externo. Deseja acrescentar o prefixo necess\u00E1rio http://?",
list:"Lista de hyperlinks",
general_tab:"Geral",
popup_tab:"Popup",
events_tab:"Eventos",
advanced_tab:"Avan\u00E7ado",
general_props:"Propriedades gerais",
popup_props:"Propriedades de popup",
event_props:"Eventos",
advanced_props:"Propriedades avan\u00E7adas",
popup_opts:"Op\u00E7\u00F5es",
anchor_names:"\u00C2ncoras",
target_same:"Abrir nesta janela/quadro",
target_parent:"Abrir na janela/quadro pai",
target_top:"Abrir na p\u00E1gina inteira (substitui todos os quadros)",
target_blank:"Abrir numa nova janela",
popup:"Popup javascript",
popup_url:"URL do popup",
popup_name:"Nome da janela",
popup_return:"Inserir \"return false\"",
popup_scrollbars:"Mostrar as barras de scroll",
popup_statusbar:"Mostrar a barra de status",
popup_toolbar:"Mostrar a barra de ferramentas",
popup_menubar:"Mostrar a barra de menu",
popup_location:"Mostrar a barra de endere\u00E7os",
popup_resizable:"Permitir altera\u00E7\u00E3o do tamanho da janela",
popup_dependent:"Dependente (Mozilla/Firefox apenas)",
popup_size:"Tamanho",
popup_position:"Posi\u00E7\u00E3o (X/Y)",
id:"Id",
style:"Estilo",
classes:"Classes",
target_name:"Nome do alvo",
langdir:"Dire\u00E7\u00E3o do texto",
target_langcode:"Idioma alvo",
langcode:"C\u00F3digo da idioma",
encoding:"Codifica\u00E7\u00E3o de caracteres",
mime:"Tipo MIME alvo",
rel:"Rela\u00E7\u00E3o p\u00E1gina/alvo",
rev:"Rela\u00E7\u00E3o alvo/p\u00E1gina",
tabindex:"Tabindex",
accesskey:"Chave de acesso",
ltr:"Da esquerda para a direita",
rtl:"Da direita para a esquerda",
link_list:"Lista de hyperlinks"
});