tinyMCE.addI18n('tr.emotions_dlg',{
title:"\u0130fade ekle",
desc:"\u0130fadeler",
cool:"Haval\u0131",
cry:"A\u011Fla",
embarassed:"Mah\u00E7up",
foot_in_mouth:"A\u011Fz\u0131 kulaklar\u0131nda",
frown:"Ka\u015F \u00E7atm\u0131\u015F",
innocent:"Masum",
kiss:"\u00D6p\u00FCc\u00FCk",
laughing:"Kahkaha",
money_mouth:"Parag\u00F6z",
sealed:"T\u0131p",
smile:"G\u00FCl\u00FCmse",
surprised:"\u015Ea\u015F\u0131rm\u0131\u015F",
tongue_out:"Dil \u00E7\u0131kar",
undecided:"Karars\u0131z",
wink:"G\u00F6z k\u0131rp",
yell:"Esne"
});