tinyMCE.addI18n({sr:{
common:{
edit_confirm:"\u017Delite li koristiti WYSIWYG na\u010Din rada za ovo tekstualno polje?",
apply:"Primjeni",
insert:"Ubaci",
update:"Obnovi",
cancel:"Odustani",
close:"Zatvori",
browse:"Pregled",
class_name:"Klasa",
not_set:"-- Nije postavljeno --",
clipboard_msg:"Kopiraj/Izre\u017Ei/Zalepi nije dostupno Mozilla i Firefox preglednicima.\nVi\u0161e informacija?",
clipboard_no_support:"Trenuta\u010Dno va\u0161 preglednik ne podr\u017Eava ovu opciju, poku\u0161ajte koristiti tipkovni\u010Dku kraticu.",
popup_blocked:"Oprostite, izgleda da je va\u0161 popup-blocker onemogu\u0107io prozor u sklopu ovog programa. Morate onemogu\u0107iti blokiranje popup prozora da bi u potpunosti iskoristili ovaj alat.",
invalid_data:"Gre\u0161ka: Une\u0161ene su nevaljane vrednosti, ozna\u010Dene su crvenom bojom.",
more_colors:"Vi\u0161e boja"
},
contextmenu:{
align:"Poravnavanje",
left:"Levo",
center:"Sredina",
right:"Desno",
full:"Puno"
},
insertdatetime:{
date_fmt:"%d.%m.%Y.",
time_fmt:"%H:%M:%S",
insertdate_desc:"Umetni datum",
inserttime_desc:"Umetni vreme",
months_long:"januar,februar,mart,april,maj,juni,juli,avgust,septembar,oktobar,novembar,decembar",
months_short:"jan,feb,mar,apr,maj,jun,jul,avg,sep,okt,nov,dec",
day_long:"nedelja,ponedjeljak,utorak,sreda,\u010Detvrtak,petak,subota,nedelja",
day_short:"ned,pon,uto,sre,\u010Det,pet,sub,ned"
},
print:{
print_desc:"Ispis"
},
preview:{
preview_desc:"Prikaz"
},
directionality:{
ltr_desc:"S leva na desno",
rtl_desc:"S desna na levo"
},
layer:{
insertlayer_desc:"Umetni novi sloj",
forward_desc:"Pomakni napred",
backward_desc:"Pomakni natrag",
absolute_desc:"Uklju\u010Di/isklju\u010Di apsolutno pozicioniranje",
content:"Novi sloj..."
},
save:{
save_desc:"Spremi",
cancel_desc:"Odustani od svih promjena"
},
nonbreaking:{
nonbreaking_desc:"Umetni razmak"
},
iespell:{
iespell_desc:"Pokreni provjeru pravopisa",
download:"Provjera pravopisa nije postavljena. Postaviti sada?"
},
advhr:{
advhr_desc:"Vodoravna crta"
},
emotions:{
emotions_desc:"Emocije"
},
searchreplace:{
search_desc:"Prona\u0111i",
replace_desc:"Prona\u0111i/Zameni"
},
advimage:{
image_desc:"Umetni/uredi sliku"
},
advlink:{
link_desc:"Insert/edit link"
},
xhtmlxtras:{
cite_desc:"Citat",
abbr_desc:"Kratica",
acronym_desc:"Akronim",
del_desc:"Brisanje",
ins_desc:"Unos",
attribs_desc:"Umetni/uredi atribute"
},
style:{
desc:"Uredi CSS"
},
paste:{
paste_text_desc:"Zalepi kao obi\u010Dni tekst",
paste_word_desc:"Zalepi iz Worda",
selectall_desc:"Odaberi sve"
},
paste_dlg:{
text_title:"Koristite CTRL+V na tipkovnici da zalepite tekst u prozor.",
text_linebreaks:"Zadr\u017Ei prelome",
word_title:"Koristite CTRL+V na tipkovnici da zalepite tekst u prozor."
},
table:{
desc:"Nova tablica",
row_before_desc:"Umetni redak iznad",
row_after_desc:"Umetni redak ispod",
delete_row_desc:"Izbri\u0161i redak",
col_before_desc:"Umetni stupac levo",
col_after_desc:"Umetni stupac desno",
delete_col_desc:"Ukloni stupac",
split_cells_desc:"Razdvoji spojene \u0107elije",
merge_cells_desc:"Spoji \u0107elije",
row_desc:"Svojstva retka",
cell_desc:"Svojstva \u0107elije",
props_desc:"Svojstva tablice",
paste_row_before_desc:"Zalepi redak iznad",
paste_row_after_desc:"Zalepi redak ispod",
cut_row_desc:"Izre\u017Ei redak",
copy_row_desc:"Kopiraj redak",
del:"Izbri\u0161i tablicu",
row:"Redak",
col:"Stupac",
cell:"\u0106elija"
},
autosave:{
unload_msg:"Promjene u dokumentu \u0107e biti izgubljene ako iza\u0111ete s ove stranice."
},
fullscreen:{
desc:"Uklju\u010Di/isklju\u010Di prikaz preko celog ekrana"
},
media:{
desc:"Insert / edit embedded media",
edit:"Edit embedded media"
},
fullpage:{
desc:"Svojstva dokumenta"
},
template:{
desc:"Umetni sadr\u017Eaj iz predlo\u017Eak"
},
visualchars:{
desc:"Vizuelni kontrolni znakovi uklju\u010Deni/isklju\u010Deni."
},
spellchecker:{
desc:"Uklju\u010Di/isklju\u010Di provjeru pravopisa",
menu:"Postavke provere pravopisa",
ignore_word:"Zanemari re\u010D",
ignore_words:"Zanemari sve",
langs:"Jezici",
wait:"Pri\u010Dekajte...",
sug:"Predlozi",
no_sug:"Nema predloga",
no_mpell:"Nije prona\u0111ena nijedna pravopisna gre\u0161ka."
},
pagebreak:{
desc:"Umetni prelom."
}}});