tinyMCE.addI18n('lt.advanced',{
style_select:"Stiliai",
font_size:"\u0160rifto dydis",
fontdefault:"\u0160rifto \u0161eima",
block:"Formatas",
paragraph:"Paragrafas",
div:"Div \u017Eym\u0117",
address:"Adresas",
pre:"I\u0161 anksto formatuotas",
h1:"Antra\u0161t\u0117 1",
h2:"Antra\u0161t\u0117 2",
h3:"Antra\u0161t\u0117 3",
h4:"Antra\u0161t\u0117 4",
h5:"Antra\u0161t\u0117 5",
h6:"Antra\u0161t\u0117 6",
blockquote:"Citatos blokas",
code:"Kodas",
samp:"Kodo pavyzdys",
dt:"Apibr\u0117\u017Eimo terminas",
dd:"Apibr\u0117\u017Eimo apra\u0161as",
bold_desc:"Pusjuodis (Ctrl+B)",
italic_desc:"Kursyvas (Ctrl+I)",
underline_desc:"Pabrauktas (Ctrl+U)",
striketrough_desc:"Perbrauktas",
justifyleft_desc:"Lygiuoti pagal kair\u0119",
justifycenter_desc:"Centruoti",
justifyright_desc:"Lygiuoti pagal de\u0161in\u0119",
justifyfull_desc:"Lygiuoti pagal abu kra\u0161tus",
bullist_desc:"Nesunumeruotas s\u0105ra\u0161as",
numlist_desc:"Sunumeruotas s\u0105ra\u0161as",
outdent_desc:"Atvirk\u0161tin\u0117 \u012Ftrauka",
indent_desc:"\u012Etrauka",
undo_desc:"At\u0161aukti (Ctrl+Z)",
redo_desc:"Gr\u0105\u017Einti (Ctrl+Y)",
link_desc:"\u012Eterpti/redaguoti nuorod\u0105",
unlink_desc:"Pa\u0161alinti nuorod\u0105",
image_desc:"\u012Eterpti/redaguoti paveiksl\u0117l\u012F",
cleanup_desc:"I\u0161valyti netvarking\u0105 kod\u0105",
code_desc:"Redaguoti HTML i\u0161eities kod\u0105",
sub_desc:"Apatinis indeksas",
sup_desc:"Vir\u0161utinis indeksas",
hr_desc:"\u012Eterpti horizontali\u0105 linij\u0105",
removeformat_desc:"Pa\u0161alinti formatavim\u0105",
custom1_desc:"J\u016Bs\u0173 apra\u0161as \u010Dia",
forecolor_desc:"Parinkti teksto spalv\u0105",
backcolor_desc:"Parinkti fono spalv\u0105",
charmap_desc:"\u012Eterpti nestandartin\u012F simbol\u012F",
visualaid_desc:"Kaitalioti gaires/nematom\u0173 element\u0173 rodym\u0105",
anchor_desc:"\u012Eterpti/redaguoti prierai\u0161\u0105",
cut_desc:"I\u0161kirpti",
copy_desc:"Kopijuoti",
paste_desc:"\u012Ed\u0117ti",
image_props_desc:"Paveiksl\u0117lio nustatymai",
newdocument_desc:"Naujas dokumentas",
help_desc:"Pagalba",
blockquote_desc:"Citatos blokas",
clipboard_msg:"Kopijavimas/I\u0161kirpimas/\u012Ed\u0117jimas negalimas Mozilla ir Firefox nar\u0161ykl\u0117se.\r\nAr norite daugiau informacijos apie \u0161i\u0105 problem\u0105?",
path:"Kelias",
newdocument:"Ar tikrai norite i\u0161valyti vis\u0105 turin\u012F?",
toolbar_focus:"Per\u0161okimas prie \u012Franki\u0173 juostos mygtuk\u0173 - Alt+Q, Per\u0161okimas prie redaktoriaus - Alt-Z, Per\u0161okimas prie element\u0173 kelio - Alt-X",
more_colors:"Daugiau spalv\u0173",
link_delta_width:"70"
});