tinyMCE.addI18n('tw.media_dlg',{
title:"\u63D2\u5165/\u7DE8\u8F2F\u5D4C\u5165\u5A92\u9AD4",
general:"\u4E00\u822C",
advanced:"\u9032\u968E",
file:"\u6587\u4EF6/\u7DB2\u5740",
list:"\u5217\u8868",
size:"\u5C3A\u5BF8",
preview:"\u9810\u89BD",
constrain_proportions:"\u5F37\u5236\u7B49\u6BD4\u4F8B",
type:"\u985E\u578B",
id:"Id",
name:"\u540D\u7A31",
class_name:"\u985E\u578B",
vspace:"\u6C34\u5E73\u9593\u8DDD",
hspace:"\u5782\u76F4\u9593\u8DDD",
play:"\u81EA\u52D5\u64AD\u653E",
loop:"\u91CD\u8986\u64AD\u653E",
menu:"\u986F\u793A\u529F\u80FD\u8868",
quality:"\u54C1\u8CEA",
scale:"\u6BD4\u4F8B",
align:"\u5C0D\u9F4A",
salign:"SAlign",
wmode:"\u8996\u7A97\u6A21\u5F0F",
bgcolor:"\u80CC\u666F\u8272",
base:"\u57FA\u5E95",
flashvars:"\u53C3\u6578",
liveconnect:"SWLiveConnect",
autohref:"\u81EA\u52D5\u9023\u7D50",
cache:"\u66AB\u5B58",
hidden:"\u96B1\u85CF",
controller:"\u63A7\u5236\u53F0",
kioskmode:"Kiosk\u6A21\u5F0F",
playeveryframe:"\u64AD\u653E\u6BCF\u4E00\u5F71\u683C",
targetcache:"\u76EE\u6A19\u66AB\u5B58",
correction:"\u6C92\u6709\u4FEE\u6B63",
enablejavascript:"\u555F\u7528JavaScript",
starttime:"\u958B\u59CB\u6642\u9593",
endtime:"\u7D50\u675F\u6642\u9593",
href:"\u9023\u7D50",
qtsrcchokespeed:"Choke speed",
target:"\u76EE\u6A19",
volume:"\u97F3\u91CF",
autostart:"\u81EA\u52D5\u958B\u59CB",
enabled:"\u555F\u7528",
fullscreen:"\u5168\u87A2\u5E55",
invokeurls:"\u76F8\u95DCURLs",
mute:"\u975C\u97F3",
stretchtofit:"\u62C9\u4F38",
windowlessvideo:"\u7121\u908A\u6846",
balance:"\u5E73\u8861",
baseurl:"\u57FA\u6E96URL",
captioningid:"Captioning id",
currentmarker:"\u7576\u524D\u6A19\u8A18",
currentposition:"\u7576\u524D\u4F4D\u7F6E",
defaultframe:"\u9810\u8A2D\u5F71\u683C",
playcount:"\u64AD\u653E\u8A08\u6578",
rate:"\u64AD\u65B9\u901F\u7387",
uimode:"\u9762\u677F\u6A21\u5F0F",
flash_options:"Flash\u9078\u9805",
qt_options:"Quicktime\u9078\u9805",
wmp_options:"Windows media player\u9078\u9805",
rmp_options:"Real media player\u9078\u9805",
shockwave_options:"Shockwave\u9078\u9805",
autogotourl:"\u81EA\u52D5\u8F49\u5230URL",
center:"\u4E2D\u5FC3",
imagestatus:"\u5716\u50CF\u72C0\u614B",
maintainaspect:"Maintain aspect",
nojava:"No java",
prefetch:"\u9810\u8B80\u6587\u4EF6",
shuffle:"Shuffle",
console:"\u63A7\u5236\u53F0",
numloop:"\u91CD\u8986\u6B21\u6578",
controls:"\u63A7\u5236\u5668",
scriptcallbacks:"\u8173\u672C\u56DE\u6A94",
swstretchstyle:"\u62C9\u5347\u6A21\u5F0F",
swstretchhalign:"\u6C34\u5E73\u62C9\u5347",
swstretchvalign:"\u5782\u76F4\u62C9\u5347",
sound:"\u8072\u97F3",
progress:"\u9032\u5EA6",
qtsrc:"QT Src",
qt_stream_warn:"\u4E32\u6D41\u5F0Frtsp\u8CC7\u6E90\u61C9\u8A72\u6DFB\u52A0\u5230\u201C\u9032\u968E\u201D\u4E2DQT Src\u3002\n\u540C\u6642\u6DFB\u52A0\u975E\u4E32\u6D41\u5F0F\u8CC7\u6E90\u5230Src\u3002",
align_top:"\u4E0A\u65B9",
align_right:"\u9760\u53F3",
align_bottom:"\u4E0B\u65B9",
align_left:"\u9760\u5DE6",
align_center:"\u4E2D\u9593",
align_top_left:"\u5DE6\u4E0A",
align_top_right:"\u53F3\u4E0A",
align_bottom_left:"\u5DE6\u4E0B",
align_bottom_right:"\u53F3\u4E0B",
flv_options:"Flash\u8996\u983B\u9078\u9805",
flv_scalemode:"Scale mode",
flv_buffer:"\u7DE9\u885D",
flv_startimage:"\u958B\u59CB\u756B\u9762",
flv_starttime:"\u958B\u59CB\u6642\u9593",
flv_defaultvolume:"\u9810\u8A2D\u97F3\u91CF",
flv_hiddengui:"\u96B1\u85CFGUI",
flv_autostart:"\u81EA\u52D5\u64AD\u653E",
flv_loop:"\u91CD\u8986",
flv_showscalemodes:"Show scale modes",
flv_smoothvideo:"\u5E73\u6ED1\u5716\u50CF",
flv_jscallback:"JS\u56DE\u6A94"
});