tinyMCE.addI18n('ro.xhtmlxtras_dlg',{
attribute_label_title:"Titlu",
attribute_label_id:"ID",
attribute_label_class:"Clas\u0103",
attribute_label_style:"Stil",
attribute_label_cite:"Citat",
attribute_label_datetime:"Dat\u0103/or\u0103",
attribute_label_langdir:"Direc\u0163ie text",
attribute_option_ltr:"De la st\u00E2nga la dreapta",
attribute_option_rtl:"De la dreapta la st\u00E2nga",
attribute_label_langcode:"Limb\u0103",
attribute_label_tabindex:"TabIndex",
attribute_label_accesskey:"Tast\u0103 de acces",
attribute_events_tab:"Evenimente",
attribute_attrib_tab:"Atribute",
general_tab:"General",
attrib_tab:"Atribute",
events_tab:"Evenimente",
fieldset_general_tab:"Set\u0103ri generale",
fieldset_attrib_tab:"Atribute element",
fieldset_events_tab:"Evenimente element",
title_ins_element:"Inserare element",
title_del_element:"\u015Etergere element",
title_acronym_element:"Acronim",
title_abbr_element:"Abreviere",
title_cite_element:"Citare",
remove:"Scoate",
insert_date:"Inserare dat\u0103/or\u0103 curent\u0103",
option_ltr:"De la st\u00E2nga la dreapta",
option_rtl:"De la dreapta la st\u00E2nga",
attribs_title:"Inserare atribute"
});