tinyMCE.addI18n('sq.advimage_dlg',{
tab_general:"T\u00EB P\u00EBrgjithshme",
tab_appearance:"Pamja",
tab_advanced:"T\u00EB Avancuara",
general:"T\u00EB P\u00EBrgjithshme",
title:"Titulli",
preview:"Paraqitje",
constrain_proportions:"Ruaj raportet",
langdir:"Drejtimi i gjuh\u00EBs",
langcode:"Kodi i gjuh\u00EBs",
long_desc:"Lidhja e p\u00EBrshkrimit t\u00EB gjat\u00EB",
style:"Stili",
classes:"Klasat",
ltr:"Majtas-Djathtas",
rtl:"Djathtas-Majtas",
id:"Id",
map:"Harta e fotos",
swap_image:"Nd\u00EBrro foto",
alt_image:"P\u00EBrshkrimi alternativ",
mouseover:"n\u00EB mouse-in sip\u00EBr",
mouseout:"n\u00EB mouse-in jasht\u00EB",
misc:"T\u00EB Ndryshme",
example_img:"Paraqitje e fotos",
missing_alt:"Jeni t\u00EB sigurt q\u00EB doni t\u00EB vazhdoni pa p\u00EBrfshir\u00EB nj\u00EB p\u00EBrshkrim alternativ? Pa t\u00EB, foto mund t\u00EB jet\u00EB e pa aksesueshme nga njer\u00EBz me shikim t\u00EB kufizuar, q\u00EB p\u00EBrdorin shfletues q\u00EB nuk i shfaqin fotot apo i kan\u00EB \u00E7aktivizuar ato.",
dialog_title:"Fut/edito foto",
src:"URL e fotos",
alt:"P\u00EBrshkrimi i fotos",
list:"Lista e fotove",
border:"Korniza",
dimensions:"P\u00EBrmasat",
vspace:"Hap\u00EBsira vertikale",
hspace:"Hap\u00EBsira horizontale",
align:"Drejtimi",
align_baseline:"Vij\u00EB fundore",
align_top:"Krye",
align_middle:"Mes",
align_bottom:"Fund",
align_texttop:"Sip\u00EBr tekstit",
align_textbottom:"Posht\u00EB tekstit",
align_left:"Majtas",
align_right:"Djathtas",
image_list:"Lista e fotove"
});