tinyMCE.addI18n({gl:{
common:{
edit_confirm:"\u00BFDesexa utiliza-lo modo WYSIWYG pra esta caixa de texto?",
apply:"Apricar",
insert:"Insertar",
update:"Actualizar",
cancel:"Cancelar",
close:"Cerrar",
browse:"Examinar",
class_name:"Clase",
not_set:"-- Ning\u00FAn --",
clipboard_msg:"Copiar/Cortar/Pegar non est\u00E1 disponible en Mozilla e Firefox.\n\u00BFDesexa obter mais informaci\u00F3n sobre de este asunto?",
clipboard_no_support:"O seu navegador non soporta estas funci\u00F3ns, use os atallos de teclado.",
popup_blocked:"O seu bloqueador de vent\u00E1s emerxentes deshabilitou unha vent\u00E1 que precisa pra o funcionamento da aplicaci\u00F3n. Precisa deshabilita-lo bloqueo de `popups` neste sitio pra utilizar \u00F3 m\u00E1ximo esta ferramenta.",
invalid_data:"Error: Introducidos valores non v\u00E1lidos, est\u00E1n marcados en vermello.",
more_colors:"Mais cores"
},
contextmenu:{
align:"Ali\u00F1amento",
left:"Esquerda",
center:"Centrado",
right:"Dereita",
full:"Xustificado"
},
insertdatetime:{
date_fmt:"%d-%m-%Y",
time_fmt:"%H:%M:%S",
insertdate_desc:"Insertar data",
inserttime_desc:"Insertar hora",
months_long:"Xaneito,Febreiro,Marzo,Abril,Maio,Xu\u00F1o,Xullo,Agosto,Setembro,Outubro,Novembro,Decembro",
months_short:"Xan,Feb,Mar,Abr,Mai,Xu\u00F1,Xul,Ago,Set,Out,Nov,Dec",
day_long:"Domingo,Luns,Martes,M\u00E9rcores,Xoves,Venres,S\u00E1bado,Domingo",
day_short:"Dom,Lun,Mar,M\u00E9r,Xov,Ver,S\u00E1b,Dom"
},
print:{
print_desc:"Imprimir"
},
preview:{
preview_desc:"Vista previa"
},
directionality:{
ltr_desc:"Direcci\u00F3n esquerda a dereita",
rtl_desc:"Direcci\u00F3n dereita a esquerda"
},
layer:{
insertlayer_desc:"Insertar nova capa",
forward_desc:"Avanzar",
backward_desc:"Recuar",
absolute_desc:"Posici\u00F3n absoluta",
content:"Nova capa..."
},
save:{
save_desc:"Gardar",
cancel_desc:"Cancelar todo-los cambios"
},
nonbreaking:{
nonbreaking_desc:"Insertar espacio non colapsable"
},
iespell:{
iespell_desc:"Corrector ortogr\u00E1fico",
download:"Non se detectou 'ieSpell'. \u00BFDesexa instala-lo agora?"
},
advhr:{
advhr_desc:"Regra horizontal"
},
emotions:{
emotions_desc:"Emoticones"
},
searchreplace:{
search_desc:"Buscar",
replace_desc:"Buscar/Reemplazar"
},
advimage:{
image_desc:"Insertar/editar imaxe"
},
advlink:{
link_desc:"Insertar/editar hiperv\u00EDnculo"
},
xhtmlxtras:{
cite_desc:"Cita",
abbr_desc:"Abreviatura",
acronym_desc:"Acr\u00F3nimo",
del_desc:"Borrado",
ins_desc:"Inserci\u00F3n",
attribs_desc:"Insertar/Editar atributos"
},
style:{
desc:"Editar Estilo CSS"
},
paste:{
paste_text_desc:"Pegar como texto simple",
paste_word_desc:"Pegar desde Word",
selectall_desc:"Seleccionar todo"
},
paste_dlg:{
text_title:"Use CTRL+V no teclado pra pega-lo texto na vent\u00E1.",
text_linebreaks:"Manter salto de li\u00F1as",
word_title:"Use CTRL+V no teclado pra pega-lo texto na vent\u00E1."
},
table:{
desc:"Inserta unha nova t\u00E1boa",
row_before_desc:"Insertar fila (antes)",
row_after_desc:"Insertar fila (desp\u00F3is)",
delete_row_desc:"Suprimir fila",
col_before_desc:"Insertar columna (antes)",
col_after_desc:"Insertar columna (desp\u00F3is)",
delete_col_desc:"Suprimir columna",
split_cells_desc:"Dividir celdas",
merge_cells_desc:"Vincular celdas",
row_desc:"Propiedades da fila",
cell_desc:"Propiedades da celda",
props_desc:"Propiedades da t\u00E1boa",
paste_row_before_desc:"Pegar filas (antes)",
paste_row_after_desc:"Pegar filas (desp\u00F3is)",
cut_row_desc:"Cortar fila",
copy_row_desc:"Copiar fila",
del:"Eliminar t\u00E1boa",
row:"Fila",
col:"Columna",
cell:"Celda"
},
autosave:{
unload_msg:"Os cambios realizados perderanse se sae desta p\u00E1xina."
},
fullscreen:{
desc:"Cambiar a modo Pantalla Completa"
},
media:{
desc:"Insertar/editar medio embebido",
edit:"Editar medio embebido"
},
fullpage:{
desc:"Propiedades do documento"
},
template:{
desc:"Insertar contido de plantilla predefinida"
},
visualchars:{
desc:"Caracteres de control ON/OFF."
},
spellchecker:{
desc:"Conmutar corrector ortogr\u00E1fico",
menu:"Configuraci\u00F3n de corrector ortogr\u00E1fico",
ignore_word:"Ignorar verba",
ignore_words:"Ignorar todo",
langs:"Idiomas",
wait:"Agarde...",
sug:"Suxerencias",
no_sug:"Sen suxerencias",
no_mpell:"Non se atoparon erros."
},
pagebreak:{
desc:"Insertar fin de p\u00E1xina"
}}});