tinyMCE.addI18n('ms.advlink_dlg',{
title:"Sisip/sunting pautan",
url:"Pautan URL",
target:"Sasaran",
titlefield:"Tajuk",
is_email:"URL yang dimasukkan adalah alamat emel, tambah \"mailto\": di awalan?",
is_external:"URL yang dimasukkan adalah pautan luar, tambah \"http://\" di awalan?",
list:"Senarai pautan",
general_tab:"Am",
popup_tab:"Popup",
events_tab:"Peristiwa",
advanced_tab:"Lanjutan",
general_props:"Alatan am",
popup_props:"Alatan Popup",
event_props:"Peristiwa",
advanced_props:"Alatan lanjutan",
popup_opts:"Pilihan",
anchor_names:"Sauh",
target_same:"Buka tetingkap ini",
target_parent:"Buka dalam tetingkap yang lain",
target_top:"Buka bingkaian atas (gantikan kesemua bingkai)",
target_blank:"Buka dalam tetingkap baru.",
popup:"Popup Javascript ",
popup_url:"Popup URL",
popup_name:"Nama tetingkap",
popup_return:"Masukkan 'return false'",
popup_scrollbars:"Tunjuk bar gulung",
popup_statusbar:"Tunjuk bar status",
popup_toolbar:"Tunjuk bar alatan",
popup_menubar:"Tunjuk bar menu",
popup_location:"Tunjuk bar lokasi",
popup_resizable:"Jadikan tetingkap boleh diubahsuai",
popup_dependent:"Tanggungan (Hanya Mozilla/Firefox)",
popup_size:"Saiz",
popup_position:"Posisi (X/Y)",
id:"Id",
style:"Gaya",
classes:"Kelas-kelas",
target_name:"Nama sasaran",
langdir:"Arah bahasa",
target_langcode:"Bahasa sasaran",
langcode:"Kod bahasa",
encoding:"Sasaran enkod perkataan",
mime:"Sasaran jenis MIME",
rel:"Kaitan halaman kepada sasaran",
rev:"Kaitan sasaran kepada halaman",
tabindex:"Tanda indeks",
accesskey:"Kunci akses",
ltr:"Kiri ke kanan",
rtl:"Kanan ke kiri",
link_list:"Senarai pautan"
});