tinyMCE.addI18n('lt.xhtmlxtras_dlg',{
attribute_label_title:"Pavadinimas",
attribute_label_id:"ID",
attribute_label_class:"Klas\u0117",
attribute_label_style:"Stilius",
attribute_label_cite:"Citata",
attribute_label_datetime:"Data/Laikas",
attribute_label_langdir:"Kalbos teksto kryptis",
attribute_option_ltr:"I\u0161 kair\u0117s \u012F de\u0161in\u0119",
attribute_option_rtl:"I\u0161 de\u0161in\u0117s \u012F kair\u0119",
attribute_label_langcode:"Kalba",
attribute_label_tabindex:"Tabuliavimo indeksas",
attribute_label_accesskey:"Prieigos klavi\u0161as",
attribute_events_tab:"\u012Evykiai",
attribute_attrib_tab:"Atributai",
general_tab:"Bendra",
attrib_tab:"Atributai",
events_tab:"\u012Evykiai",
fieldset_general_tab:"Bendri nustatymai",
fieldset_attrib_tab:"Elemento atributai",
fieldset_events_tab:"Elemento \u012Fvykiai",
title_ins_element:"\u012Eterpimo elementas",
title_del_element:"Pa\u0161alinimo elementas",
title_acronym_element:"Akronimo elementas",
title_abbr_element:"Santrumpos elementas",
title_cite_element:"Citatos elementas",
remove:"Pa\u0161alinti",
insert_date:"\u012Eterpti dabartin\u0119 dat\u0105/laik\u0105",
option_ltr:"I\u0161 kair\u0117s \u012F de\u0161in\u0119",
option_rtl:"I\u0161 de\u0161in\u0117s \u012F kair\u0119",
attribs_title:"\u012Eterpti/Redaguoti atributus"
});