tinyMCE.addI18n('ca.emotions_dlg',{
title:"Insereix emoticona",
desc:"Emoticones",
cool:"Ben parit",
cry:"Plor",
embarassed:"Vergonya",
foot_in_mouth:"Muts i a la g\u00E0bia",
frown:"Indiferent",
innocent:"Innocent",
kiss:"Pet\u00F3",
laughing:"Rialla",
money_mouth:"Boca de diner",
sealed:"Segellada",
smile:"Somriure",
surprised:"Sorpresa",
tongue_out:"Treu la llengua",
undecided:"Indecisa",
wink:"Pica l'ullet",
yell:"Crit"
});