tinyMCE.addI18n('se.xhtmlxtras_dlg',{
attribute_label_title:"Titel",
attribute_label_id:"ID",
attribute_label_class:"Klass",
attribute_label_style:"Stil",
attribute_label_cite:"Citat",
attribute_label_datetime:"Datum/Tid",
attribute_label_langdir:"Skriftriktning",
attribute_option_ltr:"V\u00E4nster till h\u00F6ger",
attribute_option_rtl:"H\u00F6ger till v\u00E4nster",
attribute_label_langcode:"Spr\u00E5k",
attribute_label_tabindex:"Tabbindex",
attribute_label_accesskey:"Snabbtangent",
attribute_events_tab:"H\u00E4ndelser",
attribute_attrib_tab:"Attribut",
general_tab:"Generellt",
attrib_tab:"Attribut",
events_tab:"H\u00E4ndelser",
fieldset_general_tab:"Generella inst\u00E4llningar",
fieldset_attrib_tab:"Attribut",
fieldset_events_tab:"H\u00E4ndelser",
title_ins_element:"Markera som tillagt",
title_del_element:"Markera som struket",
title_acronym_element:"Akronym",
title_abbr_element:"F\u00F6rkortning",
title_cite_element:"Citat",
remove:"Radera",
insert_date:"Infoga nuvarande datum och tid",
option_ltr:"V\u00E4nster till h\u00F6ger",
option_rtl:"H\u00F6ger till v\u00E4nster",
attribs_title:"Redigera attribut"
});