tinyMCE.addI18n('br.emotions_dlg',{
title:"Inserir emoticon",
desc:"Emoticons",
cool:"Fixe",
cry:"Chor\u00E3o",
embarassed:"Embara\u00E7ado",
foot_in_mouth:"Disse asneira",
frown:"Decep\u00E7\u00E3o",
innocent:"Inocente",
kiss:"Beijo",
laughing:"Riso",
money_mouth:"Avarez",
sealed:"Boca Fechada",
smile:"Sorriso",
surprised:"Surpresa",
tongue_out:"L\u00EDngua de fora",
undecided:"Indeciso",
wink:"Piscadela",
yell:"Irado"
});