tinyMCE.addI18n('vi.advimage_dlg',{
tab_general:"C\u01A1 b\u1EA3n",
tab_appearance:"Hi\u1EC3n th\u1ECB",
tab_advanced:"N\u00E2ng cao",
general:"C\u01A1 b\u1EA3n",
title:"Ti\u00EAu \u0111\u1EC1",
preview:"Xem tr\u01B0\u1EDBc",
constrain_proportions:"Gi\u1EEF \u0111\u00FAng t\u1EC9 l\u1EC7 k\u00EDch th\u01B0\u1EDBc",
langdir:"Language direction",
langcode:"Language code",
long_desc:"Long description link",
style:"\u0110\u1ECBnh d\u1EA1ng ki\u1EC3u",
classes:"Classes",
ltr:"Left to right",
rtl:"Right to left",
id:"Id",
map:"Image map",
swap_image:"Swap image",
alt_image:"Alternative image",
mouseover:"for mouse over",
mouseout:"for mouse out",
misc:"Miscellaneous",
example_img:"Appearance preview image",
missing_alt:"H\u00ECnh \u1EA3nh ch\u01B0a c\u00F3 m\u00F4 t\u1EA3. M\u00F4 t\u1EA3 cho h\u00ECnh \u1EA3nh \u0111\u01B0\u1EE3c ng\u01B0\u1EDDi s\u1EED d\u1EE5ng th\u1EA5y khi tr\u00ECnh duy\u1EC7t c\u1EE7a h\u1ECD kh\u00F4ng hi\u1EC3n th\u1ECB \u0111\u01B0\u1EE3c h\u00ECnh \u1EA3nh. B\u1EA1n mu\u1ED1n ti\u1EBFp t\u1EE5c ch\u00E8n h\u00ECnh \u1EA3nh kh\u00F4ng c\u00F3 m\u00F4 t\u1EA3 ?",
dialog_title:"Ch\u00E8n/thay \u0111\u1ED5i h\u00ECnh \u1EA3nh",
src:"\u0110\u1ECBa ch\u1EC9 file h\u00ECnh \u1EA3nh",
alt:"M\u00F4 t\u1EA3 h\u00ECnh \u1EA3nh",
list:"Image list",
border:"Border",
dimensions:"Dimensions",
vspace:"Vertical space",
hspace:"Horizontal space",
align:"Alignment",
align_baseline:"Baseline",
align_top:"Top",
align_middle:"Middle",
align_bottom:"Bottom",
align_texttop:"Text top",
align_textbottom:"Text bottom",
align_left:"Left",
align_right:"Right",
image_list:"Image list"
});