tinyMCE.addI18n('it.advlink_dlg',{
title:"Inserisci/modifica link",
url:"URL collegamento",
target:"Target",
titlefield:"Titolo",
is_email:"L'URL inserito sembra essere un indirizzo email. Aggiungere il necessario prefisso mailto: ?",
is_external:"L'URL inserito sembra essere un link esterno. Aggiungere il necessario prefisso http:// ?",
list:"Lista collegamenti",
general_tab:"Generale",
popup_tab:"Popup",
events_tab:"Eventi",
advanced_tab:"Avanzate",
general_props:"Propriet\u00E0 generali",
popup_props:"Propriet\u00E0 popup",
event_props:"Eventi",
advanced_props:"Propriet\u00E0 avanzate",
popup_opts:"Opzioni",
anchor_names:"Ancore",
target_same:"Apri in questa finestra / cornice",
target_parent:"Apri nella finestra / cornice genitore",
target_top:"Apri nella cornice superiore (sostituisce tutte le cornici)",
target_blank:"Apri in una nuova finestra",
popup:"Popup Javascript",
popup_url:"URL Popup",
popup_name:"Nome finestra",
popup_return:"Inserisci 'return false'",
popup_scrollbars:"Mostra barre di scorrimento",
popup_statusbar:"Mostra barra di stato",
popup_toolbar:"Mostra barre strumenti",
popup_menubar:"Mostra barra menu",
popup_location:"Mostra barra navigazione",
popup_resizable:"Rendi la finestra ridimensionabile",
popup_dependent:"Dipendente (Solo in Mozilla/Firefox)",
popup_size:"Dimensioni",
popup_position:"Posizione (X/Y)",
id:"Id",
style:"Stile",
classes:"Classe",
target_name:"Nome target",
langdir:"Direzione del testo",
target_langcode:"Lingua del target",
langcode:"Lingua",
encoding:"Codifica carattere del target",
mime:"Tipo MIME del target",
rel:"Relazione da pagina a target",
rev:"Relazione da target a pagina",
tabindex:"Indice tabulazione",
accesskey:"Carattere di accesso",
ltr:"Sinistra verso destra",
rtl:"Destra verso sinistra",
link_list:"Lista collegamenti"
});