tinyMCE.addI18n('se.emotions_dlg',{
title:"Infoga smiley",
desc:"Smileys",
cool:"Cool",
cry:"Gr\u00E5ter",
embarassed:"Sk\u00E4ms",
foot_in_mouth:"Foten i munnen",
frown:"Rynkar p\u00E5 n\u00E4san",
innocent:"Oskyldig",
kiss:"Kyss",
laughing:"Skrattande",
money_mouth:"Guld i mun",
sealed:"Tyst",
smile:"Glad",
surprised:"F\u00F6rv\u00E5nad",
tongue_out:"Tungan ute",
undecided:"Obest\u00E4md",
wink:"Fl\u00F6rt",
yell:"Skrikandes"
});