tinyMCE.addI18n('ro.advanced',{
style_select:"Stiluri",
font_size:"M\u0103rime font",
fontdefault:"Font",
block:"Format",
paragraph:"Paragraf",
div:"Div",
address:"Adres\u0103",
pre:"Preformatat",
h1:"Titlu 1",
h2:"Titlu 2",
h3:"Titlu 3",
h4:"Titlu 4",
h5:"Titlu 5",
h6:"Titlu 6",
blockquote:"Citat",
code:"Cod",
samp:"Mostr\u0103 de cod",
dt:"Termen definit ",
dd:"Defini\u0163ie",
bold_desc:"\u00CEngro\u015Fat (Ctrl+B)",
italic_desc:"Italic (Ctrl+I)",
underline_desc:"Subliniat (Ctrl+U)",
striketrough_desc:"T\u0103iat",
justifyleft_desc:"Aliniere la st\u00E2nga",
justifycenter_desc:"Centrare",
justifyright_desc:"Aliniere la dreapta",
justifyfull_desc:"Aliniere pe toat\u0103 l\u0103\u0163imea",
bullist_desc:"List\u0103 neordonat\u0103",
numlist_desc:"List\u0103 ordonat\u0103",
outdent_desc:"De-indenteaz\u0103",
indent_desc:"Indenteaz\u0103",
undo_desc:"Undo (Ctrl+Z)",
redo_desc:"Ref\u0103 (Ctrl+Y)",
link_desc:"Inserare/editare leg\u0103tur\u0103",
unlink_desc:"\u015Eterge leg\u0103tura",
image_desc:"Inserare/editare imagine",
cleanup_desc:"Cur\u0103\u0163are cod",
code_desc:"Editare surs\u0103 HTML",
sub_desc:"Subscript",
sup_desc:"Superscript",
hr_desc:"Insereaz\u0103 linie orizontal\u0103",
removeformat_desc:"Anuleaz\u0103 formatarea",
custom1_desc:"Descriere ...",
forecolor_desc:"Culoare text",
backcolor_desc:"Culoare fundal",
charmap_desc:"Inserare caracter special",
visualaid_desc:"Comut\u0103 ghidajele/elementele invizibile",
anchor_desc:"Inserare/editare ancor\u0103",
cut_desc:"Taie",
copy_desc:"Copiaz\u0103",
paste_desc:"Lipe\u015Fte",
image_props_desc:"Detalii imagine",
newdocument_desc:"Document nou",
help_desc:"Autor",
blockquote_desc:"Citat",
clipboard_msg:"Copierea/T\u0103ierea/Lipirea nu sunt disponibile \u00EEn Mozilla \u015Fi Firefox.\nDori\u0163i mai multe informa\u0163ii despre aceast\u0103 problem\u0103?",
path:"Cale",
newdocument:"Sigur dori\u0163i s\u0103 \u015Fterge\u0163i tot?",
toolbar_focus:"S\u0103ri\u0163i la instrumente - Alt+Q, S\u0103ri\u0163i la editor - Alt-Z, S\u0103ri\u0163i la cale - Alt-X",
more_colors:"Mai multe culori"
});