tinyMCE.addI18n({nn:{
common:{
edit_confirm:"Vil du bruke WYSIWYG-editoren for dette tekstfeltet?",
apply:"Legg til",
insert:"Set inn",
update:"Oppdater",
cancel:"Avbryt",
close:"Stopp",
browse:"Bla gjennom",
class_name:"Klasse",
not_set:"--ikkje sett--",
clipboard_msg:"Klipp ut / Kopier /Lim inn fungerer ikkje i Mozilla og Firefox. Vil du vite meir om dette?",
clipboard_no_support:"For tida ikkje st\u00F8tta av nettlesaren din, bruk tastatursnarveger i staden.",
popup_blocked:"Orsak, det er registrert at du har popup-sperre aktivert i nettlesaren. Du m\u00E5 oppheve popup-sperra for nettstaden for \u00E5 f\u00E5 tilgang til dette verktyet",
invalid_data:"Feil: Ugyldige verdiar er skrivne inn, desse er merka med raudt",
more_colors:"Fleire fargar"
},
contextmenu:{
align:"Justering",
left:"Venstre",
center:"Midtstill",
right:"H\u00F8gre",
full:"Full"
},
insertdatetime:{
date_fmt:"%Y-%m-%d",
time_fmt:"%H:%M:%S",
insertdate_desc:"Lim inn dato",
inserttime_desc:"Lim inn tid",
months_long:"januar,februar,mars,april,mai,juni,juli,august,september,oktober,november,desember",
months_short:"jan,feb,mar,apr,mai,jun,jul,aug,sep,oct,nov,des",
day_long:"sundag,mandag,tirsdag,onsdag,torsdag,fredag,laurdag,sundag",
day_short:"sun,man,tir,ons,tor,fre,lau,sun"
},
print:{
print_desc:"Skriv u"
},
preview:{
preview_desc:"F\u00F8rehandsvisni"
},
directionality:{
ltr_desc:"Retning venstre mot h\u00F8gre",
rtl_desc:"Retning h\u00F8gre mot venstre"
},
layer:{
insertlayer_desc:"Set inn nytt lag",
forward_desc:"Flytt framover",
backward_desc:"Flytt bakover",
absolute_desc:"Sl\u00E5 p\u00E5/av absolutt plassering",
content:"Nytt lag..."
},
save:{
save_desc:"Lagre",
cancel_desc:"Kanseller alle endringar"
},
nonbreaking:{
nonbreaking_desc:"Set inn hardt mellomrom"
},
iespell:{
iespell_desc:"K\u00F8yrer kontroll av rettskriving",
download:"ieSpell ikkje funnen. \u00D8nskjer du \u00E5 installere ieSpell no?"
},
advhr:{
advhr_desc:"Horisontal linje"
},
emotions:{
emotions_desc:"Hum\u00F8rfjes"
},
searchreplace:{
search_desc:"S\u00F8k",
replace_desc:"S\u00F8k/Erstatt"
},
advimage:{
image_desc:"Set inn / endre bilete"
},
advlink:{
link_desc:"Set inn / endre lenkje"
},
xhtmlxtras:{
cite_desc:"Sitat",
abbr_desc:"Forkorting",
acronym_desc:"Akronym",
del_desc:"Sletting",
ins_desc:"Innsetjing",
attribs_desc:"Set inn / Endre eigenskapar"
},
style:{
desc:"Rediger CSS-stil"
},
paste:{
paste_text_desc:"Lim inn som vanleg tekst",
paste_word_desc:"Lim inn fr\u00E5 Word",
selectall_desc:"Marker al"
},
paste_dlg:{
text_title:"Bruk CTRL+V p\u00E5 tastaturet for \u00E5 lime inn i dette vindauget.",
text_linebreaks:"Behald tekstbryting",
word_title:"Bruk CTRL+V p\u00E5 tastaturet for \u00E5 lime inn i dette vindauget."
},
table:{
desc:"Set inn ein ny tabell",
row_before_desc:"Set inn rad framfor",
row_after_desc:"Set inn rad etter",
delete_row_desc:"Fjern rad",
col_before_desc:"Set inn kolonne framfor",
col_after_desc:"Set inn kolonne etter",
delete_col_desc:"Fjern kolonne",
split_cells_desc:"Del celler",
merge_cells_desc:"Sl\u00E5 saman celler",
row_desc:"Radeigenskapar",
cell_desc:"Celleegenskapar",
props_desc:"Tabelleigenskapar",
paste_row_before_desc:"Lim inn rad framfor",
paste_row_after_desc:"Lim inn rad etter",
cut_row_desc:"Fjern rad",
copy_row_desc:"Kopier rad",
del:"Slett tabell",
row:"Rad",
col:"Kolonne",
cell:"Celle"
},
autosave:{
unload_msg:"Endringane du gjorde g\u00E5r tapt om du forl\u00E8t denne sida!"
},
fullscreen:{
desc:"Skift til/fr\u00E5 fullskjermmodus"
},
media:{
desc:"Set inn / rediger inkludert objekt",
edit:"Endre innsett objekt"
},
fullpage:{
desc:"Dokumenteigenskapar"
},
template:{
desc:"Set inn f\u00F8rehandsdefinert malinnhald"
},
visualchars:{
desc:"Visuelle konktrollteikn p\u00E5/av"
},
spellchecker:{
desc:"Stavekontroll p\u00E5/av",
menu:"Vis meny",
ignore_word:"Ignorer ord",
ignore_words:"Ignorer alt",
langs:"Spr\u00E5k",
wait:"Ver venleg og vent...",
sug:"Framlegg",
no_sug:"Inga framlegg",
no_mpell:"Inga stavefeil funne."
},
pagebreak:{
desc:"Set inn sideskift"
}}});