tinyMCE.addI18n('se.advanced',{
style_select:"Stilar",
font_size:"Fontstorlek",
fontdefault:"Fontfamilj",
block:"Format",
paragraph:"Paragraf",
div:"Div",
address:"Adress",
pre:"F\u00F6rformaterad",
h1:"Rubrik 1",
h2:"Rubrik 2",
h3:"Rubrik 3",
h4:"Rubrik 4",
h5:"Rubrik 5",
h6:"Rubrik 6",
blockquote:"Blockcitat",
code:"Kodblock",
samp:"Kodexempel",
dt:"Definitionsterm",
dd:"Definitionsbeskrivning",
bold_desc:"Fet (Ctrl+B)",
italic_desc:"Kursiv (Ctrl+I)",
underline_desc:"Understruken (Ctrl+U)",
striketrough_desc:"Genomstruken",
justifyleft_desc:"V\u00E4nsterst\u00E4lld",
justifycenter_desc:"Centrera",
justifyright_desc:"H\u00F6gerst\u00E4lld",
justifyfull_desc:"Justera",
bullist_desc:"Punktlista",
numlist_desc:"Nummerlista",
outdent_desc:"Drag tillbaka",
indent_desc:"Indrag",
undo_desc:"\u00C5ngra (Ctrl+Z)",
redo_desc:"G\u00F6r om (Ctrl+Y)",
link_desc:"Infoga/redigera l\u00E4nk",
unlink_desc:"Ta bort l\u00E4nk",
image_desc:"Infoga/redigera bild",
cleanup_desc:"St\u00E4da upp i k\u00E4llkoden",
code_desc:"Redigera HTML k\u00E4llkoden",
sub_desc:"Subscript",
sup_desc:"Superscript",
hr_desc:"Infoga horisontell skiljelinje",
removeformat_desc:"Ta bort formatering",
forecolor_desc:"V\u00E4lj textf\u00E4rg",
backcolor_desc:"V\u00E4lj bakgrundsf\u00E4rg",
charmap_desc:"Infoga specialtecken",
visualaid_desc:"Visa/d\u00F6lj visuella hj\u00E4lpmedel",
anchor_desc:"Infoga/redigera bokm\u00E4rke",
cut_desc:"Klipp ut",
copy_desc:"Kopiera",
paste_desc:"Klistra in",
image_props_desc:"Bildinst\u00E4llningar",
newdocument_desc:"Nytt dokument",
help_desc:"Hj\u00E4lp",
blockquote_desc:"Blockcitat",
clipboard_msg:"Kopiera/klipp ut/klistra in \u00E4r inte tillg\u00E4ngligt i din webbl\u00E4sare.\nVill du veta mer om detta?",
path:"Element",
newdocument:"\u00C4r du s\u00E4ker p\u00E5 att du vill radera allt inneh\u00E5ll?",
toolbar_focus:"Hoppa till verktygsf\u00E4ltet - Alt+Q, Hoppa till redigeraren - Alt-Z, Hoppa till element listan - Alt-X"
});