tinyMCE.addI18n({lt:{
common:{
edit_confirm:"Ar norite naudoti tekst\u0173 redaktoriaus re\u017Eim\u0105 \u0161iam teksto redagavimo langui?",
apply:"Taikyti",
insert:"\u012Eterpti",
update:"Atnaujinti",
cancel:"Atsisakyti",
close:"U\u017Everti",
browse:"Nar\u0161yti",
class_name:"Klas\u0117",
not_set:"-- Nenurodyta --",
clipboard_msg:"Kopijavimas/i\u0161kirpimas/\u012Fd\u0117jimas paspaudus \u0161\u012F mygtuk\u0105 negalimas Mozilla ir Firefox nar\u0161ykl\u0117se.\nNukopijuoti galima paspaudus: Ctrl + C, i\u0161kirpti: Ctrl + X, \u012Fd\u0117ti: Ctrl + V.\nAr norite daugiau informacijos apie \u0161i\u0105 problem\u0105?",
clipboard_no_support:"\u0160i nar\u0161ykl\u0117 nepalaiko \u0161io veikimo, tod\u0117l naudokite klaviat\u016Bros spar\u010Diuosius klavi\u0161us.",
popup_blocked:"Atsipra\u0161ome, ta\u010Diau pasteb\u0117jome, kad j\u016Bs\u0173 i\u0161kylan\u010Di\u0173 lang\u0173 blokavimo programa i\u0161jung\u0117 lang\u0105, kuris teikia aplikacijai funkcionalum\u0105. Tur\u0117tum\u0117te atjungti i\u0161kylan\u010Di\u0173 lang\u0173 blokavim\u0105 \u0161iam tinklalapiui, kad i\u0161naudotum\u0117te visas galimybes.",
invalid_data:"Klaida: Blogai \u012Fvestos reik\u0161m\u0117s, kurios pa\u017Eym\u0117tos raudonai.",
more_colors:"Daugiau spalv\u0173"
},
contextmenu:{
align:"Lygiavimas",
left:"Kair\u0117je",
center:"Centre",
right:"De\u0161in\u0117je",
full:"I\u0161 abiej\u0173 pusi\u0173"
},
insertdatetime:{
date_fmt:"%Y-%m-%d",
time_fmt:"%H:%M:%S",
insertdate_desc:"\u012Eterpti dat\u0105",
inserttime_desc:"\u012Eterpti laik\u0105",
months_long:"Sausis,Vasaris,Kovas,Balandis,Gegu\u017E\u0117,Bir\u017Eelis,Liepa,Rugpj\u016Btis,Rugs\u0117jis,Spalis,Lapkritis,Gruodis",
months_short:"Sau,Vas,Kov,Bal,Geg,Bir,Lie,Rugpj,Rugs,Spa,Lapkr,Gruo",
day_long:"Sekmadienis,Pirmadienis,Antradienis,Tre\u010Diadienis,Ketvirtadienis,Penktadienis,\u0160e\u0161tadienis,Sekmadienis",
day_short:"Sekm,Pirm,Antr,Tre\u010D,Ketv,Penk,\u0160e\u0161t,Sekm"
},
print:{
print_desc:"Spausdinti"
},
preview:{
preview_desc:"Per\u017Ei\u016Bra"
},
directionality:{
ltr_desc:"Kryptis i\u0161 kair\u0117s \u012F de\u0161in\u0119",
rtl_desc:"Kryptis i\u0161 de\u0161in\u0117s \u012F kair\u0119"
},
layer:{
insertlayer_desc:"\u012Eterpti nauj\u0105 sluoksn\u012F",
forward_desc:"Perkelti \u012F priek\u012F",
backward_desc:"Perkelti atgal",
absolute_desc:"Perjungti absoliut\u0173 pozicionavim\u0105",
content:"Naujas sluoksnis..."
},
save:{
save_desc:"I\u0161saugoti",
cancel_desc:"Atsisakyti vis\u0173 pakeitim\u0173"
},
nonbreaking:{
nonbreaking_desc:"\u012Eterpti jungiamojo tarpo simbol\u012F"
},
iespell:{
iespell_desc:"Paleisti ra\u0161ybos tikrintuv\u0119",
download:"ieSpell neaptiktas. Ar norite dabar j\u012F \u012Fdiegti?"
},
advhr:{
advhr_desc:"Horizontali linija",
delta_width:"10"
},
emotions:{
emotions_desc:"Jaustukai"
},
searchreplace:{
search_desc:"Ie\u0161koti",
replace_desc:"Ie\u0161koti/Pakeisti",
delta_width:"10",
delta_height:"20"
},
advimage:{
image_desc:"\u012Eterpti/Redaguoti paveiksl\u0117l\u012F",
delta_width:"10"
},
advlink:{
link_desc:"\u012Eterpti/Redaguoti nuorod\u0105",
delta_width:"10"
},
xhtmlxtras:{
cite_desc:"Citavimas",
abbr_desc:"Santrumpa",
acronym_desc:"Akronimas",
del_desc:"Panaikinimas",
ins_desc:"\u012Eterpimas",
attribs_desc:"\u012Eterpti/Redaguoti atributus",
cite_delta_width:"10",
abbr_delta_width:"10",
acronym_delta_width:"10",
del_delta_width:"10",
ins_delta_width:"10",
attribs_delta_width:"10"
},
style:{
desc:"Redaguoti CSS stili\u0173",
delta_width:"40"
},
paste:{
paste_text_desc:"\u012Ed\u0117ti kaip paprast\u0105 tekst\u0105",
paste_word_desc:"\u012Ed\u0117ti i\u0161 Word",
selectall_desc:"Visk\u0105 pa\u017Eym\u0117ti"
},
paste_dlg:{
text_title:"Naudokite CTRL+V tekstui \u012Fd\u0117ti \u012F \u0161\u012F lang\u0105.",
text_linebreaks:"Palikti eilu\u010Di\u0173 l\u016B\u017Eius",
word_title:"Naudokite CTRL+V tekstui \u012Fd\u0117ti \u012F \u0161\u012F lang\u0105."
},
table:{
desc:"\u012Eterpia nauj\u0105 lentel\u0119",
row_before_desc:"\u012Eterpti eilut\u0119 prie\u0161",
row_after_desc:"\u012Eterpti eilut\u0119 po",
delete_row_desc:"\u0160alinti eilut\u0119",
col_before_desc:"\u012Eterpti stulpel\u012F prie\u0161",
col_after_desc:"\u012Eterpti stulpel\u012F po",
delete_col_desc:"\u0160alinti stulpel\u012F",
split_cells_desc:"Skaidyti sulietus lentel\u0117s langelius",
merge_cells_desc:"Sujungti lentel\u0117s langelius",
row_desc:"Lentel\u0117s eilut\u0117s nustatymai",
cell_desc:"Lentel\u0117s langeli\u0173 nustatymai",
props_desc:"Lentel\u0117s nustatymai",
paste_row_before_desc:"\u012Ed\u0117ti lentel\u0117s eilut\u0119 prie\u0161",
paste_row_after_desc:"\u012Ed\u0117ti lentel\u0117s eilut\u0119 po",
cut_row_desc:"I\u0161kirpti lentel\u0117s eilut\u0119",
copy_row_desc:"Kopijuoti lentel\u0117s eilut\u0119",
del:"\u0160alinti lentel\u0119",
row:"Eilut\u0117",
col:"Stulpelis",
cell:"Langelis",
rowprops_delta_width:"10",
cellprops_delta_width:"10",
table_delta_width:"10",
merge_cells_delta_width:"10"
},
autosave:{
unload_msg:"Visi pakeitimai bus prarasti, jei i\u0161eisite i\u0161 \u0161io puslapio."
},
fullscreen:{
desc:"Perjungti viso ekrano re\u017Eim\u0105"
},
media:{
desc:"\u012Eterpti/redaguoti integruot\u0105 daugialyp\u0119 terp\u0119",
edit:"Redaguoti integruot\u0105 daugialyp\u0119 terp\u0119",
delta_width:"10"
},
fullpage:{
desc:"Dokumento nustatymai",
delta_width:"10"
},
template:{
desc:"\u012Eterpti numatyt\u0105 \u0161ablono turin\u012F"
},
visualchars:{
desc:"Vizualiniai valdymo simboliai \u012Fjungti/i\u0161jungti."
},
spellchecker:{
desc:"Perjungti ra\u0161ybos tikrintuv\u0119",
menu:"Ra\u0161ybos tikrintuv\u0117s nustatymai",
ignore_word:"Ignoruoti \u017Eod\u012F",
ignore_words:"Ignoruoti visk\u0105",
langs:"Kalbos",
wait:"Pra\u0161ome palaukti...",
sug:"Pasi\u016Blymai",
no_sug:"Pasi\u016Blym\u0173 nerasta",
no_mpell:"Klaid\u0173 nerasta."
},
pagebreak:{
desc:"\u012Eterpti puslapio pabaigos \u017Eym\u0119."
}}});