tinyMCE.addI18n('cs.advimage_dlg',{
tab_general:"Hlavn\u00ED",
tab_appearance:"Vzhled",
tab_advanced:"Pokro\u010Dil\u00E9",
general:"V\u0161eobecn\u00E9",
title:"Titulek",
preview:"N\u00E1hled",
constrain_proportions:"Zachovat proporce",
langdir:"Sm\u011Br textu",
langcode:"K\u00F3d jazyka",
long_desc:"Dlouh\u00FD popis",
style:"Styl",
classes:"T\u0159\u00EDdy",
ltr:"Zleva doprava",
rtl:"Zprava doleva",
id:"ID",
map:"Obr\u00E1zkov\u00E1 mapa",
swap_image:"P\u0159epnout obr\u00E1zek",
alt_image:"Alternativn\u00ED obr\u00E1zek",
mouseover:"P\u0159i najet\u00ED my\u0161i...",
mouseout:"Po odjet\u00ED my\u0161i...",
misc:"R\u016Fzn\u00E9",
example_img:"P\u0159\u00EDklad obr\u00E1zku",
missing_alt:"Jste si jisti, \u017Ee chcete pokra\u010Dovat bez vlo\u017Een\u00ED popisu obr\u00E1zku? Obr\u00E1zek m\u016F\u017Ee b\u00FDt nep\u0159\u00EDstupn\u00FD u\u017Eivatel\u016Fm se zrakov\u00FDm posti\u017Een\u00EDm, u\u017Eivatel\u016Fm textov\u00FDch prohl\u00ED\u017Ee\u010D\u016F nebo u\u017Eivatel\u016Fm, kte\u0159\u00ED maj\u00ED vypnuto zobrazov\u00E1n\u00ED obr\u00E1zk\u016F.",
dialog_title:"Vlo\u017Eit/upravit obr\u00E1zek",
src:"URL obr\u00E1zku",
alt:"Popis obr\u00E1zku",
list:"Seznam",
border:"R\u00E1me\u010Dek",
dimensions:"Rozm\u011Bry",
vspace:"Vertik\u00E1ln\u00ED mezera",
hspace:"Horizont\u00E1ln\u00ED mezera",
align:"Zarovn\u00E1n\u00ED",
align_baseline:"Na z\u00E1kladnu",
align_top:"Nahoru",
align_middle:"Na st\u0159ed \u0159\u00E1dku",
align_bottom:"Dol\u016F",
align_texttop:"S vrchem \u0159\u00E1dku",
align_textbottom:"Se spodkem \u0159\u00E1dku",
align_left:"Vlevo",
align_right:"Vpravo",
image_list:"Seznam obr\u00E1zk\u016F"
});