/* CSS file for table dialog in the table plugin */

.panel_wrapper div.current {
	height: 245px;
}

.advfield {
	width: 200px;
}

#class {
	width: 150px;
}
.hiddenset, #advanced_panel { display: none; }
