tinyMCE.addI18n({ro:{
common:{
edit_confirm:"Dori\u0163i s\u0103 folosi\u0163i un editor avansat pentru aceast\u0103 zon\u0103d de text?",
apply:"Aplic\u0103",
insert:"Insereaz\u0103",
update:"Actualizeaz\u0103",
cancel:"Anulare",
close:"\u00CEnchide",
browse:"R\u0103sfoie\u015Fte",
class_name:"Clas\u0103",
not_set:"-- Nestat\u0103 --",
clipboard_msg:"Copiere/T\u0103iere/Lipire nu sunt disponibile \u00EEn  Mozilla \u015Fi Firefox.\nDori\u0163i mai multe informa\u0163ii despre aceast\u0103 problem\u0103?",
clipboard_no_support:"Deocamdat\u0103 nu este suportat\u0103 de browser. V\u0103 rug\u0103m s\u0103 folosi\u0163i combina\u0163ii de taste.",
popup_blocked:"Ne pare r\u0103u, dar un popup-blocker a dezativat o fereastr\u0103 care d\u0103 func\u0163ionalitate aplica\u0163iei.Trebuie s\u0103 dezactiva\u0163i acel popup-blocker pentru acest site pentru a folosi aplica\u0163ia la capacitate maxim\u0103.",
invalid_data:"Ave\u0163i erori. Datele gre\u015Fite sunt \u00EEn ro\u015Fu.",
more_colors:"Mai multe culori"
},
contextmenu:{
align:"Aliniere",
left:"St\u00E2nga",
center:"Centru",
right:"Dreapta",
full:"Justify"
},
insertdatetime:{
date_fmt:"%Y-%m-%d",
time_fmt:"%H:%M:%S",
insertdate_desc:"Insereaz\u0103 dat\u0103",
inserttime_desc:"Insereaz\u0103 or\u0103",
months_long:"Ianuarie,Februarie,Martie,Aprilie,Mai,Iunie,Iulie,August,Septembrie,Octombrie,Noiembrie,Decembrie ",
months_short:"Ian,Feb,Mar,Apr,Mai,Iun,Iul,Aug,Sep,Oct,Noi,Dec",
day_long:"Duminic\u0103,Luni,Mar\u0163i,Miercuri,Joi,Vineri,S\u00E2mb\u0103t\u0103,Duminic\u0103",
day_short:"Dum,Lun,Mar,Mie,Joi,Vin,S\u00E2m,Dum"
},
print:{
print_desc:"Imprimare"
},
preview:{
preview_desc:"Previzualizare"
},
directionality:{
ltr_desc:"Direc\u0163ia de la st\u00E2nga la dreapta",
rtl_desc:"Direc\u0163ia de la dreapta la st\u00E2nga"
},
layer:{
insertlayer_desc:"Insereaz\u0103 stat nou",
forward_desc:"Mut\u0103 \u00EEnainte",
backward_desc:"Mut\u0103 \u00EEnapoi",
absolute_desc:"Pozi\u0163ionare absolut\u0103",
content:"Strat nou ..."
},
save:{
save_desc:"Salveaz\u0103",
cancel_desc:"Anuleaz\u0103 toate schimb\u0103rile"
},
nonbreaking:{
nonbreaking_desc:"Insereaz\u0103 caracterul spa\u0163iu"
},
iespell:{
iespell_desc:"Ruleaz\u0103 corectorul de limb\u0103",
download:"ieSpell nu a fost detectat. Dori\u0163i s\u0103-l instala\u0163i?"
},
advhr:{
advhr_desc:"Linie orizontal\u0103"
},
emotions:{
emotions_desc:"Figurine"
},
searchreplace:{
search_desc:"Caut\u0103",
replace_desc:"Caut\u0103/\u00CEnlocuie\u015Fte"
},
advimage:{
image_desc:"Inserare/editare imagine"
},
advlink:{
link_desc:"Inserare/editare leg\u0103tur\u0103"
},
xhtmlxtras:{
cite_desc:"Citat",
abbr_desc:"Abreviere",
acronym_desc:"Acronim",
del_desc:"\u015Etergere",
ins_desc:"Inserare",
attribs_desc:"Insereaz\u0103/editeaz\u0103 atribute"
},
style:{
desc:"Editare CSS"
},
paste:{
paste_text_desc:"Lipire ca text simplu",
paste_word_desc:"Lipire din Word",
selectall_desc:"Selecteaz\u0103 tot"
},
paste_dlg:{
text_title:"Folosi\u0163i CTRL+V pentru a lipi \u00EEn aceast\u0103 zon\u0103.",
text_linebreaks:"P\u0103streaz\u0103 separatoarele de linii.",
word_title:"Folosi\u0163i CTRL+V pentru a lipi \u00EEn aceast\u0103 zon\u0103."
},
table:{
desc:"Insereaz\u0103 tabel nou",
row_before_desc:"Inserare r\u00E2nd \u00EEnainte",
row_after_desc:"Inserare r\u00E2nd dup\u0103",
delete_row_desc:"\u015Eterge r\u00E2nd",
col_before_desc:"Inserare coloan\u0103 \u00EEnainte",
col_after_desc:"Inserare coloan\u0103 dup\u0103",
delete_col_desc:"\u015Eterge coloan\u0103",
split_cells_desc:"Separa\u0163i celule unite",
merge_cells_desc:"Uni\u0163i celule",
row_desc:"Propriet\u0103\u0163i r\u00E2nd",
cell_desc:"Propriet\u0103\u0163i celul\u0103",
props_desc:"Propriet\u0103\u0163i tabel",
paste_row_before_desc:"Lipe\u015Fte r\u00E2nd \u00EEnainte",
paste_row_after_desc:"Lipe\u015Fte r\u00E2nd dup\u0103",
cut_row_desc:"Taie r\u00E2nd",
copy_row_desc:"Copiaz\u0103 r\u00E2nd",
del:"\u015Eterge tabel",
row:"R\u00E2nd",
col:"Coloan\u0103",
cell:"Celul\u0103"
},
autosave:{
unload_msg:"Modific\u0103rile nu vor fi salvate."
},
fullscreen:{
desc:"Mod ecran complet"
},
media:{
desc:"Insereaz\u0103 / editeaz\u0103 media",
edit:"Editeaz\u0103 media"
},
fullpage:{
desc:"Propriet\u0103\u0163i document"
},
template:{
desc:"Insereaz\u0103 un \u015Fablon predefinit"
},
visualchars:{
desc:"Comut\u0103 caracterele vizuale de control"
},
spellchecker:{
desc:"Activare/dezactivare dic\u0163ionar",
menu:"Set\u0103ri dic\u0163ionar",
ignore_word:"Ignor\u0103 cuv\u00E2nt",
ignore_words:"Ignor\u0103 toate",
langs:"Limbi",
wait:"V\u0103 rog a\u015Ftepta\u0163i...",
sug:"Sugestii",
no_sug:"Nu sunt sugestii.",
no_mpell:"Nu sunt gre\u015Feli."
},
pagebreak:{
desc:"Insereaz\u0103 un separator de pagin\u0103"
}}});