tinyMCE.addI18n('sv.advanced_dlg',{
about_title:"Om TinyMCE",
about_general:"Om",
about_help:"Hj\u00E4lp",
about_license:"Licens",
about_plugins:"Om plug-in",
about_plugin:"Om plug-in",
about_author:"Utvecklare",
about_version:"Version",
about_loaded:"Laddade plug-ins",
anchor_title:"Infoga/redigera bokm\u00E4rke",
anchor_name:"Namn",
code_title:"HTML k\u00E4llkodsl\u00E4ge",
code_wordwrap:"Bryt ord",
colorpicker_title:"V\u00E4lj en f\u00E4rg",
colorpicker_picker_tab:"V\u00E4ljare",
colorpicker_picker_title:"F\u00E4rgv\u00E4ljare",
colorpicker_palette_tab:"Palett",
colorpicker_palette_title:"Palettf\u00E4rger",
colorpicker_named_tab:"Namngivna",
colorpicker_named_title:"Namngivna f\u00E4rger",
colorpicker_color:"F\u00E4rg:",
colorpicker_name:"Namn:",
charmap_title:"V\u00E4lj ett specialtecken",
image_title:"Infoga/redigera bild",
image_src:"Bildens URL",
image_alt:"Bildens beskrivning",
image_list:"Bildlista",
image_border:"Ram",
image_dimensions:"Dimensioner",
image_vspace:"Vertikalrymd",
image_hspace:"Horisontalrymd",
image_align:"Justering",
image_align_baseline:"Baslinje",
image_align_top:"Toppen",
image_align_middle:"Mitten",
image_align_bottom:"Botten",
image_align_texttop:"Toppen av texten",
image_align_textbottom:"Botten av texten",
image_align_left:"V\u00E4nster",
image_align_right:"H\u00F6ger",
link_title:"Infoga/redigera l\u00E4nk",
link_url:"L\u00E4nkens URL",
link_target:"M\u00E5l",
link_target_same:"\u00D6\u0096ppna l\u00E4nken i samma f\u00F6nster",
link_target_blank:"\u00D6\u0096ppna l\u00E4nken i ett nytt f\u00F6nster",
link_titlefield:"Titel",
link_is_email:"L\u00E4nken du angav verkar vara en e-post adress. Vill du infoga mailto: prefixet p\u00E5 l\u00E4nken?",
link_is_external:"L\u00E4nken du angav verkar vara en extern adress. Vill du infoga http:// prefixet p\u00E5 l\u00E4nken?",
link_list:"L\u00E4nklista"
});