tinyMCE.addI18n('ca.advanced_dlg',{
about_title:"Quant a TinyMCE",
about_general:"Quant a",
about_help:"Ajuda",
about_license:"Llic\u00E8ncia",
about_plugins:"Extensions",
about_plugin:"Extensi\u00F3",
about_author:"Autor",
about_version:"Versi\u00F3",
about_loaded:"Extensions carregades",
anchor_title:"Insereix/edita \u00E0ncora",
anchor_name:"Nom de l'\u00E0ncora",
code_title:"Editor de Font HTML",
code_wordwrap:"Salt de paraula",
colorpicker_title:"Selecciona un color",
colorpicker_picker_tab:"Triador",
colorpicker_picker_title:"Triador de color",
colorpicker_palette_tab:"Paleta",
colorpicker_palette_title:"Colors de la paleta",
colorpicker_named_tab:"Amb nom",
colorpicker_named_title:"Colors amb nom",
colorpicker_color:"Color:",
colorpicker_name:"Nom:",
charmap_title:"Selecciona el car\u00E0cter personalitzat",
image_title:"Insereix/edita imatge",
image_src:"URL de la imatge",
image_alt:"Descripci\u00F3 de la imatge",
image_list:"Llista d'imatges",
image_border:"Vora",
image_dimensions:"Dimensions",
image_vspace:"Espaiat vertical",
image_hspace:"Espaiat horitzontal",
image_align:"Alineaci\u00F3",
image_align_baseline:"L\u00EDnia base",
image_align_top:"Dalt",
image_align_middle:"Mig",
image_align_bottom:"Baix",
image_align_texttop:"A dalt del text",
image_align_textbottom:"A baix del text",
image_align_left:"Esquerra",
image_align_right:"Dreta",
link_title:"Insereix/edita enlla\u00E7",
link_url:"URL de l'enlla\u00E7",
link_target:"Objectiu",
link_target_same:"Obre l'enlla\u00E7 a la mateixa finestra",
link_target_blank:"Obre l'enlla\u00E7 en una finestra nova",
link_titlefield:"T\u00EDtol",
link_is_email:"L'URL que has introdu\u00EFt sembla una adre\u00E7a de correu, vols afegir-hi el prefix mailto://?",
link_is_external:"L'URL que has introdu\u00EFt sembla un enlla\u00E7 extern, vols afegir-hi el prefix http://?",
link_list:"Llista d'enlla\u00E7os"
});