tinyMCE.addI18n('fi.advimage_dlg',{
tab_general:"Yleiset",
tab_appearance:"N\u00E4kyminen",
tab_advanced:"Edistynyt",
general:"Yleiset",
title:"Otsikko",
preview:"Esikatselu",
constrain_proportions:"S\u00E4ilyt\u00E4 mittasuhteet",
langdir:"Kielen suunta",
langcode:"Kielen koodi",
long_desc:"Pitk\u00E4n kuvauksen linkki",
style:"Tyyli",
classes:"Luokat",
ltr:"Vasemmalta oikealle",
rtl:"Oikealta vasemmalle",
id:"Id",
map:"Kuvakartta",
swap_image:"Vaihda kuva",
alt_image:"Vaihtoehtoinen kuva",
mouseover:"mouseoverille",
mouseout:"mouseoutille",
misc:"Sekalaiset",
example_img:"Ulkoasun esikatselukuva",
missing_alt:"Haluatko varmasti jatkaa lis\u00E4\u00E4m\u00E4tt\u00E4 kuvausta? Kuvauksen puuttuminen saattaa h\u00E4irit\u00E4 sellaisia, jotka k\u00E4ytt\u00E4v\u00E4t tekstipohjaista selainta tai ovat kytkeneet kuvien n\u00E4kymisen pois p\u00E4\u00E4lt\u00E4.",
dialog_title:"Lis\u00E4\u00E4/muokkaa kuvaa",
src:"Kuvan URL",
alt:"Kuvan kuvaus",
list:"Kuvalista",
border:"Kehys",
dimensions:"Mitat",
vspace:"pystysuora tila",
hspace:"vaakasuora tila",
align:"Tasaus",
align_baseline:"Rivill\u00E4",
align_top:"Ylh\u00E4\u00E4ll\u00E4",
align_middle:"Keskell\u00E4",
align_bottom:"Alhaalla",
align_texttop:"Teksti ylh\u00E4\u00E4ll\u00E4",
align_textbottom:"Teksti alhaalla",
align_left:"Vasemmalla",
align_right:"Oikealla",
image_list:"Kuvalista"
});