tinyMCE.addI18n('th.table_dlg',{
general_tab:"\u0E17\u0E31\u0E48\u0E27\u0E44\u0E1B",
advanced_tab:"\u0E02\u0E31\u0E49\u0E19\u0E2A\u0E39\u0E07",
general_props:"\u0E04\u0E38\u0E13\u0E2A\u0E21\u0E1A\u0E31\u0E15\u0E34\u0E17\u0E31\u0E48\u0E27\u0E44\u0E1B",
advanced_props:"\u0E04\u0E38\u0E13\u0E2A\u0E21\u0E1A\u0E31\u0E15\u0E34\u0E02\u0E31\u0E49\u0E19\u0E2A\u0E39\u0E07",
rowtype:"Row in table part",
title:"\u0E40\u0E1E\u0E34\u0E48\u0E21/\u0E41\u0E01\u0E49\u0E44\u0E02 \u0E15\u0E32\u0E23\u0E32\u0E07",
width:"\u0E01\u0E27\u0E49\u0E32\u0E07",
height:"\u0E2A\u0E39\u0E07",
cols:"\u0E04\u0E2D\u0E25\u0E31\u0E21\u0E1E\u0E4C",
rows:"\u0E41\u0E16\u0E27",
cellspacing:"Cellspacing",
cellpadding:"Cellpadding",
border:"\u0E01\u0E23\u0E2D\u0E1A",
align:"\u0E15\u0E33\u0E41\u0E2B\u0E19\u0E48\u0E07\u0E08\u0E31\u0E14\u0E27\u0E32\u0E07",
align_default:"\u0E04\u0E48\u0E32\u0E40\u0E23\u0E34\u0E48\u0E21\u0E15\u0E49\u0E19",
align_left:"\u0E0B\u0E49\u0E32\u0E22",
align_right:"\u0E02\u0E27\u0E32",
align_middle:"\u0E01\u0E25\u0E32\u0E07",
row_title:"\u0E04\u0E38\u0E13\u0E2A\u0E21\u0E1A\u0E31\u0E15\u0E34\u0E41\u0E16\u0E27\u0E43\u0E19\u0E15\u0E32\u0E23\u0E32\u0E07",
cell_title:"\u0E04\u0E38\u0E13\u0E2A\u0E21\u0E1A\u0E31\u0E15\u0E34\u0E40\u0E0B\u0E25\u0E25\u0E4C\u0E43\u0E19\u0E32\u0E23\u0E32\u0E07",
cell_type:"Cell type",
valign:"Vertical alignment",
align_top:"\u0E1A\u0E19",
align_bottom:"\u0E25\u0E48\u0E32\u0E07",
bordercolor:"\u0E2A\u0E35\u0E01\u0E23\u0E2D\u0E1A",
bgcolor:"\u0E2A\u0E35\u0E1E\u0E37\u0E49\u0E19\u0E2B\u0E25\u0E31\u0E07",
merge_cells_title:"Merge table cells",
id:"Id",
style:"\u0E23\u0E39\u0E1B\u0E41\u0E1A\u0E1A",
langdir:"\u0E17\u0E34\u0E28\u0E17\u0E32\u0E07\u0E01\u0E32\u0E23\u0E2D\u0E48\u0E32\u0E19",
langcode:"\u0E42\u0E04\u0E4A\u0E14\u0E20\u0E32\u0E29\u0E32",
mime:"\u0E40\u0E1B\u0E49\u0E32\u0E2B\u0E21\u0E32\u0E22 MIME type",
ltr:"\u0E0B\u0E49\u0E32\u0E22\u0E44\u0E1B\u0E02\u0E27\u0E32",
rtl:"\u0E02\u0E27\u0E32\u0E44\u0E1B\u0E0B\u0E49\u0E32\u0E22",
bgimage:"\u0E1E\u0E37\u0E49\u0E19\u0E2B\u0E25\u0E31\u0E07 image",
summary:"Summary",
td:"Data",
th:"Header",
cell_cell:"Update current cell",
cell_row:"Update all cells in row",
cell_all:"Update all cells in table",
row_row:"Update current row",
row_odd:"Update odd rows in table",
row_even:"Update even rows in table",
row_all:"Update all rows in table",
thead:"Table Head",
tbody:"Table Body",
tfoot:"Table Foot",
scope:"Scope",
rowgroup:"Row Group",
colgroup:"Col Group",
col_limit:"You've exceeded the maximum number of columns of {$cols}.",
row_limit:"You've exceeded the maximum number of rows of {$rows}.",
cell_limit:"You've exceeded the maximum number of cells of {$cells}.",
missing_scope:"Are you sure you want to continue without specifying a scope for this table header cell. Without it, it may be difficult for some users with disabilities to understand the content or data displayed of the table.",
caption:"Table caption",
frame:"Frame",
frame_none:"none",
frame_groups:"groups",
frame_rows:"rows",
frame_cols:"cols",
frame_all:"all",
rules:"Rules",
rules_void:"void",
rules_above:"above",
rules_below:"below",
rules_hsides:"hsides",
rules_lhs:"lhs",
rules_rhs:"rhs",
rules_vsides:"vsides",
rules_box:"box",
rules_border:"border"
});