tinyMCE.addI18n('tt.media_dlg',{
title:"\u63D2\u5165/\u7DE8\u8F2F \u5A92\u9AD4",
general:"\u57FA\u672C",
advanced:"\u9032\u968E",
file:"\u6587\u4EF6/\u5730\u5740",
list:"\u5217\u8868",
size:"\u5927\u5C0F",
preview:"\u9810\u89BD",
constrain_proportions:"\u4FDD\u6301\u6BD4\u4F8B",
type:"\u985E\u578B",
id:"Id",
name:"\u540D\u7A31",
class_name:"\u985E\u540D",
vspace:"\u5782\u76F4\u9593\u8DDD",
hspace:"\u6C34\u5E73\u9593\u8DDD",
play:"\u81EA\u52D5\u64AD\u653E",
loop:"\u8FF4\u5708",
menu:"\u986F\u793A\u529F\u80FD\u8868",
quality:"\u54C1\u8CEA",
scale:"\u7E2E\u653E",
align:"\u5C0D\u9F4A",
salign:"SAlign",
wmode:"WMode",
bgcolor:"\u80CC\u666F\u8272",
base:"\u57FA\u7DDA",
flashvars:"Flash\u8B8A\u6578",
liveconnect:"SWLiveConnect",
autohref:"AutoHREF",
cache:"\u66AB\u5B58",
hidden:"\u96B1\u85CF",
controller:"\u63A7\u5236\u81FA",
kioskmode:"Kiosk \u6A21\u5F0F",
playeveryframe:"\u9010\u683C\u64AD\u653E",
targetcache:"\u76EE\u6A19\u66AB\u5B58",
correction:"\u4FEE\u6B63",
enablejavascript:"\u5553\u7528 JavaScript",
starttime:"\u958B\u59CB\u6642\u9593",
endtime:"\u7D50\u675F\u6642\u9593",
href:"Href",
qtsrcchokespeed:"Choke speed",
target:"\u76EE\u6A19",
volume:"\u97F3\u91CF",
autostart:"\u81EA\u52D5\u958B\u59CB",
enabled:"\u5553\u7528",
fullscreen:"\u5168\u87A2\u5E55",
invokeurls:"\u8ABF\u7528\u7684URLs",
mute:"\u975C\u97F3",
stretchtofit:"\u7E2E\u653E\u81F3\u5408\u9069\u5927\u5C0F",
windowlessvideo:"\u7121\u8996\u7A97\u5F71\u50CF",
balance:"\u5E73\u8861",
baseurl:"Base URL",
captioningid:"\u5B57\u5E55 id",
currentmarker:"\u7576\u524D\u6A19\u7C64",
currentposition:"\u7576\u524D\u4F4D\u7F6E",
defaultframe:"\u9810\u8A2D\u683C",
playcount:"\u64AD\u653E\u6B21\u6578",
rate:"\u78BC\u7387",
uimode:"UI \u6A21\u5F0F",
flash_options:"Flash \u9078\u9805",
qt_options:"Quicktime \u9078\u9805",
wmp_options:"Windows media player \u9078\u9805",
rmp_options:"Real media player \u9078\u9805",
shockwave_options:"Shockwave \u9078\u9805",
autogotourl:"\u81EA\u52D5\u8DF3\u8F49 URL",
center:"\u7F6E\u4E2D",
imagestatus:"\u5716\u50CF\u72C0\u614B",
maintainaspect:"\u7DAD\u8B77\u72C0\u614B",
nojava:"No java",
prefetch:"\u9810\u8B80",
shuffle:"\u96A8\u6A5F",
console:"\u63A7\u5236\u81FA",
numloop:"\u8FF4\u5708\u6B21\u6578",
controls:"\u63A7\u5236",
scriptcallbacks:"\u8173\u672C\u56DE\u6A94",
swstretchstyle:"\u7E2E\u653E\u6A23\u5F0F",
swstretchhalign:"\u7E2E\u653E\u81F3\u6C34\u5E73\u5C0D\u9F4A",
swstretchvalign:"\u7E2E\u653E\u81F3\u5782\u76F4\u5C0D\u9F4A",
sound:"\u8072\u97F3",
progress:"\u9032\u5EA6",
qtsrc:"QT Src",
qt_stream_warn:"Streamed rtsp resources should be added to the QT Src field under the advanced tab.\nYou should also add a non streamed version to the Src field..",
align_top:"\u9802\u90E8",
align_right:"\u5C45\u53F3",
align_bottom:"\u5E95\u90E8",
align_left:"\u5C45\u5DE6",
align_center:"\u7F6E\u4E2D",
align_top_left:"\u9802\u90E8\u5C45\u5DE6",
align_top_right:"\u9802\u90E8\u5C45\u53F3",
align_bottom_left:"\u5E95\u90E8\u5C45\u5DE6",
align_bottom_right:"\u5E95\u90E8\u5C45\u53F3",
flv_options:"Flash \u5F71\u50CF\u9078\u9805",
flv_scalemode:"\u7E2E\u653E\u6A21\u5F0F",
flv_buffer:"\u7DE9\u885D",
flv_startimage:"\u958B\u59CB\u5716\u50CF",
flv_starttime:"\u958B\u59CB\u6642\u9593",
flv_defaultvolume:"\u9810\u8A2D\u8072\u97F3",
flv_hiddengui:"\u96B1\u85CFGUI",
flv_autostart:"\u81EA\u52D5\u958B\u59CB",
flv_loop:"\u8FF4\u5708",
flv_showscalemodes:"\u986F\u793A\u7E2E\u653E\u6A21\u5F0F",
flv_smoothvideo:"\u5E73\u6ED1\u5F71\u50CF",
flv_jscallback:"JS \u56DE\u6A94"
});