tinyMCE.addI18n('nb.advimage_dlg',{
tab_general:"Generelt",
tab_appearance:"Utseende",
tab_advanced:"Avansert",
general:"Generelt",
title:"Tittel",
preview:"Forh\u00E5ndsvisning",
constrain_proportions:"Behold st\u00F8rrelsesforhold",
langdir:"Skriftretning",
langcode:"Spr\u00E5kkode",
long_desc:"Lang beskrivelse",
style:"Stil",
classes:"Klasser",
ltr:"Venstre mot h\u00F8yre",
rtl:"H\u00F8yre  mot venstre",
id:"Id",
map:"Bildekart",
swap_image:"Bytt bilde",
alt_image:"Alternativt bilde",
mouseover:"for musepeker p\u00E5",
mouseout:"for musepeker utenfor",
misc:"Annet",
example_img:"Utseende Forh\u00E5ndsvisning bilde",
missing_alt:"Er du sikker p\u00E5 at du vil fortsette uten \u00E5 sette inn en beskrivelse av bildet? Uten beskrivelse vil bildet ikke gi mening for enkelte funksjonshemmede eller for personer som bruker en nettleser med bildevisning avsl\u00E5tt.",
dialog_title:"Sett inn / endre bilde",
src:"Bildets URL",
alt:"Bildebeskrivelse",
list:"Bildeliste",
border:"Ramme",
dimensions:"Dimensjoner",
vspace:"Vertikal avstand",
hspace:"Horisontal avstand",
align:"Justering",
align_baseline:"Grunnlinje",
align_top:"Topp",
align_middle:"Midtstilt",
align_bottom:"Bunn",
align_texttop:"Tekst topp",
align_textbottom:"Tekst bunn",
align_left:"Venstre",
align_right:"H\u00F8yre",
image_list:"Bildeliste"
});