tinyMCE.addI18n('ca.advanced',{
style_select:"Estils",
font_size:"Mida de lletra",
fontdefault:"Tipografia",
block:"Format",
paragraph:"Par\u00E0graf",
div:"Div",
address:"Adre\u00E7a",
pre:"Preformatat",
h1:"Cap\u00E7alera 1",
h2:"Cap\u00E7alera 2",
h3:"Cap\u00E7alera 3",
h4:"Cap\u00E7alera 4",
h5:"Cap\u00E7alera 5",
h6:"Cap\u00E7alera 6",
blockquote:"Cita",
code:"Codi",
samp:"Mostra de codi",
dt:"Terme de la definici\u00F3",
dd:"Descripci\u00F3 de la definici\u00F3",
bold_desc:"Negreta (Ctrl+B)",
italic_desc:"Cursiva (Ctrl+I)",
underline_desc:"Subratllat (Ctrl+U)",
striketrough_desc:"Tatxat",
justifyleft_desc:"Alinea a l'esquerra",
justifycenter_desc:"Centra",
justifyright_desc:"Alinea a la dreta",
justifyfull_desc:"Justifica",
bullist_desc:"Llista no ordenada",
numlist_desc:"Llista ordenada",
outdent_desc:"Redueix el sagnat",
indent_desc:"Augmenta el sagnat",
undo_desc:"Desf\u00E9s (Ctrl+Z)",
redo_desc:"Ref\u00E9s (Ctrl+Y)",
link_desc:"Insereix/edita enlla\u00E7",
unlink_desc:"Desenlla\u00E7a",
image_desc:"Insereix/edita imatge",
cleanup_desc:"Neteja el codi no correcte",
code_desc:"Edita la font HTML",
sub_desc:"Sub\u00EDndex",
sup_desc:"Super\u00EDndex",
hr_desc:"Insereix regle horitzontal",
removeformat_desc:"Elimina el format",
custom1_desc:"Aqu\u00ED la teva descripci\u00F3 personalitzada",
forecolor_desc:"Selecciona el color del text",
backcolor_desc:"Selecciona el color de fons",
charmap_desc:"Insereix car\u00E0cter personalitzat",
visualaid_desc:"Canvia els elements guies/invisibles",
anchor_desc:"Insereix/edita \u00E0ncora",
cut_desc:"Retalla",
copy_desc:"Copia",
paste_desc:"Enganxa",
image_props_desc:"Propietats de la imatge",
newdocument_desc:"Nou document",
help_desc:"Ajuda",
blockquote_desc:"Descripci\u00F3 de la cita",
clipboard_msg:"Copia/Retalla/Enganxa no est\u00E0 disponible en Mozilla/Firefox.\r\nVols m\u00E9s informaci\u00F3 sobre aquest tema?",
path:"Cam\u00ED",
newdocument:"Segur que vols esborrar tot el contingut?",
toolbar_focus:"Salta als botons d'eines - Alt+Q, Salta a l'editor - Alt-Z, Salta al cam\u00ED de l'element - Alt-X",
more_colors:"M\u00E9s colors"
});