tinyMCE.addI18n('ja.xhtmlxtras_dlg',{
attribute_label_title:"\u30BF\u30A4\u30C8\u30EB",
attribute_label_id:"ID",
attribute_label_class:"\u30AF\u30E9\u30B9",
attribute_label_style:"\u30B9\u30BF\u30A4\u30EB",
attribute_label_cite:"\u5F15\u7528",
attribute_label_datetime:"\u65E5\u4ED8/\u6642\u523B",
attribute_label_langdir:"\u6587\u7AE0\u306E\u65B9\u5411",
attribute_option_ltr:"\u5DE6\u304B\u3089\u53F3",
attribute_option_rtl:"\u53F3\u304B\u3089\u5DE6",
attribute_label_langcode:"\u8A00\u8A9E",
attribute_label_tabindex:"\u30BF\u30D6\u30A4\u30F3\u30C7\u30C3\u30AF\u30B9",
attribute_label_accesskey:"\u30A2\u30AF\u30BB\u30B9\u30AD\u30FC",
attribute_events_tab:"\u30A4\u30D9\u30F3\u30C8",
attribute_attrib_tab:"\u5C5E\u6027",
general_tab:"\u4E00\u822C",
attrib_tab:"\u5C5E\u6027",
events_tab:"\u30A4\u30D9\u30F3\u30C8",
fieldset_general_tab:"\u4E00\u822C",
fieldset_attrib_tab:"\u30A8\u30EC\u30E1\u30F3\u30C8\u306E\u5C5E\u6027",
fieldset_events_tab:"\u30A8\u30EC\u30E1\u30F3\u30C8\u306E\u30A4\u30D9\u30F3\u30C8",
title_ins_element:"\u30A8\u30EC\u30E1\u30F3\u30C8\u3092\u633F\u5165",
title_del_element:"\u30A8\u30EC\u30E1\u30F3\u30C8\u3092\u524A\u9664",
title_acronym_element:"\u982D\u5B57\u8A9E\u30A8\u30EC\u30E1\u30F3\u30C8",
title_abbr_element:"\u7565\u8A9E\u30A8\u30EC\u30E1\u30F3\u30C8",
title_cite_element:"\u5F15\u7528\u30A8\u30EC\u30E1\u30F3\u30C8",
remove:"Remove",
insert_date:"\u73FE\u5728\u306E\u65E5\u4ED8/\u6642\u523B\u3092\u633F\u5165",
option_ltr:"\u5DE6\u304B\u3089\u53F3",
option_rtl:"\u53F3\u304B\u3089\u5DE6",
attribs_title:"\u5C5E\u6027\u306E\u633F\u5165/\u524A\u9664"
});