tinyMCE.addI18n('ca.media_dlg',{
title:"Insereix / edita mitj\u00E0 encastat",
general:"General",
advanced:"Avan\u00E7at",
file:"Fitxer/URL",
list:"Llista",
size:"Dimensions",
preview:"Vista pr\u00E8via",
constrain_proportions:"Constreny les proporcions",
type:"Tipus",
id:"Id",
name:"Nom",
class_name:"Classe",
vspace:"Espaiat V",
hspace:"Espaiat H",
play:"Auto reprodueix",
loop:"Cicle",
menu:"Mostra el men\u00FA",
quality:"Qualitat",
scale:"Escala",
align:"Alineaci\u00F3",
salign:"Al\u00EDniaci\u00F3",
wmode:"Mode de finestra",
bgcolor:"Fons",
base:"Base",
flashvars:"Variables Flash",
liveconnect:"Connexi\u00F3 directa SW",
autohref:"AutoHREF",
cache:"Cau",
hidden:"Ocult",
controller:"Controlador",
kioskmode:"Mode kiosk",
playeveryframe:"Reprodueix cada marc",
targetcache:"Cau objectiu",
correction:"Sense correcci\u00F3",
enablejavascript:"Activa JavaScript",
starttime:"Hora inicial",
endtime:"Hora final",
href:"Href",
qtsrcchokespeed:"restringeix la velocitat",
target:"Objectiu",
volume:"Volum",
autostart:"Auto inici",
enabled:"Activat",
fullscreen:"Pantalla completa",
invokeurls:"Invoca URLs",
mute:"Sense so",
stretchtofit:"Estira per encaixar",
windowlessvideo:"V\u00EDdeo sense finestra",
balance:"Balan\u00E7",
baseurl:"URL base",
captioningid:"Id del t\u00EDtol",
currentmarker:"Marcador actual",
currentposition:"Posici\u00F3 actual",
defaultframe:"Marc per defecte",
playcount:"Recompte de reproduccions",
rate:"Ritme",
uimode:"Mode de la UI",
flash_options:"Opcions Flash",
qt_options:"Opcions Quicktime",
wmp_options:"Opcions Windows Media Player",
rmp_options:"Opcions Real Meedia Player",
shockwave_options:"Opcions Shockwave",
autogotourl:"URL Auto goto",
center:"Centrat",
imagestatus:"Estat de la imatge",
maintainaspect:"Matingues l'aspecte",
nojava:"Sense java",
prefetch:"Precerca",
shuffle:"Barreja",
console:"Consola",
numloop:"N\u00BA de cicles",
controls:"Controls",
scriptcallbacks:"Retorns a script",
swstretchstyle:"Estil d'estirament",
swstretchhalign:"Estirament de l'alineaci\u00F3 H",
swstretchvalign:"Estirament de l'alineaci\u00F3 V",
sound:"So",
progress:"Progr\u00E9s",
qtsrc:"Font QT",
qt_stream_warn:"Els recursos rtsp stream no s'han d'afegir al camp Font QT sota la pestanya Avan\u00E7ada.\nhas d'afegir tamb\u00E9 una versi\u00F3 no-stream al camp Font.",
align_top:"Dalt",
align_right:"Dreta",
align_bottom:"Baix",
align_left:"Esquerra",
align_center:"Centrat",
align_top_left:"Dalt esquerra",
align_top_right:"Dalt dreta",
align_bottom_left:"Baix esquerra",
align_bottom_right:"Baix dreta",
flv_options:"Opcions de v\u00EDdeo Flash",
flv_scalemode:"Mode d'escala",
flv_buffer:"Buffer",
flv_startimage:"Imatge inicial",
flv_starttime:"Hora inicial",
flv_defaultvolume:"Volum per defecte",
flv_hiddengui:"GUI Amagada",
flv_autostart:"Auto inici",
flv_loop:"Cicle",
flv_showscalemodes:"Mostra els modes d'escala",
flv_smoothvideo:"V\u00EDdeo suau",
flv_jscallback:"Retorn JS"
});