tinyMCE.addI18n({se:{
common:{
edit_confirm:"Vill du anv\u00E4nda WYSIWYG l\u00E4get f\u00F6r denna textarea.",
apply:"Applicera",
insert:"Infoga",
update:"Uppdatera",
cancel:"Avbryt",
close:"St\u00E4ng",
browse:"Bl\u00E4ddra",
class_name:"Klass",
not_set:"-- Inte satt --",
clipboard_msg:"Kopiera/klipp ut/klistra in \u00E4r inte tillg\u00E4ngligt i din webbl\u00E4sare.\nVill du veta mer?",
clipboard_no_support:"Funktionen \u00E4r inte tillg\u00E4nglig i din webbl\u00E4sare, anv\u00E4nd tangentbordsgenv\u00E4garna i st\u00E4llet.",
popup_blocked:"Popup blockerare detekterad. St\u00E4ng av den s\u00E5 att dialogerna kan \u00F6ppnas.",
invalid_data:"Fel: Inkorrekta v\u00E4rden har matats in, dessa \u00E4r markerade i r\u00F6tt.",
more_colors:"Fler f\u00E4rger"
},
contextmenu:{
align:"Justering",
left:"V\u00E4nster",
center:"Centrerad",
right:"H\u00F6ger",
full:"Utfyllnad"
},
insertdatetime:{
date_fmt:"%Y-%m-%d ",
time_fmt:"%H:%M:%S",
insertdate_desc:"Infoga datum",
inserttime_desc:"Infoga tid",
months_long:"Januari,Februari,Mars,April,Maj,Juni,Juli,Augusti,September,Oktober,November,December",
months_short:"Jan,Feb,Mar,Apr,Maj,Jun,Jul,Aug,Sep,Okt,Nov,Dec",
day_long:"S\u00F6ndag,M\u00E5ndag,Tisdag,Onsdag,Torsdag,Fredag,L\u00F6rdag,S\u00F6ndag",
day_short:"S\u00F6n,M\u00E5n,Tis,Ons,Tors,Fre,L\u00F6r,S\u00F6n"
},
print:{
print_desc:"Skriv ut"
},
preview:{
preview_desc:"F\u00F6rhandsgranska"
},
directionality:{
ltr_desc:"Skriftl\u00E4ge - v\u00E4nster till h\u00F6ger",
rtl_desc:"Skriftl\u00E4ge - h\u00F6ger till v\u00E4nster"
},
layer:{
insertlayer_desc:"Infoga nytt lager",
forward_desc:"Flytta fram\u00E5t",
backward_desc:"Flytta bak\u00E5t",
absolute_desc:"Sl\u00E5 av/p\u00E5 absolut positionering",
content:"Nytt lager..."
},
save:{
save_desc:"Spara",
cancel_desc:"Hoppa \u00F6ver alla f\u00F6r\u00E4ndringar"
},
nonbreaking:{
nonbreaking_desc:"Infoga icke radbrytande mellanslag"
},
iespell:{
iespell_desc:"R\u00E4ttstava",
download:"ieSpell kunde inte hittas, vill du installera denna nu?"
},
advhr:{
advhr_desc:"Horisontell skiljelinje"
},
emotions:{
emotions_desc:"Smileys"
},
searchreplace:{
search_desc:"S\u00F6k",
replace_desc:"S\u00F6k/ers\u00E4tt"
},
advimage:{
image_desc:"Infoga/redigera bild"
},
advlink:{
link_desc:"Infoga/redigera l\u00E4nk"
},
xhtmlxtras:{
cite_desc:"citat",
abbr_desc:"F\u00F6rkortning",
acronym_desc:"Akronym",
del_desc:"Markera som struket",
ins_desc:"Markera som tillagt",
attribs_desc:"Redigera attribut"
},
style:{
desc:"Redigera inline CSS"
},
paste:{
paste_text_desc:"Klistra in som text",
paste_word_desc:"Klistra in fr\u00E5n Word",
selectall_desc:"Markera allt"
},
paste_dlg:{
text_title:"Anv\u00E4nd ctrl-v p\u00E5 ditt tangentbord f\u00F6r att klistra in i detta f\u00F6nster.",
text_linebreaks:"Spara radbrytningar",
word_title:"Anv\u00E4nd ctrl-v p\u00E5 ditt tangentbord f\u00F6r att klistra in i detta f\u00F6nster."
},
table:{
desc:"Infoga/redigera ny tabell",
row_before_desc:"Infoga ny rad f\u00F6re",
row_after_desc:"Infoga ny rad efter",
delete_row_desc:"Radera rad",
col_before_desc:"Infoga kolumn f\u00F6re",
col_after_desc:"Infoga kolumn efter",
delete_col_desc:"Radera kolumn",
split_cells_desc:"Separera sammansatta celler",
merge_cells_desc:"Sammanfoga celler",
row_desc:"Tabellradsinst\u00E4llningar",
cell_desc:"Tabellcellsinst\u00E4llningar",
props_desc:"Tabellinst\u00E4llningar",
paste_row_before_desc:"Klistra in rad ovanf\u00F6r",
paste_row_after_desc:"Klistra in rad efter",
cut_row_desc:"Klipp ut rad",
copy_row_desc:"Klistra in rad",
del:"Radera tabell",
row:"Rad",
col:"Kolumn",
cell:"Cell"
},
autosave:{
unload_msg:"F\u00F6r\u00E4ndringarna du gjorde kommer att g\u00E5 f\u00F6rlorade om du v\u00E4ljer att l\u00E4mna denna sida."
},
fullscreen:{
desc:"Sl\u00E5 av/p\u00E5 fullsk\u00E4rmsl\u00E4ge"
},
media:{
desc:"Infoga/redigera inb\u00E4ddad media",
edit:"Redigera inb\u00E4ddad media"
},
fullpage:{
desc:"Dokumentinst\u00E4llningar"
},
template:{
desc:"Infoga en f\u00E4rdig mall"
},
visualchars:{
desc:"Visa osynliga tecken"
},
spellchecker:{
desc:"Sl\u00E5 av/p\u00E5 r\u00E4ttstavningskontroll",
menu:"R\u00E4ttstavningsinst\u00E4llningar",
ignore_word:"Ignorera ord",
ignore_words:"Ignorera alla",
langs:"Spr\u00E5k",
wait:"Var god v\u00E4nta...",
sug:"F\u00F6rslag",
no_sug:"Inga f\u00F6rslag",
no_mpell:"Kunde inte finna n\u00E5gra felstavningar."
},
pagebreak:{
desc:"Infoga sidbrytning"
}}});