tinyMCE.addI18n('sk.advlink_dlg',{
title:"Vlo\u017Ei\u0165/editova\u0165 odkaz",
url:"URL odkazu",
target:"Cie\u013E",
titlefield:"N\u00E1zov",
is_email:"Zd\u00E1 sa, \u017Ee zadan\u00E1 URL je emailov\u00E1 adresa. Chce\u0161 vlo\u017Ei\u0165 povinn\u00FD prefix mailto: ?",
is_external:"Zd\u00E1 sa, \u017Ee zadan\u00E1 URL je extern\u00FD odkaz. Chce\u0161 vlo\u017Ei\u0165 povinn\u00FD prefix http:// ?",
list:"Zoznam odkazov",
general_tab:"Hlavn\u00E9",
popup_tab:"Popup",
events_tab:"Akcie",
advanced_tab:"Roz\u0161\u00EDren\u00E9",
general_props:"Hlavn\u00E9 nastavenia",
popup_props:"Vlastnosti popup okna",
event_props:"Akcie",
advanced_props:"Roz\u0161\u00EDren\u00E9 vlastnosti",
popup_opts:"Vlastnosti",
anchor_names:"Kotvy",
target_same:"Otvor\u00ED\u0165 v rovnakom okne/r\u00E1me",
target_parent:"Otvor\u00ED\u0165 v rodi\u010Dovsk\u00E9m okne/r\u00E1me",
target_top:"Otvori\u0165 v najvy\u0161\u0161om r\u00E1me (prep\u00ED\u0161e v\u0161etky r\u00E1my)",
target_blank:"Otvor\u00ED\u0165 v novom okne",
popup:"JavaScript popup",
popup_url:"Popup URL",
popup_name:"N\u00E1zov okna",
popup_return:"Vlo\u017Ei\u0165 'return false'",
popup_scrollbars:"Zobrazova\u0165 pos\u00FAvn\u00EDky",
popup_statusbar:"Zobrazova\u0165 stavov\u00FD riadok",
popup_toolbar:"Zobrazova\u0165 ovl\u00E1daciu li\u0161tu",
popup_menubar:"Zobrazova\u0165 menu",
popup_location:"Zobrazova\u0165 li\u0161tu umiestnen\u00ED",
popup_resizable:"Povoli\u0165 zmenu ve\u013Eksoti okna",
popup_dependent:"Z\u00E1vislos\u0165 (iba Mozilla/Firefox)",
popup_size:"Ve\u013Ekos\u0165",
popup_position:"Poz\u00EDcia (X/Y)",
id:"ID",
style:"CSS \u0161t\u00FDl",
classes:"Trieda",
target_name:"N\u00E1zov cie\u013Ea",
langdir:"Smer textu",
target_langcode:"Jazyk cie\u013Ea",
langcode:"K\u00F3d jazyka cie\u013Ea",
encoding:"Znakov\u00E9 k\u00F3dovanie cie\u013Ea",
mime:"MIME typ cie\u013Ea",
rel:"Vz\u0165ah str\u00E1nky k cie\u013Eu",
rev:"Vz\u0165ah cie\u013Ea k str\u00E1nke",
tabindex:"Poradie pre tabul\u00E1tor",
accesskey:"Kl\u00E1vesov\u00E1 skratka",
ltr:"Z \u013Eava do prava",
rtl:"Z prava do \u013Eava",
link_list:"Zoznam odkazov"
});