tinyMCE.addI18n('sq.emotions_dlg',{
title:"Fut emocion",
desc:"Emocionet",
cool:"I/e lezetsh\u00EBm",
cry:"Qaj",
embarassed:"Turp",
foot_in_mouth:"K\u00EBmba n\u00EB goj\u00EB",
frown:"Rrudh vetullat",
innocent:"I/e pafajsh\u00EBm",
kiss:"Puth",
laughing:"Qesh",
money_mouth:"Lek\u00EB n\u00EB goj\u00EB",
sealed:"Dh\u00EBmb\u00EBt e mbyllur",
smile:"Buz\u00EBqesh",
surprised:"I/e \u00E7uditur",
tongue_out:"Gjuha jasht\u00EB",
undecided:"I/e pavendosur",
wink:"Shkel syrin",
yell:"B\u00EBrtit"
});