tinyMCE.addI18n('et.template_dlg',{
title:"\u0160abloonid",
label:"\u0160abloon",
desc_label:"Kirjeldus",
desc:"Sisesta eeldefineeritud \u0161ablooni sisu",
select:"Vali \u0161abloon",
preview:"Eelvaade",
warning:"Hoiatus: \u0160ablooni uuendamine teistsugusega v\u00F5ib kaasa tuua andmete kaotsiminemist.",
mdate_format:"%Y-%m-%d %H:%M:%S",
cdate_format:"%Y-%m-%d %H:%M:%S",
months_long:"Jaanuar,Veebruar,M\u00E4rts,Aprill,Mai,Juuni,Juuli,August,September,Oktoober,November,Detsember",
months_short:"Jaan,Veeb,M\u00E4rts,Apr,Mai,Juuni,Juuli,Aug,Sep,Okt,Nov,Dets",
day_long:"P\u00FChap\u00E4ev,Esmasp\u00E4ev,Teisip\u00E4ev,Kolmap\u00E4ev,Neljap\u00E4ev,reede,Laup\u00E4ev,P\u00FChap\u00E4ev",
day_short:"P,E,T,K,N,R,L,P"
});