tinyMCE.addI18n('da.xhtmlxtras_dlg',{
attribute_label_title:"Titel",
attribute_label_id:"ID",
attribute_label_class:"Klasse",
attribute_label_style:"Stil",
attribute_label_cite:"Citat",
attribute_label_datetime:"Dato/tid",
attribute_label_langdir:"Tekstretning",
attribute_option_ltr:"Venstre mod h\u00F8jre",
attribute_option_rtl:"H\u00F8jre mod venstre",
attribute_label_langcode:"Sprog",
attribute_label_tabindex:"Tab-indeks",
attribute_label_accesskey:"Adgangsn\u00F8gle",
attribute_events_tab:"H\u00E6ndelser",
attribute_attrib_tab:"Attributter",
general_tab:"Generelt",
attrib_tab:"Attributter",
events_tab:"H\u00E6ndelser",
fieldset_general_tab:"Genererelle indstillinger",
fieldset_attrib_tab:"Element-attributter",
fieldset_events_tab:"Element-h\u00E6ndelser",
title_ins_element:"Inds\u00E6tbart element",
title_del_element:"Sletteklart element",
title_acronym_element:"Akronym element",
title_abbr_element:"Forkortet element",
title_cite_element:"Citationselement",
remove:"Slet",
insert_date:"Inds\u00E6t nuv\u00E6rende dato/tid",
option_ltr:"Venstre mod h\u00F8jre",
option_rtl:"H\u00F8jre mod venstre",
attribs_title:"Inds\u00E6t/rediger attributter"
});