tinyMCE.addI18n('vi.advanced_dlg',{
about_title:"Gi\u1EDBi thi\u1EC7u TinyMCE",
about_general:"Gi\u1EDBi thi\u1EC7u",
about_help:"Gi\u00FAp \u0111\u1EE1",
about_license:"Gi\u1EA5y ph\u00E9p",
about_plugins:"C\u00E1c ph\u1EA7n m\u1EDF r\u1ED9ng",
about_plugin:"Ph\u1EA7n m\u1EDF r\u1ED9ng",
about_author:"T\u00E1c gi\u1EA3",
about_version:"Phi\u00EAn b\u1EA3n",
about_loaded:"C\u00E1c ph\u1EA7n m\u1EDF r\u1ED9ng \u0111\u00E3 n\u1EA1p",
anchor_title:"Ch\u00E8n/s\u1EEDa m\u1ED1c (anchor)",
anchor_name:"T\u00EAn m\u1ED1c (anchor)",
code_title:"So\u1EA1n M\u00E3 HTML",
code_wordwrap:"Xu\u1ED1ng d\u00F2ng",
colorpicker_title:"Ch\u1ECDn m\u1ED9t m\u00E0u",
colorpicker_picker_tab:"B\u1ED9 ch\u1ECDn",
colorpicker_picker_title:"B\u1ED9 ch\u1ECDn m\u00E0u",
colorpicker_palette_tab:"B\u1EA3ng",
colorpicker_palette_title:"B\u1EA3ng m\u00E0u",
colorpicker_named_tab:"\u0110\u00E3 c\u00F3 t\u00EAn",
colorpicker_named_title:"M\u00E0u \u0111\u00E3 c\u00F3 t\u00EAn",
colorpicker_color:"M\u00E0u:",
colorpicker_name:"T\u00EAn:",
charmap_title:"Ch\u1ECDn k\u00FD t\u1EF1 \u0111\u1EB7c bi\u1EC7t",
image_title:"Ch\u00E8n/s\u1EEDa h\u00ECnh \u1EA3nh",
image_src:"D\u01B0\u1EDDng d\u1EABn \u0111\u1EBFn h\u00ECnh \u1EA3nh",
image_alt:"M\u00F4 t\u1EA3 h\u00ECnh \u1EA3nh",
image_list:"Danh s\u00E1ch h\u00ECnh \u1EA3nh",
image_border:"Vi\u1EC1n",
image_dimensions:"K\u00EDch th\u01B0\u1EDBc",
image_vspace:"Kho\u1EA3ng c\u00E1ch d\u1ECDc",
image_hspace:"Kho\u1EA3ng c\u00E1ch ngang",
image_align:"C\u0103n l\u1EC1",
image_align_baseline:"\u0110\u01B0\u1EDDng c\u01A1 b\u1EA3n",
image_align_top:"Tr\u00EAn",
image_align_middle:"Gi\u1EEFa",
image_align_bottom:"\u0110\u00E1y",
image_align_texttop:"Tr\u00EAn c\u1EE7a ch\u1EEF",
image_align_textbottom:"\u0110\u00E1y c\u1EE7a ch\u1EEF",
image_align_left:"Tr\u00E1i",
image_align_right:"Ph\u1EA3i",
link_title:"Ch\u00E8n/s\u1EEDa li\u00EAn k\u1EBFt",
link_url:"Li\u00EAn k\u1EBFt",
link_target:"\u0110\u00EDch",
link_target_same:"M\u1EDF li\u00EAn k\u1EBFt trong c\u00F9ng c\u1EEDa s\u1ED5",
link_target_blank:"M\u1EDF li\u00EAn k\u1EBFt trong c\u1EEDa s\u1ED5 m\u1EDBi",
link_titlefield:"Ti\u00EAu \u0111\u1EC1",
link_is_email:"Li\u00EAn k\u1EBFt b\u1EA1n nh\u1EADp c\u00F3 v\u1EBB nh\u01B0 l\u00E0 m\u1ED9t \u0111\u1ECBa ch\u1EC9 email, b\u1EA1n c\u00F3 mu\u1ED1n th\u00EAm ph\u1EA7n mailto: v\u00E0o tr\u01B0\u1EDBc li\u00EAn k\u1EBFt?",
link_is_external:"Li\u00EAn k\u1EBFt b\u1EA1n nh\u1EADp c\u00F3 v\u1EBB nh\u01B0 l\u00E0 m\u1ED9t trang web ngo\u00E0i, b\u1EA1n c\u00F3 mu\u1ED1n th\u00EAm ph\u1EA7n http:// v\u00E0o tr\u01B0\u1EDBc li\u00EAn k\u1EBFt?",
link_list:"Danh s\u00E1ch li\u00EAn k\u1EBFt"
});