tinyMCE.addI18n('sq.advanced_dlg',{
about_title:"Rreth TinyMCE",
about_general:"Rreth",
about_help:"Ndihm\u00EB",
about_license:"Li\u00E7enca",
about_plugins:"Shtesa",
about_plugin:"Shtes\u00EB",
about_author:"Autori",
about_version:"Versioni",
about_loaded:"Shtesa t\u00EB ngarkuara",
anchor_title:"Fut/edito lidhje",
anchor_name:"Emri i lidhjes",
code_title:"Edituesi i kodit HTML",
code_wordwrap:"Word wrap",
colorpicker_title:"Zgjidh nj\u00EB ngjyr\u00EB",
colorpicker_picker_tab:"Zgjedh\u00EBsi",
colorpicker_picker_title:"Zgjedh\u00EBsi i ngjyr\u00EBs",
colorpicker_palette_tab:"Librari",
colorpicker_palette_title:"Ngjyrat e Libraris\u00EB",
colorpicker_named_tab:"Em\u00EBruar",
colorpicker_named_title:"Ngjyrat e em\u00EBruara",
colorpicker_color:"Ngjyra:",
colorpicker_name:"Emri:",
charmap_title:"Zgjidh karakter t\u00EB personalizuar",
image_title:"Fut/edio foto",
image_src:"URL e fotos",
image_alt:"P\u00EBrshkrimi i fotos",
image_list:"Lista e fotove",
image_border:"Korniza",
image_dimensions:"P\u00EBrmasat",
image_vspace:"Hap\u00EBsira Vertikale",
image_hspace:"Hap\u00EBsira Horizontale",
image_align:"Drejtimi",
image_align_baseline:"Vij\u00EB fundore",
image_align_top:"Krye",
image_align_middle:"Mes",
image_align_bottom:"Fund",
image_align_texttop:"N\u00EB krye t\u00EB tekstit",
image_align_textbottom:"N\u00EB fund t\u00EB tekstit",
image_align_left:"Majtas",
image_align_right:"Djathtas",
link_title:"Fut/edito lidhje",
link_url:"URL e lidhjes",
link_target:"Sh\u00EBnjestra",
link_target_same:"Hape lidhjen n\u00EB t\u00EB nj\u00EBjt\u00EBn dritare",
link_target_blank:"Hape lidhjen n\u00EB dritare t\u00EB re",
link_titlefield:"Titulli",
link_is_email:"Lidhja q\u00EB keni futur duket si adres\u00EB emaili. Doni t\u00EB shtoni prefiksin mailto:?",
link_is_external:"Lidhja q\u00EB keni futur duket si lidhje e jasht\u00EBme. Doni t\u00EB shtoni prefiksin http://?",
link_list:"Lista e lidhjeve"
});