tinyMCE.addI18n('tr.xhtmlxtras_dlg',{
attribute_label_title:"Ba\u015Fl\u0131k",
attribute_label_id:"ID",
attribute_label_class:"S\u0131n\u0131f",
attribute_label_style:"Stil",
attribute_label_cite:"Belirt",
attribute_label_datetime:"Tarih/Zaman",
attribute_label_langdir:"Metin y\u00F6nelimi",
attribute_option_ltr:"Soldan sa\u011Fa",
attribute_option_rtl:"Sa\u011Fdan sola",
attribute_label_langcode:"Dil",
attribute_label_tabindex:"Sekme \u0130ndeksi",
attribute_label_accesskey:"Eri\u015Fim Anahtar\u0131",
attribute_events_tab:"Olaylar",
attribute_attrib_tab:"Nitelikler",
general_tab:"Genel",
attrib_tab:"Nitelikler",
events_tab:"Olaylar",
fieldset_general_tab:"Genel Ayarlar",
fieldset_attrib_tab:"Eleman Nitelikleri",
fieldset_events_tab:"Eleman Olaylar\u0131",
title_ins_element:"Ekleme Eleman\u0131",
title_del_element:"Silme Eleman\u0131",
title_acronym_element:"K\u0131saltma Eleman\u0131",
title_abbr_element:"K\u0131saad Eleman\u0131",
title_cite_element:"Belirtme Eleman\u0131",
remove:"Kald\u0131r",
insert_date:"\u015Eimdiki tarih/zaman\u0131 ekle",
option_ltr:"Soldan sa\u011Fa",
option_rtl:"Sa\u011Fdan sola",
attribs_title:"Nitelik ekle/d\u00FCzenle"
});