tinyMCE.addI18n('cs.advanced',{
style_select:"--- Styly ---",
font_size:"- Velikost p\u00EDsma -",
fontdefault:"--- P\u00EDsma ---",
block:"-- Form\u00E1t --",
paragraph:"Odstavec",
div:"Div",
address:"Adresa",
pre:"P\u0159edform\u00E1tov\u00E1no",
h1:"Nadpis 1",
h2:"Nadpis 2",
h3:"Nadpis 3",
h4:"Nadpis 4",
h5:"Nadpis 5",
h6:"Nadpis 6",
blockquote:"Odsazen\u00FD blok textu",
code:"K\u00F3d",
samp:"Vzorek",
dt:"Term\u00EDn",
dd:"Definice",
bold_desc:"Tu\u010Dn\u00E9 (Ctrl+B)",
italic_desc:"Kurz\u00EDva (Ctrl+I)",
underline_desc:"Podtr\u017Een\u00E9 (Ctrl+U)",
striketrough_desc:"P\u0159e\u0161krtnut\u00E9",
justifyleft_desc:"Zarovnat doleva",
justifycenter_desc:"Zarovnat na st\u0159ed",
justifyright_desc:"Zarovnat doprava",
justifyfull_desc:"Zarovnat do bloku",
bullist_desc:"Seznam s odr\u00E1\u017Ekami",
numlist_desc:"\u010C\u00EDslovan\u00FD seznam",
outdent_desc:"Zmen\u0161it odsazen\u00ED",
indent_desc:"Zv\u011Bt\u0161it odsazen\u00ED",
undo_desc:"Zp\u011Bt (Ctrl+Z)",
redo_desc:"Znovu (Ctrl+Y)",
link_desc:"Vlo\u017Eit/upravit odkaz",
unlink_desc:"Zru\u0161it odkaz",
image_desc:"Vlo\u017Eit/upravit obr\u00E1zek",
cleanup_desc:"Vy\u010Distit k\u00F3d",
code_desc:"Editovat HTML k\u00F3d",
sub_desc:"Doln\u00ED index",
sup_desc:"Horn\u00ED index",
hr_desc:"Vlo\u017Eit vodorovn\u00FD odd\u011Blova\u010D",
removeformat_desc:"Zru\u0161it form\u00E1tov\u00E1n\u00ED",
custom1_desc:"Libovoln\u00FD popisek",
forecolor_desc:"Barva textu",
backcolor_desc:"Barva pozad\u00ED",
charmap_desc:"Vlo\u017Eit speci\u00E1ln\u00ED znak",
visualaid_desc:"Zviditelnit zna\u010Dky",
anchor_desc:"Vlo\u017Eit/upravit kotvu",
cut_desc:"Vyjmout",
copy_desc:"Kop\u00EDrovat",
paste_desc:"Vlo\u017Eit",
image_props_desc:"Vlastnosti obr\u00E1zku",
newdocument_desc:"Nov\u00FD dokument",
help_desc:"N\u00E1pov\u011Bda",
blockquote_desc:"Blok citace",
clipboard_msg:"Funkce kop\u00EDrovat/vyjmout/vlo\u017Eit nejsou pou\u017Eiteln\u00E9 v Mozille a Firefoxu.\nChcete v\u00EDce informac\u00ED?",
path:"Cesta",
newdocument:"Jste si opravdu jisti, \u017Ee chcete vymazat ve\u0161ker\u00FD obsah?",
toolbar_focus:"Skok na li\u0161tu n\u00E1stroj\u016F - Alt+Q, skok do editoru - Alt-Z, skok na cestu prvk\u016F - Alt-X",
more_colors:"Dal\u0161\u00ED barvy"
});