tinyMCE.addI18n('cy.advanced_dlg',{
about_title:"Ynglyn TinyMCE",
about_general:"Ynglyn",
about_help:"Cymorth",
about_license:"Twyddedd",
about_plugins:"Ategion",
about_plugin:"Ategyn",
about_author:"Awdur",
about_version:"Fersion",
about_loaded:"Ategion wedi llwytho",
anchor_title:"Mewnosod/golygu angor",
anchor_name:"Enw angor",
code_title:"Golygydd Ffynhonell HTML",
code_wordwrap:"Amlapio geiriau",
colorpicker_title:"Dewis lliw",
colorpicker_picker_tab:"Dweisydd",
colorpicker_picker_title:"Dewisydd lliw",
colorpicker_palette_tab:"Palet",
colorpicker_palette_title:"Lliwiau palet",
colorpicker_named_tab:"Wedi'u enwi",
colorpicker_named_title:"Lliwiau wedi'u enwi",
colorpicker_color:"Lliw:",
colorpicker_name:"Enw:",
charmap_title:"Dewis n\u00F4d addasiedig",
image_title:"Mewnosod/golygu delwedd",
image_src:"URL delwedd",
image_alt:"disgrifiad delwedd",
image_list:"Rhestr delweddau",
image_border:"Border",
image_dimensions:"Dimensiynau",
image_vspace:"Gofod fertigol",
image_hspace:"Gofod llorweddol",
image_align:"Aliniad",
image_align_baseline:"Gwaelodlin",
image_align_top:"Pen",
image_align_middle:"Canol",
image_align_bottom:"Gwaelod",
image_align_texttop:"Pen testun",
image_align_textbottom:"Gwaelod testun",
image_align_left:"Chwith",
image_align_right:"De",
link_title:"Mewnosod/golygu cyswllt",
link_url:"URL cyswllt",
link_target:"Targed",
link_target_same:"Agor cyswllt yn yr un ffenst",
link_target_blank:"Agor cyswllt mewn ffenst newydd",
link_titlefield:"Teitl",
link_is_email:"Mae'r URL a rydych wedi rhoi yn edrych fel cyferiad e-bost, ydych chi eisiau ychwanegu'r rhagddodiad mailto: sydd angen?",
link_is_external:"Mae'r URL a rydych wedi rhoi yn edrych fel cyswllt allannol, ydych chi eisiau ychwanegu'r rhagddodiad http:// sydd angen?",
link_list:"Rhestr cysylltau"
});