tinyMCE.addI18n('tr.media_dlg',{
title:"T\u00FCmle\u015Fik medya ekle/d\u00FCzenle",
general:"Genel",
advanced:"Geli\u015Fmi\u015F",
file:"Dosya/URL",
list:"Liste",
size:"Boyutlar",
preview:"\u00D6nizleme",
constrain_proportions:"Orant\u0131y\u0131 koru",
type:"Tip",
id:"Id",
name:"\u0130sim",
class_name:"S\u0131n\u0131f",
vspace:"Dik.Bo\u015Fluk",
hspace:"Yty.Bo\u015Fluk",
play:"Oto.\u00C7al",
loop:"D\u00F6ng\u00FC",
menu:"Men\u00FC g\u00F6ster",
quality:"Kalite",
scale:"\u00D6l\u00E7ek",
align:"Hizala",
salign:"SHizala",
wmode:"WMode",
bgcolor:"Arkaplan",
base:"Taban",
flashvars:"Flash de\u011Fi\u015F.",
liveconnect:"SWLiveConnect",
autohref:"Oto.HREF",
cache:"\u00D6nbellek",
hidden:"Gizli",
controller:"Kontrolc\u00FC",
kioskmode:"Kiosk modu",
playeveryframe:"Her \u00E7er\u00E7eveyi \u00E7al",
targetcache:"Hedef \u00F6nbellek",
correction:"D\u00FCzeltmesiz",
enablejavascript:"JavaScript etkin",
starttime:"Ba\u015Flang\u0131c zaman\u0131",
endtime:"Biti\u015F zaman\u0131",
href:"Href",
qtsrcchokespeed:"T\u0131kanma h\u0131z\u0131",
target:"Hedef",
volume:"Ses d\u00FCzeyi",
autostart:"Oto.ba\u015Flat",
enabled:"Etkin",
fullscreen:"Tam ekran",
invokeurls:"\u00C7a\u011Fr\u0131lacak URL'ler",
mute:"Sessiz",
stretchtofit:"S\u0131\u011Facak \u015Fekilde boyutland\u0131r",
windowlessvideo:"Penceresiz video",
balance:"Balans",
baseurl:"Taban URL",
captioningid:"Ba\u015Fl\u0131kland\u0131rma id",
currentmarker:"\u015Eimdiki i\u015Faret\u00E7i",
currentposition:"\u015Eimdiki konum",
defaultframe:"Varsay\u0131lan \u00E7er\u00E7eve",
playcount:"\u00C7alma say\u0131s\u0131",
rate:"Oran",
uimode:"UI Modu",
flash_options:"Flash se\u00E7enekleri",
qt_options:"Quicktime se\u00E7enekleri",
wmp_options:"Windows media player se\u00E7enekleri",
rmp_options:"Real media player se\u00E7enekleri",
shockwave_options:"Shockwave se\u00E7enekleri",
autogotourl:"Otomatik gidilecek URL",
center:"Ortala",
imagestatus:"Resim durumu",
maintainaspect:"Orant\u0131y\u0131 koru",
nojava:"Java yok",
prefetch:"\u00D6n-getirme",
shuffle:"Kar\u0131\u015Ft\u0131r",
console:"Konsol",
numloop:"D\u00F6ng\u00FC say\u0131s\u0131",
controls:"Kontroller",
scriptcallbacks:"Script \u00E7a\u011Fr\u0131mlar\u0131",
swstretchstyle:"Esnetme stili",
swstretchhalign:"Esnetme Y-Hiza",
swstretchvalign:"Esnetme D-Hiza",
sound:"Ses",
progress:"\u0130lerleme",
qtsrc:"QT Kay.",
qt_stream_warn:"Ak\u0131nt\u0131 rtsp kaynaklar\u0131 geli\u015Fmi\u015F alt\u0131ndaki QT Kay. alan\u0131na girilmeli.\nSrc alan\u0131na ayr\u0131ca ak\u0131nt\u0131l\u0131 olmayan bir s\u00FCr\u00FCm\u00FC de girmelisiniz..",
align_top:"\u00DCst",
align_right:"Sa\u011Fa",
align_bottom:"Alt",
align_left:"Sola",
align_center:"Ortala",
align_top_left:"Sol \u00DCst",
align_top_right:"Sa\u011F \u00FCst",
align_bottom_left:"Sol alt",
align_bottom_right:"Sa\u011F alt",
flv_options:"Flash video se\u00E7enekleri",
flv_scalemode:"Esnetme modu",
flv_buffer:"Tampon",
flv_startimage:"Ba\u015Flang\u0131\u00E7 resmi",
flv_starttime:"Ba\u015Flang\u0131\u00E7 zaman\u0131",
flv_defaultvolume:"Varsay\u0131lan ses d\u00FCzeyi",
flv_hiddengui:"Gizli GUI",
flv_autostart:"Otomatik ba\u015Flat",
flv_loop:"D\u00F6ng\u00FC",
flv_showscalemodes:"\u00D6l\u00E7ek modlar\u0131n\u0131 g\u00F6ster",
flv_smoothvideo:"Video'yu yumu\u015Fat",
flv_jscallback:"JS \u00C7a\u011Fr\u0131mlar\u0131"
});