tinyMCE.addI18n({is:{
common:{
edit_confirm:"Viltu nota WYSIWYG ritil fyrir \u00FEetta textasv\u00E6\u00F0i?",
apply:"Sta\u00F0festa",
insert:"Setja inn",
update:"Uppf\u00E6ra",
cancel:"H\u00E6tta vi\u00F0",
close:"Loka",
browse:"Gramsa",
class_name:"Klasi",
not_set:"-- Ekki skilgreint --",
clipboard_msg:"Afrita/Klippa/L\u00EDma er ekki a\u00F0gengilegt \u00ED Mozilla og Firefox eins og er.\nViltu f\u00E1 n\u00E1nari uppl\u00FDsingar?",
clipboard_no_support:"Ekki stutt \u00ED \u00FE\u00EDnum vefsko\u00F0ara, nota\u00F0ur fl\u00FDtilykla \u00ED sta\u00F0inn.",
popup_blocked:"Afsaki\u00F0, uppsprettuv\u00F6rnin \u00FE\u00EDn (popup blocker) hefur blokka\u00F0 glugga sem er hluti af ritlinum. \u00DE\u00FA ver\u00F0ur a\u00F0 sl\u00F6kkva \u00E1 uppsprettuv\u00F6rn til a\u00F0 geta nota\u00F0 \u00FEennan ritil.",
invalid_data:"Villa: Vitlaus gildi slegin inn, \u00FEau eru merkt me\u00F0 rau\u00F0u.",
more_colors:"Fleiri litir"
},
contextmenu:{
align:"J\u00F6fnun",
left:"Vinstri",
center:"Mi\u00F0ja",
right:"H\u00E6gri",
full:"Full"
},
insertdatetime:{
date_fmt:"%Y-%m-%d",
time_fmt:"%H:%M:%S",
insertdate_desc:"Setja inn dagsetningu",
inserttime_desc:"Setja inn t\u00EDmasetningu",
months_long:"Jan\u00FAar,Febr\u00FAar,Mars,Apr\u00EDl,Ma\u00ED,J\u00FAn\u00ED,J\u00FAl\u00ED,\u00C1g\u00FAst,September,Okt\u00F3ber,N\u00F3vember,Desember",
months_short:"Jan,Feb,Mar,Apr,Ma\u00ED,J\u00FAn,J\u00FAl,\u00C1gs,Sep,Okt,N\u00F3v,Des",
day_long:"Sunnudagur,M\u00E1nudagur,\u00DEri\u00F0judagur,Mi\u00F0vikudagur,Fimmtudagur,F\u00F6studagur,Laugardagur,Sunnudagur",
day_short:"Sun,M\u00E1n,\u00DEri,Mi\u00F0,Fim,F\u00F6s,Lau,Sun"
},
print:{
print_desc:"Prenta"
},
preview:{
preview_desc:"Forsko\u00F0a"
},
directionality:{
ltr_desc:"Fr\u00E1 vinstri til h\u00E6gri",
rtl_desc:"Fr\u00E1 h\u00E6gri til vinstri"
},
layer:{
insertlayer_desc:"Setja inn n\u00FDtt lag",
forward_desc:"F\u00E6ra framfyrir",
backward_desc:"F\u00E6ra afturfyrir",
absolute_desc:"Taka af/setja \u00E1 absolute positioning",
content:"N\u00FDtt lag..."
},
save:{
save_desc:"Vista",
cancel_desc:"H\u00E6tta vi\u00F0 allar breytingar"
},
nonbreaking:{
nonbreaking_desc:"Setja inn bil staf"
},
iespell:{
iespell_desc:"Lesa yfir",
download:"ieSpell fannst ekki. Viltu setja \u00FEa\u00F0 inn n\u00FAna?"
},
advhr:{
advhr_desc:"Horizontal rule"
},
emotions:{
emotions_desc:"Broskarlar"
},
searchreplace:{
search_desc:"Finna",
replace_desc:"Finna/Skipta \u00FAt"
},
advimage:{
image_desc:"Setja inn/breyta mynd"
},
advlink:{
link_desc:"Insert/edit link"
},
xhtmlxtras:{
cite_desc:"Citation",
abbr_desc:"Abbreviation",
acronym_desc:"Acronym",
del_desc:"Deletion",
ins_desc:"Insertion",
attribs_desc:"Insert/Edit Attributes"
},
style:{
desc:"Edit CSS Style"
},
paste:{
paste_text_desc:"Paste as Plain Text",
paste_word_desc:"Paste from Word",
selectall_desc:"Select All"
},
paste_dlg:{
text_title:"Use CTRL+V on your keyboard to paste the text into the window.",
text_linebreaks:"Keep linebreaks",
word_title:"Use CTRL+V on your keyboard to paste the text into the window."
},
table:{
desc:"Inserts a new table",
row_before_desc:"Insert row before",
row_after_desc:"Insert row after",
delete_row_desc:"Delete row",
col_before_desc:"Insert column before",
col_after_desc:"Insert column after",
delete_col_desc:"Remove column",
split_cells_desc:"Split merged table cells",
merge_cells_desc:"Merge table cells",
row_desc:"Table row properties",
cell_desc:"Table cell properties",
props_desc:"Table properties",
paste_row_before_desc:"Paste table row before",
paste_row_after_desc:"Paste table row after",
cut_row_desc:"Cut table row",
copy_row_desc:"Copy table row",
del:"Delete table",
row:"Row",
col:"Column",
cell:"Cell"
},
autosave:{
unload_msg:"The changes you made will be lost if you navigate away from this page."
},
fullscreen:{
desc:"Toggle fullscreen mode"
},
media:{
desc:"Insert / edit embedded media",
edit:"Edit embedded media"
},
fullpage:{
desc:"Document properties"
},
template:{
desc:"Insert predefined template content"
},
visualchars:{
desc:"Visual control characters on/off."
},
spellchecker:{
desc:"Toggle spellchecker",
menu:"Spellchecker settings",
ignore_word:"Ignore word",
ignore_words:"Ignore all",
langs:"Languages",
wait:"Please wait...",
sug:"Suggestions",
no_sug:"No suggestions",
no_mpell:"No misspellings found."
},
pagebreak:{
desc:"Insert page break."
}}});