tinyMCE.addI18n('cs.xhtmlxtras_dlg',{
attribute_label_title:"Titulek",
attribute_label_id:"ID",
attribute_label_class:"T\u0159\u00EDda",
attribute_label_style:"Styl",
attribute_label_cite:"Citace",
attribute_label_datetime:"Datum/\u010Cas",
attribute_label_langdir:"Sm\u011Br textu",
attribute_option_ltr:"Zleva doprava",
attribute_option_rtl:"Zprava doleva",
attribute_label_langcode:"Jazyk",
attribute_label_tabindex:"Tabindex",
attribute_label_accesskey:"P\u0159\u00EDstupov\u00E1 kl\u00E1vesa",
attribute_events_tab:"Ud\u00E1losti",
attribute_attrib_tab:"Atributy",
general_tab:"Hlavn\u00ED",
attrib_tab:"Atributy",
events_tab:"Ud\u00E1losti",
fieldset_general_tab:"Hlavn\u00ED nastaven\u00ED",
fieldset_attrib_tab:"Atributy prvku",
fieldset_events_tab:"Atributy ud\u00E1losti",
title_ins_element:"Vlo\u017Een\u00ED prvku",
title_del_element:"Vymaz\u00E1n\u00ED prvku",
title_acronym_element:"Akronym",
title_abbr_element:"Zkratka",
title_cite_element:"Citace",
remove:"Odstranit",
insert_date:"Vlo\u017Eit aktu\u00E1ln\u00ED datum/\u010Das",
option_ltr:"Zleva doprava",
option_rtl:"Zprava doleva",
attribs_title:"Vlo\u017Eit/editovat atributy"
});