tinyMCE.addI18n('nn.xhtmlxtras_dlg',{
attribute_label_title:"Tittel",
attribute_label_id:"ID",
attribute_label_class:"Klasse",
attribute_label_style:"Stil",
attribute_label_cite:"Stad",
attribute_label_datetime:"Dato/tid",
attribute_label_langdir:"Tekstretning",
attribute_option_ltr:"Venstre mot h\u00F8gre",
attribute_option_rtl:"H\u00F8gre mot venstre",
attribute_label_langcode:"Spr\u00E5k",
attribute_label_tabindex:"Tabuleringsindeks",
attribute_label_accesskey:"Tilgangsn\u00F8kkel",
attribute_events_tab:"Hendingar",
attribute_attrib_tab:"Attributt",
general_tab:"Generelt",
attrib_tab:"Attributtar",
events_tab:"Hendingar",
fieldset_general_tab:"Generelle innstillingar",
fieldset_attrib_tab:"Elementattributtar",
fieldset_events_tab:"Elementhendingar",
title_ins_element:"Innsetjingselement",
title_del_element:"Sletteelement",
title_acronym_element:"Akronymelement",
title_abbr_element:"Forkortingselement",
title_cite_element:"Sitatelement",
remove:"Fjern",
insert_date:"Set inn dato/ti",
option_ltr:"Venstre mot h\u00F8gre",
option_rtl:"H\u00F8gre mot venstre",
attribs_title:"Set inn / endre attributt"
});