tinyMCE.addI18n('az.advimage_dlg',{
tab_general:"\u00DCmumi",
tab_appearance:"G\u00F6r\u00FCn\u00FC\u015F",
tab_advanced:"\u018Flav\u0259",
general:"\u00DCmumi",
title:"Ad\u0131",
preview:"\u0130lkin bax\u0131\u015F",
constrain_proportions:"Proporsiyalar\u0131 saxla",
langdir:"Dilin istiqam\u0259tl\u0259ndirilm\u0259si",
langcode:"Dil kodu",
long_desc:"\u018Ftrafl\u0131 t\u0259svir\u0259 ke\u00E7id",
style:"Stil",
classes:"Sinifl\u0259r",
ltr:"Solda-sa\u011Fa",
rtl:"Sa\u011Fda-sola",
id:"\u0130dentifikator",
map:"X\u0259rit\u0259-\u015F\u0259kil",
swap_image:"\u015E\u0259kli d\u0259yi\u015F",
alt_image:"Alternativ \u015F\u0259kil",
mouseover:"si\u00E7an\u0131 g\u0259tirdikd\u0259",
mouseout:"si\u00E7an\u0131 uzaqla\u015Fd\u0131rd\u0131qda",
misc:"M\u00FCxt\u0259lif",
example_img:"Xarici g\u00F6r\u00FCn\u00FC\u015F\u0259 ilkin bax\u0131\u015F",
missing_alt:"\u018Fminsiniz ki, \u015F\u0259kl\u0259 t\u0259svir yazmadan davam etm\u0259k ist\u0259yirsiniz? T\u0259svirsiz \u015F\u0259kil i\u015F qabiliyy\u0259ti a\u015Fa\u011F\u0131 olan v\u0259 ya \u015F\u0259klin s\u00F6nd\u00FCr\u00FClm\u00FC\u015F funksiyas\u0131 il\u0259 m\u0259tn b\u0259l\u0259d\u00E7isind\u0259n istifad\u0259 ed\u0259n istifad\u0259\u00E7il\u0259r\u0259 \u0259l\u00E7atmaz ola bil\u0259r.",
dialog_title:"\u015E\u0259kil \u0259lav\u0259/redakt\u0259 et",
src:"\u015E\u0259kil \u00FCnvan\u0131",
alt:"\u015E\u0259kil t\u0259sviri",
list:"\u015E\u0259kil siyah\u0131s\u0131",
border:"S\u0259rh\u0259d",
dimensions:"\u00D6l\u00E7\u00FCl\u0259r",
vspace:"\u015Eaquli f\u0259za",
hspace:"\u00DCf\u00FCqi f\u0259za",
align:"Tarazla\u015Fd\u0131rma",
align_baseline:"Bin\u00F6vr\u0259 il\u0259",
align_top:"Yuxar\u0131 il\u0259",
align_middle:"M\u0259rk\u0259z il\u0259",
align_bottom:"A\u015Fa\u011F\u0131 il\u0259",
align_texttop:"M\u0259tn yuxar\u0131 il\u0259",
align_textbottom:"M\u0259tn a\u015Fa\u011F\u0131s\u0131 il\u0259",
align_left:"Sola",
align_right:"Sa\u011Fa",
image_list:"\u015E\u0259kil siyah\u0131s\u0131"
});