tinyMCE.addI18n('de.advanced',{
style_select:"Format",
font_size:"Schriftgr\u00F6\u00DFe",
fontdefault:"Schriftart",
block:"Vorlage",
paragraph:"Absatz",
div:"Zusammenh\u00E4ngender Bereich",
address:"Adresse",
pre:"Rohdaten",
h1:"\u00DCberschrift 1",
h2:"\u00DCberschrift 2",
h3:"\u00DCberschrift 3",
h4:"\u00DCberschrift 4",
h5:"\u00DCberschrift 5",
h6:"\u00DCberschrift 6",
blockquote:"Zitatblock",
code:"Code",
samp:"Beispiel",
dt:"Definitionsbegriff",
dd:"Definitionsbeschreibung",
bold_desc:"Fett (Strg+B)",
italic_desc:"Kursiv (Strg+I)",
underline_desc:"Unterstrichen (Strg+U)",
striketrough_desc:"Durchgestrichen",
justifyleft_desc:"Links ausgerichtet",
justifycenter_desc:"Mittig ausgerichtet",
justifyright_desc:"Rechts ausgerichtet",
justifyfull_desc:"Blocksatz",
bullist_desc:"Unsortierte Liste",
numlist_desc:"Sortierte Liste",
outdent_desc:"Ausr\u00FCcken",
indent_desc:"Einr\u00FCcken",
undo_desc:"R\u00FCckg\u00E4ngig (Strg+Z)",
redo_desc:"Wiederholen (Strg+Y)",
link_desc:"Link einf\u00FCgen/ver\u00E4ndern",
unlink_desc:"Link entfernen",
image_desc:"Bild einf\u00FCgen/ver\u00E4ndern",
cleanup_desc:"Quellcode aufr\u00E4umen",
code_desc:"HTML-Quellcode bearbeiten",
sub_desc:"Tiefgestellt",
sup_desc:"Hochgestellt",
hr_desc:"Trennlinie einf\u00FCgen",
removeformat_desc:"Formatierungen zur\u00FCcksetzen",
custom1_desc:"Benutzerdefinierte Beschreibung",
forecolor_desc:"Textfarbe",
backcolor_desc:"Hintergrundfarbe",
charmap_desc:"Sonderzeichen einf\u00FCgen",
visualaid_desc:"Hilfslinien und unsichtbare Elemente ein-/ausblenden",
anchor_desc:"Anker einf\u00FCgen/ver\u00E4ndern",
cut_desc:"Ausschneiden",
copy_desc:"Kopieren",
paste_desc:"Einf\u00FCgen",
image_props_desc:"Bildeigenschaften",
newdocument_desc:"Neues Dokument",
help_desc:"Hilfe",
blockquote_desc:"Zitatblock",
clipboard_msg:"Kopieren, Ausschneiden und Einf\u00FCgen sind im Mozilla Firefox nicht m\u00F6glich.\r\nWollen Sie mehr \u00FCber dieses Problem erfahren?",
path:"Pfad",
newdocument:"Wollen Sie wirklich den ganzen Inhalt l\u00F6schen?",
toolbar_focus:"Zur Werkzeugleiste springen: Alt+Q; Zum Editor springen: Alt-Z; Zum Elementpfad springen: Alt-X",
more_colors:"Weitere Farben",
anchor_delta_width:"13"
});