tinyMCE.addI18n('lv.advanced',{
style_select:"Stili",
font_size:"Fonta lielums",
fontdefault:"Fonta veids",
block:"Form\u0101ts",
paragraph:"Rindkopa",
div:"Div\u012Bzija",
address:"Adrese",
pre:"Priek\u0161format\u0113ts",
h1:"Virsraksts 1",
h2:"Virsraksts 2",
h3:"Virsraksts 3",
h4:"Virsraksts 4",
h5:"Virsraksts 5",
h6:"Virsraksts 6",
blockquote:"Cit\u0101ts",
code:"Kods",
samp:"Koda piem\u0113rs",
dt:"Defin\u012Bcijas termins ",
dd:"Defin\u012Bcijas apraksts",
bold_desc:"Treknraksts (Ctrl+B)",
italic_desc:"Sl\u012Bpraksts (Ctrl+I)",
underline_desc:"Pasv\u012Btrojums (Ctrl+U)",
striketrough_desc:"P\u0101rsv\u012Btrojums",
justifyleft_desc:"Novietot pa kreisi",
justifycenter_desc:"Centr\u0113t",
justifyright_desc:"Novietot pa labi",
justifyfull_desc:"Nol\u012Bdzin\u0101t malas",
bullist_desc:"Nenumur\u0113ts saraksts",
numlist_desc:"Numur\u0113ts saraksts",
outdent_desc:"Uzk\u0101pe",
indent_desc:"Atk\u0101pe",
undo_desc:"Atsaukt (Ctrl+Z)",
redo_desc:"Atatsaukt (Ctrl+Y)",
link_desc:"Ievietot/Redi\u0123\u0113t saiti",
unlink_desc:"Atsait\u0113t",
image_desc:"Ievietot/Redi\u0123\u0113t att\u0113lu",
cleanup_desc:"Izt\u012Br\u012Bt nek\u0101rt\u012Bgu kodu",
code_desc:"Redi\u0123\u0113t HTML kodu",
sub_desc:"Apak\u0161raksts",
sup_desc:"Aug\u0161raksts",
hr_desc:"Ievietot horizont\u0101lu sv\u012Btru",
removeformat_desc:"Izdz\u0113st format\u0113to",
custom1_desc:"Tevis izdom\u0101ts apraksts \u0161eit",
forecolor_desc:"Uzst\u0101d\u012Bt teksta kr\u0101su",
backcolor_desc:"Uzst\u0101d\u012Bt fona kr\u0101su",
charmap_desc:"Ievietot simbolu",
visualaid_desc:"Uzlikt/Nov\u0101kt pal\u012Bgsv\u012Btras/neredzamos elementus",
anchor_desc:"Ievietot/Redi\u0123\u0113t enkursaiti",
cut_desc:"Izgriezt",
copy_desc:"Kop\u0113t",
paste_desc:"Iekop\u0113t",
image_props_desc:"Bildes iestat\u012Bjumi",
newdocument_desc:"Jauns dokuments",
help_desc:"Pal\u012Bdz\u012Bba",
blockquote_desc:"Cit\u0101ts",
clipboard_msg:"Iesp\u0113ja Kop\u0113t/Izgriezt/Iekop\u0113t nav pieejama p\u0101rl\u016Bkiem Mozilla and Firefox.\r\nVai J\u016Bs v\u0113laties uzzin\u0101t vair\u0101k par \u0161o probl\u0113mu?",
path:"Atra\u0161an\u0101s vieta",
newdocument:"Vai J\u016Bs esat p\u0101rliecin\u0101ti, ka v\u0113laties izdz\u0113st visu saturu?",
toolbar_focus:"Iet uz r\u012Bkpog\u0101m - Alt+Q, Iet uz redaktoru - Alt-Z, Iet uz elementa atra\u0161an\u0101s vietu - Alt-X",
more_colors:"Vair\u0101k kr\u0101su"
});