tinyMCE.addI18n('et.xhtmlxtras_dlg',{
attribute_label_title:"Pealkiri",
attribute_label_id:"ID",
attribute_label_class:"Klass",
attribute_label_style:"Stiil",
attribute_label_cite:"Tsitaat",
attribute_label_datetime:"Kuup\u00E4ev/aeg",
attribute_label_langdir:"Teksti suund",
attribute_option_ltr:"Vasakult paremale",
attribute_option_rtl:"Paremalt vasakule",
attribute_label_langcode:"Keel",
attribute_label_tabindex:"Sisujuht",
attribute_label_accesskey:"Ligip\u00E4\u00E4suklahv",
attribute_events_tab:"S\u00FCndmused",
attribute_attrib_tab:"Atribuudid",
general_tab:"\u00DCldine",
attrib_tab:"Atribuudid",
events_tab:"S\u00FCndmused",
fieldset_general_tab:"\u00DCldised seaded",
fieldset_attrib_tab:"Elementide atribuudid",
fieldset_events_tab:"Elementide s\u00FCndmused",
title_ins_element:"Elemendi sisestus",
title_del_element:"Elemendi kustutus",
title_acronym_element:"Elemendi akron\u00FC\u00FCm",
title_abbr_element:"Elemendi l\u00FChend",
title_cite_element:"Elemendi tsitaat",
remove:"Eemalda",
insert_date:"Sisesta hetke kuup\u00E4ev/aeg",
option_ltr:"Vasakult paremale",
option_rtl:"Paremalt vasakule",
attribs_title:"Sisesta/muuda atribuute"
});