tinyMCE.addI18n('br.table_dlg',{
general_tab:"Geral",
advanced_tab:"Avan\u00E7ado",
general_props:"Propriedades gerais",
advanced_props:"Propriedades avan\u00E7adas",
rowtype:"Linha na parte da tabela",
title:"Inserir/modificar tabela",
width:"Largura",
height:"Altura",
cols:"Colunas",
rows:"Linhas",
cellspacing:"Cellspacing",
cellpadding:"Cellpadding",
border:"Limites",
align:"Alinhamento",
align_default:"Padr\u00E3o",
align_left:"Esquerda",
align_right:"Direita",
align_middle:"Centro",
row_title:"Propriedades de linhas",
cell_title:"Propriedades de c\u00E9lulas",
cell_type:"Tipo de c\u00E9lula",
valign:"Alinhamento vertical",
align_top:"Topo",
align_bottom:"Abaixo",
bordercolor:"Cor dos limites",
bgcolor:"Cor de fundo",
merge_cells_title:"Unir c\u00E9lulas",
id:"Id",
style:"Estilo",
langdir:"Dire\u00E7\u00E3o do texto",
langcode:"C\u00F3digo da linguagem",
mime:"MIME alvo",
ltr:"Da esquerda para a direita",
rtl:"Da direita para a esquerda",
bgimage:"Imagem de fundo",
summary:"Sum\u00E1rio",
td:"Dados",
th:"Campo",
cell_cell:"Atualizar esta c\u00E9lula",
cell_row:"Atualizar todas as c\u00E9lulas na linha",
cell_all:"Atualizar todas as c\u00E9lulas na tabela",
row_row:"Atcualizar esta linha",
row_odd:"Atualizar linhas \u00EDmpares",
row_even:"Atualizar linhas pares",
row_all:"Atualizar todas as linhas",
thead:"Topo da tabela",
tbody:"Corpo da tabela",
tfoot:"Rodap\u00E9 da tabela",
scope:"Alcance",
rowgroup:"Grupo linhas",
colgroup:"Grupo colunas",
col_limit:"Excedeu o n\u00FAmero m\u00E1ximo de colunas de {$cols}.",
row_limit:"Excedeu o n\u00FAmero m\u00E1ximo de linhas de {$rows}.",
cell_limit:"Excedeu o n\u00FAmero m\u00E1ximo de c\u00E9lulas de {$cells}.",
missing_scope:"Tem certeza de que quer continuar sem especificar um escopo para esta c\u00E9lula? (Isso poder\u00E1 causar dificuldades a usu\u00E1rios deficientes)",
caption:"T\u00EDtulo da tabela",
frame:"Frame",
frame_none:"Nenhum",
frame_groups:"Grupos",
frame_rows:"Linhas",
frame_cols:"colunas",
frame_all:"Todos",
rules:"Regras",
rules_void:"void",
rules_above:"acima",
rules_below:"abaixo",
rules_hsides:"Hsides",
rules_lhs:"Lhs",
rules_rhs:"Rhs",
rules_vsides:"Vsides",
rules_box:"Box",
rules_border:"Limites"
});