tinyMCE.addI18n('hu.emotions_dlg',{
title:"Hangulatjel besz\u00FAr\u00E1sa",
desc:"Hangulatjelek",
cool:"Kir\u00E1ly",
cry:"S\u00EDr\u00F3s",
embarassed:"Zavarban van",
foot_in_mouth:"L\u00E1b a sz\u00E1jban",
frown:"Rosszall",
innocent:"\u00C1rtatlan",
kiss:"Cs\u00F3k",
laughing:"Nevet\u00E9s",
money_mouth:"P\u00E9nz besz\u00E9l",
sealed:"Lakat a sz\u00E1j\u00E1n",
smile:"Vigyor",
surprised:"Meglepett",
tongue_out:"Nyelv\u00F6lt\u00E9s",
undecided:"Hat\u00E1rozatlan",
wink:"Kacsint\u00E1s",
yell:"\u00DCv\u00F6lt\u00E9s"
});