tinyMCE.addI18n('sl.advanced_dlg',{
about_title:"O TinyMCE",
about_general:"Vizitka",
about_help:"Pomo\u010D",
about_license:"Licenca",
about_plugins:"Vsadki",
about_plugin:"Vsadek",
about_author:"Avtor",
about_version:"Verzija",
about_loaded:"Nalo\u017Eeni vsadki",
anchor_title:"Vstavi/uredi sidro",
anchor_name:"Ime sidra",
code_title:"Urejevalnik kode HTML",
code_wordwrap:"Prelomi vrstice",
colorpicker_title:"Izberite barvo",
colorpicker_picker_tab:"Izbor",
colorpicker_picker_title:"Izbor barve",
colorpicker_palette_tab:"Paleta",
colorpicker_palette_title:"Barve palete",
colorpicker_named_tab:"Poimenovane",
colorpicker_named_title:"Poimenovane barve",
colorpicker_color:"Barva:",
colorpicker_name:"Ime:",
charmap_title:"Izberite posebni znak",
image_title:"Vstavi/uredi sliko",
image_src:"Naslov URL slike",
image_alt:"Opis slike",
image_list:"Seznam slik",
image_border:"Obroba",
image_dimensions:"Dimenzije",
image_vspace:"Prostor zg/sp",
image_hspace:"Prostor le/de",
image_align:"Poravnava",
image_align_baseline:"osnovna \u010Drta",
image_align_top:"vrh",
image_align_middle:"sredina",
image_align_bottom:"dno",
image_align_texttop:"vrh besedila",
image_align_textbottom:"dno besedila",
image_align_left:"levo, plavajo\u010De",
image_align_right:"desno, plavajo\u010De",
link_title:"Vstavi/uredi povezavo",
link_url:"Naslov URL",
link_target:"Ime cilja",
link_target_same:"odpri povezavo v istem oknu",
link_target_blank:"odpri povezavo v novem oknu",
link_titlefield:"Naslov",
link_is_email:"Vneseni naslov verjetno prestavlja e-naslov, \u017Eelite da dodam zahtevano predpono \'mailto:\'?",
link_is_external:"Vneseni naslov verjetno predstavlja zunanjo povezavo, \u017Eelite da dodam zahtevano predpono \'http://\'?",
link_list:"Seznam povezav"
});